package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.AreaSupplier;
import com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;

public class AreaSupplierService {
	
	static final String URL = "areaSupplier";
	
	private Logger logger = Logger.getLogger(AreaSupplierService.class);
	
	
	/**
	 * @Description: 判断区内企业是否存在
	 * @author mazc
	 * @param areaSupplierName
	 * @param supplierType
	 * @return 
	 */
	public boolean hasSupplier(String areaSupplierName, String supplierType){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/hasSupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("areaSupplierName", areaSupplierName);
		param.put("supplierType", supplierType);
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 通过名字获取区内企业
	 * @author mazc
	 * @param areaSupplierName
	 * @return 
	 */
	public List<AreaSupplier> getAreaSupplierList( ){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getAreaSupplierListByName");
  		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.strToList(result, AreaSupplier.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存下载区内企业信息
	 * @author mazc
	 * @param areaSupplier
	 * @return 
	 */
	public String saveDownLoadAreaSupplier(AreaSupplier areaSupplier){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveDownLoadAreaSupplier");
 		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(areaSupplier));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return result;
  			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;	 
	}
	
	/**
	 * @Description: 插入数据
	 * @author mazc
	 * @param areaSupplier
	 * @return 
	 */
	public boolean insert(AreaSupplier areaSupplier){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(areaSupplier));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 更新分配属性
	 * @author mazc
	 * @param areaSupplier
	 * @param attributes
	 * @return 
	 */
	public boolean updateAssignProperty(AreaSupplier areaSupplier ,String [] attributes){
		AreaSupplier areaSupplierEntity = null;
		try {
			WebReflecUtill<AreaSupplier> utill = new WebReflecUtill<AreaSupplier>();
			areaSupplierEntity =  (AreaSupplier) utill.reflex(areaSupplier, attributes,AreaSupplier.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != areaSupplierEntity){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(areaSupplierEntity));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
}
