package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.DictEnum;
import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.BidPriceEnum;
import com.gx.obe.components.core.enumeration.CommonEnum;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.entity.DictionaryValue;
import com.gx.obe.web.entity.price.Currency;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class BaseDictionaryValueService {
	
	static final String URL = "baseDictionaryValue";
	
	private Logger logger = Logger.getLogger(BaseDictionaryValueService.class);
	
	 /**   
	 * @Title: getBidOpeningRoomList   
	 * @Description: 通过状态查询开标室列表
	 * @param: @param useStatus
	 * @param: @return      
	 * @return: List<BidOpeningRoom>      
	 * @throws   
	 */  
	public List<DictionaryValue> getDictionaryValueList(String dictCode){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/dictionarylist");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictCode", dictCode);
		param.put("useStatus", CommonEnum.REAL_STATUS);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.strToList(result, DictionaryValue.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据字典编号获得数据字典值列表
	 * @author wangxiang
	 * @param dicCode
	 * @return 
	 */
	public List<DictionaryValue> getDictValueListByDicCode(String dicCode){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictValueListByDicCode");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dicCode", dicCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, DictionaryValue.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得币种数据字典
	 * @author guoyr
	 * @return 
	 */
	public List<Currency> getCurrencyDictionaryList(){
		//请求地址
		List<DictionaryValue> dictionaryValueList = null;
		List<Currency> currencyList = new ArrayList<Currency>();
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictValueListByDicCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dicCode", DictEnum.DIC_CURRENCY);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				dictionaryValueList = JsonUtil.jsonToList(result, DictionaryValue.class);				
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			Currency currency = new Currency();
			currency.setCurrencyCode(BidPriceEnum.CNY_CODE);
			currency.setCurrencyName(BidPriceEnum.CNY_NAME);
			currency.addPriceUnit("元");
			currency.addPriceUnit("万元");
			currencyList.add(currency);
			
			if(null != dictionaryValueList){
				for(DictionaryValue dictionaryValue : dictionaryValueList){
					if(dictionaryValue.getDictValueCode().equals(BidPriceEnum.CNY_CODE)){
						continue;
					}
					
					Currency dicCurrency = new Currency();
					dicCurrency.setCurrencyCode(dictionaryValue.getDictValueCode());
					dicCurrency.setCurrencyName(dictionaryValue.getDictValueName());
					if(StringUtils.hasLength(dictionaryValue.getDictValueDesc())){
						String desc = dictionaryValue.getDictValueDesc();
						// TODO 这里根据备注中的jsons格式或其他格式读取单位
						dicCurrency.addPriceUnit(desc);
						dicCurrency.addPriceUnit("万"+desc);
					}else {
						dicCurrency.addPriceUnit(dictionaryValue.getDictValueName());
					}
					currencyList.add(dicCurrency);
				}
			}
			Currency rateCurrency = new Currency();
			rateCurrency.setCurrencyCode(BidPriceEnum.PRICE_RATE);
			rateCurrency.setCurrencyName("折扣率");
			rateCurrency.addPriceUnit("%");
			currencyList.add(rateCurrency);
		}
		return currencyList;
	}
	
	/**
	 * @Description: 验证字典值名称唯一性
	 * @author mazc
	 * @param id
	 * @param dictName
	 * @return boolean true：是唯一；false:不是唯一
	 */
	public boolean isUniqueDictValueName(String dictId, String id, String dictValueName){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueDictValueName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictId", dictId);
		param.put("id", id);
		param.put("dictValueName", dictValueName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);		
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;		
		}
	}
	
	/**
	 * @Description: 验证字典值编码唯一性
	 * @author mazc
	 * @param id
	 * @param dictCode
	 * @return
	 */
	public boolean isUniqueDictValueCode(String dictId, String id, String dictValueCode){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueDictValueCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictId", dictId);
		param.put("id", id);
		param.put("dictValueCode", dictValueCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);		
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;		
		}
	}
	
	/**
	 * @Description: 获得数据字典值的最大序号
	 * @author mazc
	 * @return
	 */
	public int getMaxDictValueSortNo(){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxDictValueSortNo");
		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;		
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;		
		}
	}
	
	/**
	 * @Description: 交换数据字典值的排序
	 * @author mazc
	 * @param sourceDictValue
	 * @param targetDictValue
	 */
	public boolean changeDictValueSortNo(Integer sourceSortNo, String sourceid, Integer targetSortNo, String targetId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/changeDictValueSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sourceSortNo", sourceSortNo);
		param.put("sourceid", sourceid);
		param.put("targetSortNo", targetSortNo);
		param.put("targetId", targetId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得字典值列表
	 * @author mazc
	 * @param objIds
	 * @return
	 */
	public List<DictionaryValue> getDictValueList(List<String> objIds){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictValueList");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(objIds));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得字典ID下的字典值集合
	 * @author mazc
	 * @return List<DictionaryValue>
	 */
	public List<DictionaryValue> getDictionaryValueListByDicId(String dictId, String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictionaryValueListByDictIdAnduseStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictId", dictId);
		param.put("useStatus", useStatus);
 
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
	}
		
	/**
	 * @Description: 根据字典编号获得数据字典值
	 * @author mazc
	 * @param dicCode
	 * @return
	 */
	public Map<String, String> getDictMapValueByDicCode(String dicCode){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictMapValueByDicCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dicCode", dicCode);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				List<Map<String, Object>> dicValueList = JsonUtil.jsonToListMap(result);
					Map<String, String> dicValueMap = null;
					if(null != dicValueList && dicValueList.size() > 0){
						dicValueMap = new HashMap<String, String>();
						for(Map<String, Object> map : dicValueList){
							dicValueMap.put((String)map.get("VALUE_CODE"), (String)map.get("VALUE_NAME"));
						}
					}
					return dicValueMap;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得指定数据字典的值
	 * @author mazc
	 * @param dictCode
	 * @param valueCode
	 * @return 
	 */
	public DictionaryValue getDictValue(String dictCode, String valueCode){
		if(null == dictCode || null == valueCode || valueCode.equals("")){
			return null;
		}
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictValueBydictCodeAndValue");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictCode", dictCode);
		param.put("valueCode", valueCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得特征码检查项
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<DictionaryValue> getFeatureCheckItemList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getFeatureCheckItemList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean insert(DictionaryValue dictionaryValue){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(dictionaryValue));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 获得清标检查项
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<DictionaryValue> getCleanTenderItemList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getCleanTenderItemList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 判断字典值是否存在
	 * @author mazc
	 * @param dictValueName
	 * @return 
	 */
	public boolean hasDictValueName(String dictValueName){
		if(null == dictValueName){
			return false;
		}
		String strWebServerUrl = Constants.getServiceUrl( URL + "/hasDictValueName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictValueName", dictValueName);
	  	try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得指定数据字典的值
	 * @author mazc
	 * @return 
	 */
	public DictionaryValue getDictValue(String dictValueName){
		if(null == dictValueName || dictValueName.equals("")){
			return null;
		}
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getDictValueByDictValueName");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictValueName", dictValueName);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	public int batchDelete(List<DictionaryValue> list){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchDelete");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.isReultStatusInteger(result)){	
 				return Integer.valueOf(result);
 			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	public boolean updateAssignProperty(DictionaryValue dictionaryValue ,String [] attributes){
		DictionaryValue dictionaryValueEntity = null;
		try {
			WebReflecUtill<DictionaryValue> utill = new WebReflecUtill<DictionaryValue>();
			dictionaryValueEntity =  (DictionaryValue) utill.reflex(dictionaryValue, attributes,DictionaryValue.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != dictionaryValueEntity){
 			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(dictionaryValueEntity));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param authUser
	 * @return 
	 */
	public DictionaryValue saveOrUpdateReturn(DictionaryValue dictionaryValue){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
		try{
			String result = NetworkRequest.post(strWebServerUrl,  JsonUtil.jsonObjectToStr(dictionaryValue));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				DictionaryValue tempDictionaryValue = JsonUtil.jsonToBean(result, DictionaryValue.class);					
				return tempDictionaryValue;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
}
