package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.BidOpeningRoom;
import com.gx.obe.web.utils.ResultStatus;

public class BidOpeningRoomService {
	
	private Logger logger = Logger.getLogger(BidOpeningRoomService.class);

	static final String URL = "bidOpeningRoom";
	 /**   
	 * @Title: getBidOpeningRoomList   
	 * @Description: 通过状态查询开标室列表
	 * @param: @param useStatus
	 * @param: @return      
	 * @return: List<BidOpeningRoom>      
	 * @throws   
	 */  
	public List<BidOpeningRoom> getBidOpeningRoomList(String useStatus){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/openingRoomList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("useStatus", useStatus);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.strToList(result, BidOpeningRoom.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 通过id获取评标室信息
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public BidOpeningRoom getBidOpeningRoomById(String id){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToBean(result, BidOpeningRoom.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	  
	/**
	 * @Description:  查询开标室列表
	 * @author mazc
	 * @return 
	 */
	public List<BidOpeningRoom> getBidOpeningRoomAll(){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/openingRoomAll");
		Map<String, Object> param = new HashMap<String, Object>();
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.strToList(result, BidOpeningRoom.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
  
	/**
	 * @Description: 通过id删除
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public boolean deleteById(String id){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 更新
	 * @author mazc
	 * @param supplierList
	 * @param attributes 要跟新的字段
	 */
	public boolean updateById(BidOpeningRoom openingRoom,String [] attributes){
		WebReflecUtill<BidOpeningRoom> utill = new WebReflecUtill<BidOpeningRoom>();
		BidOpeningRoom bidOpeningRoom =  (BidOpeningRoom) utill.reflex(openingRoom, attributes,BidOpeningRoom.class);			
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateById");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidOpeningRoom));
			return ResultStatus.getReultStatusBoolean(result); 
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param openingRoom
	 * @return 
	 */
	public BidOpeningRoom saveOrUpdate(BidOpeningRoom openingRoom){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateById");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(openingRoom));
			if(ResultStatus.getReultStatusBoolean(result)){
				return 	openingRoom;
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return openingRoom;
	}
	
	/**
	 * @Description: 通过id或者name查询
	 * @author mazc
	 * @param id
	 * @param name
	 * @return 
	 */
	public List<Object> findIdOrName(String id , String name){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/findIdOrName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		param.put("name", name);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	public static void main(String[] args) {
		BidOpeningRoomService bidOpeningRoomService = new BidOpeningRoomService();
		List<BidOpeningRoom> roomlist =  bidOpeningRoomService.getBidOpeningRoomList("01");
		for(BidOpeningRoom room : roomlist ){
			System.out.println(room.getBidOpeningRoomName());
		}
	}
}
