package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.StringUtil;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.price.BidPriceHisResult;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 历史投标报价
 * @author mazc 
 */
public class BidPriceHisResultService {
	
	private Logger logger = Logger.getLogger(BidPriceHisResultService.class);

	static final String URL = "bidPriceHisResult";

	/**
	 * @Description: 通过tenderId 删除历史投标报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public int deleteBidPrcieByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteBidPrcieByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 插入记录
	 * @author mazc
	 * @param bidPriceHisResult
	 * @return 
	 */
	public boolean insert(BidPriceHisResult bidPriceHisResult){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPriceHisResult));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 
	 * @author mazc
	 * @param tenderId
	 * @param supplierList
	 * @return 
	 */
	public Map<String,String> getSupplierMaxPriceRoundMap(String tenderId ,String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierMaxPriceRoundMap");
		Map<String,String> resultMap = null;
		try{
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);	
			param.put("supplierId", supplierId);	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				resultMap = JsonUtil.jsonToBean(result, Map.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == resultMap){
				resultMap = new HashMap<String, String>();
			}
		}
		return resultMap;
	}
	
	/**
	 * @Description: 获得项目下指定轮次报价供应商报价完成情况
	 * @author mazc
	 * @param tenderId
	 * @param supplierList
	 * @return 
	 */
	public Map<String,Boolean> getBidPriceRoundComplateStatus(String tenderId ,int round){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierBidPriceRoundComplateStatus");
		Map<String,Boolean> resultMap = null;
		try{
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);	
			param.put("round", round);	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				resultMap = JsonUtil.jsonToBean(result, Map.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == resultMap){
				resultMap = new  HashMap<String, Boolean>();
			}
		}
		return resultMap;
	}
	
	/**
	 * @Description: 获得供应商在指定报价轮次报价完成情况
	 * @author mazc
	 * @param tenderId
	 * @param supplierList
	 * @return 
	 */
	public Map<String,Boolean> getSupplierBidPriceRoundComplateStatus(String tenderId ,String supplierId, int round){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierBidPriceRoundComplateStatus");
		Map<String,Boolean> resultMap = null;
		try{
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);	
			param.put("supplierId", supplierId);	
			param.put("round", round);	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				resultMap = JsonUtil.jsonToBean(result, Map.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == resultMap){
				resultMap = new  HashMap<String, Boolean>();
			}
		}
		return resultMap;
	}
	
	
	
	
	/**
	 * @Description: 获得供应商的历史报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidprcieId
	 * @param supplierId
	 * @return 
	 */
	public List<BidPriceHisResult> getBidPriceHisResultList(String tenderId, String bidpriceId,String supplierId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceHisResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		if(!StringUtil.empty(bidpriceId)){
			param.put("bidPriceId", bidpriceId);
		}else{
			param.put("bidPriceId", null);
		}
		if(!StringUtil.empty(supplierId)){
			param.put("supplierId", supplierId);			
		}
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}

	/**
	 * @Description: 按轮次获得历史报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @param round
	 * @return 
	 */
	public List<BidPriceHisResult> getBidPriceHisResultList(String tenderId, String bidPriceId ,int round ){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceHisResultListByRound");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		if(!StringUtil.empty(bidPriceId)){
			param.put("bidPriceId", bidPriceId);			
		}
		param.put("round", round);			
		 
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
 
	/**
	 * @Description: 按轮次获得历史报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @param round
	 * @return 
	 */
	public List<BidPriceHisResult> getSupplierBidPriceHisResultListByRound(String tenderId, String supplierId ,int round ){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierBidPriceHisResultListByRound");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);			
		param.put("round", round);			
		
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/**
	 * @Description: 通过TenderId、SupplierId、bidPriceRound 查询报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceRound 
	 */
	public BidPriceHisResult getBidPriceHisResultByTenderId(String tenderId,String supplierId,int bidPriceRound){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceHisResultByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("bidPriceRound", bidPriceRound);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToBean(result, BidPriceHisResult.class); 
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据供应商id查询历史报价
	 * @author mazc
	 * @return 
	 */
	public List<BidPriceHisResult> getBidPriceHisResultBySupplierId(String supplierId ,int bidPriceRound){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceHisResultBySupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("supplierId", supplierId);
		param.put("bidPriceRound", bidPriceRound);			
		 
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	
	/**
	 * @Description: 根据tenderId查询历史报价
	 * @author mazc
	 * @return 
	 */
	public List<BidPriceHisResult> getBidPriceHisResultByTenderIdList(String tenderId ,String bidPriceId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceHisResultByTenderIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidPriceId", bidPriceId);			
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	public BidPriceHisResult getHisResultPriceIdAndSupplierIdAndPriceRound(String supplierId ,String bidPriceId ,int bidPriceRound){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getHisResultPriceIdAndSupplierIdAndPriceRound");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("supplierId", supplierId);
		param.put("bidPriceId", bidPriceId);
		param.put("bidPriceRound", bidPriceRound);

		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToBean(result, BidPriceHisResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/** 保存多轮报价历史表
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceResultList
	 * @param roundId
	 * @param fileName 
	 * @param downUrl 
	 * @return
	 */
	public boolean saveSupplierReBidPriceHisResult(String tenderId, String supplierId, List<BidPriceHisResult> bidPriceResultList ,String roundId, String downUrl, String fileName){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierReBidPriceHisResult");
		RequestBody<BidPriceHisResult> requestBody = new RequestBody<BidPriceHisResult>(); 
		requestBody.setEntityList(bidPriceResultList);
		requestBody.setParam("tenderId", tenderId);
		requestBody.setParam("supplierId", supplierId);
		requestBody.setParam("roundId", roundId);
		requestBody.setParam("downUrl", downUrl);
		requestBody.setParam("fileName", fileName);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	
	}
	
	
	public boolean saveUpateSupplierReBidPriceHisResult(String tenderId, String supplierId, List<BidPriceHisResult> bidPriceResultList ,String roundId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveUpateSupplierReBidPriceHisResult");
		RequestBody<BidPriceHisResult> requestBody = new RequestBody<BidPriceHisResult>(); 
		requestBody.setEntityList(bidPriceResultList);
		requestBody.setParam("tenderId", tenderId);
		requestBody.setParam("supplierId", supplierId);
		if(StringUtils.isNotEmpty(roundId)) {
			requestBody.setParam("roundId", roundId);
		}
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	
	}
	
	
	
	
	
//	/**
//	 * @Description: 获得供应商报价的最大轮次
//	 * @author mazc
//	 * @param tenderId
//	 * @param supplierId
//	 * @param bidPriceId
//	 * @return 
//	 */
//	public int getSupplierMaxPriceRound(String tenderId, String supplierId, String bidPriceId){
//		String strWebServerUrl = Constants.getServiceUrl(URL + "/");
//		Map<String, Object> param = new HashMap<String, Object>();
//		param.put("tenderId", tenderId);
//		param.put("supplierId", supplierId);
//		param.put("bidPriceId", bidPriceId);
// 		try{
//			String result = NetworkRequest.get(strWebServerUrl,param);
//			if(ResultStatus.getReultStatusInteger(result)){	
//				return Integer.valueOf(result);
//			}
//			return 0;
//		} catch (Exception e) {
//			logger.error(e.getMessage(), e);
//			return 0;
//		}
//	}
//	
	public static void main(String[] args) {
		BidPriceHisResultService bidPriceHisResultService =new BidPriceHisResultService();
		List<Supplier> list = new ArrayList<Supplier>();
//		bidPriceHisResultService.getSupplierMaxPriceRoundMap("",list);
	}
}
