package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.vo.SaveSupplierBidPriceResultVo;
import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.SupplierOpeningResult;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.price.BidPrice;
import com.gx.obe.web.entity.price.BidPriceResult;
import com.gx.obe.web.entity.tender.TenderProjectEntity;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.SaveSubBidPriceResultVo;
import com.gx.obe.web.vo.SaveSupplierInputBidPriceResultVo;
import com.gx.obe.web.vo.SaveSupplierInputEvaluationPriceResultVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/** 
 * @Description: 投标报价数据接口
 * @author mazc 
 */
public class BidPriceResultService {
	
	static final String URL = "bidPriceResult";
	
	private Logger logger = Logger.getLogger(BidPriceResultService.class);
	

	
	/**
	 * @Description: 获得供应商的分项报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @return 
	 */
	public List<BidPriceResult> getBidPriceResultList(String tenderId, String bidPriceId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findBidPriceResultList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
//		if(null != bidPriceId ){
			param.put("bidPriceId", bidPriceId);
//		}
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得供应商开标一览表
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public List<BidPriceResult> getBidPriceResultTableList(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceResultTableList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description:  获得分项报价结果
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<BidPriceResult> getBidPriceResultList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceResultList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}


	/**
	 * @Description: 获得唱标的分项报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Deprecated
	public List<BidPriceResult> getSingBidPriceResultList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSingBidPriceResultList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 获得供应商的分项报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public List<BidPriceResult> getSupplierBidPriceResultList(String tenderId, String supplierId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierBidPriceResultList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得供应商的分项报价
	 * @author mazc
	 * @param bidPriceId
	 * @param supplierId
	 * @return 
	 */
	public BidPriceResult getSupplierBidPriceResult(String bidPriceId, String supplierId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierBidPriceResult");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("bidPriceId", bidPriceId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToBean(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存分项报价和总报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierOpeningResultList
	 * @param bidPriceResultList
	 * @return 
	 */
	public boolean saveSubBidPriceResult(String tenderId, List<SupplierOpeningResult> supplierOpeningResultList, List<BidPriceResult> bidPriceResultList, boolean isEvaluationPrice){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSubBidPriceResult");
		SaveSubBidPriceResultVo  saveSubBidPriceResultVo = new SaveSubBidPriceResultVo();
		saveSubBidPriceResultVo.setTenderId(tenderId);
		saveSubBidPriceResultVo.setEvaluationPrice(isEvaluationPrice);
		saveSubBidPriceResultVo.setBidPriceResultList(bidPriceResultList);
		saveSubBidPriceResultVo.setSupplierOpeningResultList(supplierOpeningResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveSubBidPriceResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存供应商的报价信息
	 * @author mazc
	 * @param tenderId
	 * @param supplierOpeningResult
	 * @param newBidPriceList 新增的分项报价
	 * @param newBidPriceItemList 新增的分项报价明细
	 * @param bidPriceResultList 分项报价列表
	 * @param bidPriceItemResultList 分项报价明细列表
	 */
	public SupplierOpeningResult saveSupplierBidPriceResult(String tenderId, SupplierOpeningResult supplierOpeningResult, String businessBidStatus, String technologyBidStatus, String priceBidStatus, String bidOpeningStatus, Date bidOpeningTime, String bidOpeningRecord, List<BidPrice> newBidPriceList, List<BidPriceResult> bidPriceResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierBidPriceResult");
		SaveSupplierBidPriceResultVo saveSupplierBidPriceResultVo = new SaveSupplierBidPriceResultVo();
		saveSupplierBidPriceResultVo.setBidOpeningRecord(bidOpeningRecord);
		saveSupplierBidPriceResultVo.setBidOpeningStatus(bidOpeningStatus);
		saveSupplierBidPriceResultVo.setBidOpeningTime(bidOpeningTime);
		saveSupplierBidPriceResultVo.setBidPriceResultList(bidPriceResultList);
		saveSupplierBidPriceResultVo.setBusinessBidStatus(businessBidStatus);
		saveSupplierBidPriceResultVo.setNewBidPriceList(newBidPriceList);
		saveSupplierBidPriceResultVo.setPriceBidStatus(priceBidStatus);
		saveSupplierBidPriceResultVo.setSupplierOpeningResult(supplierOpeningResult);
		saveSupplierBidPriceResultVo.setTechnologyBidStatus(technologyBidStatus);
		saveSupplierBidPriceResultVo.setTenderId(tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveSupplierBidPriceResultVo));
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToBean(result, SupplierOpeningResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/** 
	 * @Description: 补录开标结果
	 * @author mazc
	 * @param supplierOpeningResult
	 * @param bidPriceResultList
	 * @param bidPriceItemResultList
	 * @return 
	 */
	public boolean saveSupplierInputBidPriceResult(TenderProjectEntity tenderProjectEntity, SupplierOpeningResult supplierOpeningResult, List<BidPriceResult> bidPriceResultList, boolean allBidStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierInputBidPriceResult");
		SaveSupplierInputBidPriceResultVo saveSupplierInputBidPriceResultVo = new SaveSupplierInputBidPriceResultVo();
		saveSupplierInputBidPriceResultVo.setAllBidStatus(allBidStatus);
		saveSupplierInputBidPriceResultVo.setBidPriceResultList(bidPriceResultList);
		saveSupplierInputBidPriceResultVo.setSupplierOpeningResult(supplierOpeningResult);
		saveSupplierInputBidPriceResultVo.setTenderId(tenderProjectEntity.getId());
		saveSupplierInputBidPriceResultVo.setProjectId(tenderProjectEntity.getParentId());
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveSupplierInputBidPriceResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
//	/**
//	 * @Description: 保存供应商多轮报价
//	 * @author guoyr
//	 * @param tenderId
//	 * @param supplierId
//	 * @param bidPriceResultList
//	 * @return 
//	 */
//	public boolean saveSupplierReBidPriceResult(String tenderId, String supplierId, List<BidPriceResult> bidPriceResultList ,String roundId){
//
//		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierReBidPriceResult");
//		RequestBody<BidPriceResult> requestBody = new RequestBody<BidPriceResult>(); 
//		requestBody.setEntityList(bidPriceResultList);
//		requestBody.setParam("tenderId", tenderId);
//		requestBody.setParam("supplierId", supplierId);
//		if(StringUtils.isNotEmpty(roundId)) {
//			requestBody.setParam("roundId", roundId);
//		}
//		try {
//			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
//			return ResultStatus.getReultStatusBoolean(result);
//		} catch (Exception e) {
//			logger.error(e.getMessage(), e);
//			return false;
//		}
//	
//	}
	
	/** 
	 * @Description: 补录评标价
	 * @author mazc
	 * @param supplierOpeningResult
	 * @param bidPriceResultList
	 * @return 
	 */
	@Deprecated 
	public boolean saveSupplierInputEvaluationPriceResult(SupplierOpeningResult supplierOpeningResult, List<BidPriceResult> bidPriceResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierInputEvaluationPriceResult");
		SaveSupplierInputEvaluationPriceResultVo saveSupplierInputEvaluationPriceResultVo = new SaveSupplierInputEvaluationPriceResultVo();
		saveSupplierInputEvaluationPriceResultVo.setBidPriceResultList(bidPriceResultList);
		saveSupplierInputEvaluationPriceResultVo.setSupplierOpeningResult(supplierOpeningResult);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveSupplierInputEvaluationPriceResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存汇率转换后的评标价
	 * @author mazc
	 * @param tenderProjectEntity
	 * @param bidPriceResultList
	 * @return 
	 */
	public boolean saveExchangeRateEvaluation(TenderProjectEntity tenderProjectEntity, List<BidPriceResult> bidPriceResultList){
		RequestBody<BidPriceResult> requestBody = new RequestBody<BidPriceResult>();
		requestBody.setEntityList(bidPriceResultList);
		requestBody.setParam("tenderProjectEntity", tenderProjectEntity);
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveExchangeRateEvaluation");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean insert(BidPriceResult bidPriceResult){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPriceResult));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	} 
	
	public boolean hasBidPriceResult(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/hasBidPriceResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param tenderId
	 * @param bidPrice
	 * @return 
	 */
	public List<BidPriceResult> getTenderIdAndBidPrice(String tenderId, String bidPrice){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderIdAndBidPrice");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidPrice", bidPrice);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPriceResult.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param bidPriceResult
	 * @param attributes
	 * @return 
	 */
	public boolean updateAssignProperty(BidPriceResult bidPriceResult, String[] attributes) {
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<BidPriceResult> updateAssignPropertyVo = new UpdateAssignPropertyVo<BidPriceResult>();
		updateAssignPropertyVo.setEntity(bidPriceResult);
		updateAssignPropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param supplierList
	 * @param attributes 要跟新的字段
	 */
	public Integer batchSaveOrUpdate(List<BidPriceResult> list,String [] attributes){
		List<BidPriceResult>  newList;
		if(null != attributes && attributes.length > 0){
			newList  = new ArrayList<BidPriceResult>();
			for(BidPriceResult evaluationFactor : list){
				WebReflecUtill<BidPriceResult> utill = new WebReflecUtill<BidPriceResult>();
				BidPriceResult ruleEntity =  (BidPriceResult) utill.reflex(evaluationFactor, attributes,BidPriceResult.class);
				if(null != ruleEntity){
					newList.add(ruleEntity);
				}
			}
 		}else{
 			newList = list;
		}
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSaveOrUpdate");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(newList));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	public boolean updateCurrencyCodeAndPriceUnitAndEvaluationPrice(String tenderId,String bidPriceId,String supplierId,String priceUnit,String currencyCode,String bidPrice, String evaluationPrice,String evaluationPriceOriginal){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateCurrencyCodeAndPriceUnitAndEvaluationPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidPriceId", bidPriceId);
		param.put("supplierId", supplierId);
		param.put("priceUnit", priceUnit);
		param.put("currencyCode", currencyCode);
		param.put("bidPrice", bidPrice);
		param.put("evaluationPrice", evaluationPrice);
		param.put("evaluationPriceOriginal", evaluationPriceOriginal);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 更新投标报价
	 * @author chenxw
	 * @param bidPriceResult
	 * @return 
	 */
	public boolean updateBidPriceResultOrSum(BidPriceResult bidPriceResult) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateBidPriceResultOrSum");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPriceResult));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 将未完成报价的供应商报价自动填充上一轮报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean updateSupplierIdNotRecordedBidPrice(String tenderId,String roundId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateSupplierIdNotRecordedBidPrice");
		try {
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);
			param.put("roundId", roundId);
 			String result = NetworkRequest.post(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
}
