package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.BidPriceRound;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.price.BidPriceRoundStatus;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 报价轮次状态表
 * @author mazc 
 */
public class BidPriceRoundStatusService {
	
	static final String URL = "bidPriceRoundStatus";
	
	private Logger logger = Logger.getLogger(BidPriceRoundStatusService.class);
	
	/**
	 * 
	 * @Description: 当前轮次是否完成报价 
	 * @author mazc
	 * @param strRoundId
	 * @return
	 */
 	public boolean isCompletePrice(String strRoundId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isCompletePrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("strRoundId", strRoundId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 当前轮次指定供应商是否完成报价
	 * @author mazc
	 * @param strRoundId
	 * @param supplier
	 * @return 
	 */
 	public boolean isCompletePriceBySupplier(String strRoundId,String supplier) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isCompletePriceBySupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("strRoundId", strRoundId);
		param.put("supplier", supplier);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 当前轮次未完成报价的供应商数量
	 * @author mazc
	 * @param strRoundId
	 * @return 
	 */
 	public int getNotCompletePriceNumber(String strRoundId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getNotCompletePriceNumber");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("strRoundId", strRoundId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	/**
	 * @Description: 当前轮次已完成的供应商数量
	 * @author mazc
	 * @param strRoundId
	 * @return 
	 */
 	public int getCompletePriceNumber(String strRoundId) {
 		String strWebServerUrl = Constants.getServiceUrl(URL + "/getCompletePriceNumber");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("strRoundId", strRoundId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	/**
	 * @Description: 更新轮次指定供应商报价状态
	 * @author mazc
	 * @param roundId
	 * @param supplier
	 * @return 
	 */
 	public boolean updateCompletePriceStatusBySupplierId(String roundId,String supplier,String status) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateCompletePriceStatusBySupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roundId", roundId);
		param.put("supplier", supplier);
		param.put("status", status);
  		try{
 			String result = NetworkRequest.post(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false ;
		}
	}
 	
 	
 	

	/**
	 * @Description: 更新轮次指定供应商报价状态
	 * @author mazc
	 * @param roundId
	 * @param supplier
	 * @return 
	 */
 	public boolean updateCompletePriceStatus(String roundId ,String status) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateCompletePriceStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roundId", roundId);
 		param.put("status", status);
  		try{
 			String result = NetworkRequest.post(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false ;
		}
	}
 	
 	
 	
 	
	public Map<String, String> getSupplierBidPriceRoundStatus(String roundId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierBidPriceRoundStatus");
		Map<String,String> resultMap = null;
		try{
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("roundId", roundId);	
 			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				resultMap = JsonUtil.jsonToBean(result, Map.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == resultMap){
				resultMap = new  HashMap<String, String>();
			}
		}
		return resultMap;
	}

	/**
	 * @Description: 根据轮次Id及供应商Id获取数据
	 * @author chenxw
	 * @param priceRoundId
	 * @param supplierId
	 * @return 
	 */
	public BidPriceRoundStatus getBidPriceRoundStatus(String priceRoundId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBidPriceRoundStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("priceRoundId", priceRoundId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, BidPriceRoundStatus.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	 
	public Map<String, String> getBidPriceRoundComplateStatus(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBidPriceRoundComplateStatus");
		Map<String,String> resultMap = null;
		try{
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);	
 			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				resultMap = JsonUtil.jsonToBean(result, Map.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == resultMap){
				resultMap = new  HashMap<String, String>();
			}
		}
		return resultMap;
	}
	
	public void updatRoundStatus(BidPriceRound curbidPriceRound) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updatRoundStatus");
		try{
			NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(curbidPriceRound));
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}
	
	
}
