package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.Result;
import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.price.BidPrice;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

public class BidPriceService {
	
	static final String URL = "bidPrice";
	
	private Logger logger = Logger.getLogger(BidPriceService.class);
	
	/**
	 * @Description: 删除分项报价
	 * @author mazc
	 * @param tenderId
	 * @param bidPrice
	 * @return 
	 */
	public boolean deleteBidPrice(String tenderId, String bidPriceId ,String joinTotal){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteBidPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidPriceId", bidPriceId);
		param.put("joinTotal", joinTotal);		 
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	
	}
	 
	/**
	 * @Description: 通过tenderId 获取投标报价列表
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<BidPrice> findTenderIdList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findTenderIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPrice.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获取开标一览表的数量
	 * @author guoyr
	 * @param tenderId
	 * @return 
	 */
	public int getBidPriceTableCount(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceTableCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	/**
	 * @Description: 获取当前项目的开标一览表
	 * @author guoyr
	 * @param tenderId
	 * @return 
	 */
	public List<BidPrice> getTenderBidPriceTableList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderBidPriceTableList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPrice.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description: 获取当前项目的开标一览表报价项
	 * @author guoyr
	 * @param tenderId
	 * @return 
	 */
	public List<BidPrice> getTenderBidPriceList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderBidPriceList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPrice.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得可做为价格指标的分项报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<BidPrice> getBidPriceFactorList(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceFactorList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, BidPrice.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 插入一条记录
	 * @author mazc
	 * @param bidPrice
	 * @return 
	 */
	public boolean insert(BidPrice bidPrice){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPrice));
			 return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	/**
	 * @Description: 批量保存已解析的开标一览表结构
	 * @author mazc
	 * @param bidPriceList
	 * @return 
	 */
	public boolean batchSaveResolverBidPriceTable(List<BidPrice> bidPriceList){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSaveResolverBidPriceTable");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPriceList));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 删除项目的分项报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean deleteProjectBidPrice(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteProjectBidPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
 
 
	/**
	 * @Description: 交换两个分项报价的排序
	 * @author mazc
	 * @param sourceSortNo
	 * @param sourceid
	 * @param targetSortNo
	 * @param targetId
	 * @return 
	 */
	public boolean changeBidPriceSortNo(Integer sourceSortNo, String sourceid, Integer targetSortNo, String targetId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/changeBidPriceSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sourceSortNo", sourceSortNo);
		param.put("sourceid", sourceid);
		param.put("targetSortNo", targetSortNo);
		param.put("targetId", targetId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
 
	/**
	 * @Description: 获得分项报价计入总价的其中一个
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public BidPrice getBidPriceByJoinTotal(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidPriceByJoinTotal");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, BidPrice.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	
	
	public boolean saveOrUpdate(BidPrice bidPrice){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		if(null == bidPrice.getId()){
			bidPrice.setId(UuidUtils.getUUID());
		}
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPrice));
			 return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param updateAssignProperty
	 */
	public boolean updateAssignProperty(BidPrice bidPrice, String[] attributes) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<BidPrice> updateAssignPropertyVo = new UpdateAssignPropertyVo<BidPrice>();
		updateAssignPropertyVo.setEntity(bidPrice);
		updateAssignPropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 删除根据id删除
	 * @author chenxw
	 * @param bidPriceId
	 * @return 
	 */
	public boolean deleteById(String bidPriceId) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", bidPriceId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 保存报价项
	 * @author chenxw
	 * @param bidPrice
	 * @return 
	 */
	@SuppressWarnings("unchecked")
	public Result<Integer> saveBidPrice(BidPrice bidPrice) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveBidPrice");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPrice));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, Result.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	

	/**
	 * @Description: 修改报价项
	 * @author chenxw
	 * @param updateAssignProperty
	 */
	public boolean updateBidPrice(BidPrice bidPrice, String[] attributes) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateBidPrice");
		UpdateAssignPropertyVo<BidPrice> updateAssignPropertyVo = new UpdateAssignPropertyVo<BidPrice>();
		updateAssignPropertyVo.setEntity(bidPrice);
		updateAssignPropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	public int getMaxBidPriceSortNo(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMaxBidPriceSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
}
