package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.BidRegulations;
import com.gx.obe.web.entity.StatusEntity;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 废标条款服务请求
 * @author mazc 
 */
public class BidRegulationsService {
	
	static final String URL = "bidRegulations";
	
	private Logger logger = Logger.getLogger(BidRegulationsService.class);
	
	/**
	 * @Description: 通过tenderid获取废标条款
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<BidRegulations> getBidRegulationsListByTenderId(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/byTenderIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){	
				return JsonUtil.strToList(result, BidRegulations.class); 
			}
			return null;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 统计当前项目下废标条款数量
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public Integer getBidRegulationsCount(String tenderId){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/byTenderIdSize");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){	
				return Integer.valueOf(result);						
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	/**
	 * @Description: 验证当前编号是否存在
	 * @author mazc
	 * @param tenderId
	 * @param number
	 * @return 
	 */
	public boolean verificationBidRegulationsSortNo(String tenderId ,int number){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isExistByTenderIdAndNumber");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("number", number);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){	
				return Boolean.valueOf(result); 
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 通过id删除记录
	 * @author mazc
	 * @param id 
	 */
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){	
				return Boolean.valueOf(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param source
	 * @param target 
	 */
	public void changeBidRegulationsSortNo(BidRegulations source, BidRegulations target){

		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateBatchById");
		
		BidRegulations sourcebidRegulations =  new BidRegulations();
		sourcebidRegulations.setId(source.getId());
		sourcebidRegulations.setSortNo(target.getSortNo());
		
		sourcebidRegulations.setShortName(source.getShortName());
		
		BidRegulations targetbidRegulations =  new BidRegulations();
		targetbidRegulations.setId(target.getId());
		targetbidRegulations.setSortNo(source.getSortNo());
		
		targetbidRegulations.setShortName(target.getShortName());
		
		List<Object> list = new ArrayList<Object>();
		list.add(targetbidRegulations);
		list.add(sourcebidRegulations);
		
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}
	
	/**
	 * @Description: 导入
	 * @author mazc
	 * @param bidRegulationsList
	 * @param tenderId
	 * @return 
	 */
	public boolean importBidRegulations(List<BidRegulations> bidRegulationsList, String tenderId){
		RequestBody<BidRegulations> requestBody = new RequestBody<BidRegulations>();
		requestBody.setEntityList(bidRegulationsList);
		requestBody.setParam("id", tenderId);
		String strWebServerUrl = Constants.getServiceUrl( URL + "/importBidRegulations");
		
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusOK(result)){	
				return Boolean.valueOf(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	public boolean saveOrUpdate(BidRegulations bidRegulations){
		String strWebServerUrl;
		if(null != bidRegulations.getId()){
			strWebServerUrl = Constants.getServiceUrl( URL + "/update");	
		}else{
			strWebServerUrl = Constants.getServiceUrl( URL + "/insert");	
		}
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidRegulations));
			if(ResultStatus.getReultStatusOK(result) && StatusEntity.TRUE.equals(result)){
				return true;
			}
			return false;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
 
	

}
