package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.CaBinding;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: CA服务
 * @author mazc 
 */
public class CaBindingService {
	
	static final String URL = "caBinding";
	
	private Logger logger = Logger.getLogger(CaBindingService.class);
	
	
	public boolean saveOrUpdate(CaBinding biding){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(biding));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}		
	}
	
	/**
	 * @Description: 通过用户id 获取ca信息
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	public List<CaBinding> getCaBindingByUserIdOrderBy(String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getCaBindingByUserIdOrderBy");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, CaBinding.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description: 插入一条记录
	 * @author mazc
	 * @param bidPrice
	 * @return 
	 */
	public boolean insert(CaBinding caBinding){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
 		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(caBinding));
			 return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	/**
	 * @Description: 通过id删除角色
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id );
		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获取证书是否被用过了
	 * @author mazc
	 * @param certId
	 * @param userId
	 * @return 
	 */
	public int getCaBindingByCertIdAndUserIdSize(String certId ,String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getCaBindingByCertIdAndUserIdSize");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("certId", certId );
		param.put("userId", userId );
		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.isReultStatusInteger(result)){	
 				return Integer.valueOf(result);
 			}
 			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	public CaBinding getCaBindingByCertIdAndUserId(String certId ,String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getCaBindingByCertIdAndUserId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("certId", certId );
		param.put("userId", userId );
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToBean(result, CaBinding.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
}
