package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.CheckResult;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.util.utils.StringUtil;

/** 
 * @Description: 
 * @author mazc 
 */
public class CheckResultService {
	static final String URL = "checkResult";
	private Logger logger = Logger.getLogger(CheckResultService.class);
	
	
	/**
	 * @Description:  保存工量清单的检查结果
	 * @author guoyr
	 * @param tenderId
	 * @param userId
	 * @param checkResultList
	 */
	public int saveBoqCheckResult(String tenderId, String userId, String checkItemId, List<CheckResult> checkResultList){
 		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveBoqCheckResult");
 		RequestBody<CheckResult> requestBody = new RequestBody<CheckResult>();
 		requestBody.setParam("tenderId", tenderId);
 		requestBody.setParam("userId", userId);
 		requestBody.setParam("checkItemId", checkItemId);
 		requestBody.setEntityList(checkResultList);
 		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);	
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 查询条件数量
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param checkItemId
	 * @return 
	 */
	public int getQueryCount(String tenderId,String userId,String checkItemId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getQueryCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("checkItemId", checkItemId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);	
			}
			return 0;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	/**
	 * @Description: 条件查询
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param supplierId
	 * @param checkItemId
	 * @param stepId 可以为null
	 * @return 
	 */
	public CheckResult getCheckResultByCondition(String tenderId,String userId,String supplierId ,String checkItemId,String stepId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getCheckResultByCondition");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("supplierId", supplierId);
		param.put("checkItemId", checkItemId);
		if(!StringUtil.empty(stepId)){
			param.put("stepId", stepId);
		}
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, CheckResult.class);
			}
			return null;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/** 
     * @Description: 获取清单检查结果
     * @author mazc
     * @param tenderId
     * @param checkItemId
     * @param supplierId
     * @return 
     */
	public List<CheckResult> getCheckResultByDictionaryValueId(String tenderId, String checkItemId, List<String> supplierIds) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getCheckResultByDictionaryValueId");
		RequestBody<String> requestBody = new RequestBody<String>(supplierIds);
		requestBody.setParam("tenderId", tenderId);
		requestBody.setParam("checkItemId", checkItemId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, CheckResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
}
