package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.DecEnvelope;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class DecEnvelopeService {
	
	static final String URL = "decEnvelope";
	
	private Logger logger = Logger.getLogger(CheckResultService.class);
	
	/**
	 * @Description: 获得解密信封
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public DecEnvelope getDecEnvelope(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDecEnvelope");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, DecEnvelope.class);
			}
			return null;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/**
	 * @Description: 上传解密信封
	 * @author mazc
	 * @param decEnvelope
	 * @return 
	 */
	public boolean uploadDecEnvelope(DecEnvelope decEnvelope){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/uploadDecEnvelope");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(decEnvelope));
			return ResultStatus.getReultStatusBoolean(result);	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
		
		
	}
	
	/**
	 * @Description: 是否已经存在解密信封
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public boolean hasDecEnvelope(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/hasDecEnvelope");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 按照id 去删除
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
}
