package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.Dictionary;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.DictionaryValue;
import com.gx.obe.web.utils.ResultStatus;

/**
 * @Description:
 * @author mazc
 */
public class DictionaryService {
	static final String URL = "baseDictionary";
	
	private Logger logger = Logger.getLogger(DictionaryService.class);
	
	/**
	 * @Description: 验证字典名称唯一性
	 * @author mazc
	 * @param id
	 * @param dictName
	 * @return boolean true：是唯一；false:不是唯一
	 */
	public boolean isUniqueDictName(String id, String dictName) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueDictName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		param.put("dictName", dictName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 验证字典编码唯一性
	 * @author mazc
	 * @param id
	 * @param dictCode
	 * @return
	 */
	public boolean isUniqueDictCode(String id, String dictCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueDictCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		param.put("dictCode", dictCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 根据编码，获得数据字典对象。
	 * @author mazc
	 * @param dictCode
	 * @return
	 */
	public Dictionary getDictionaryByCode(String dictCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDictionaryByCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictCode", dictCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, Dictionary.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
	}
	
	/**
	 * @Description: 根据编码，获得字典和字典值。
	 * @author mazc
	 * @param dictCode
	 * @return
	 */
	public Dictionary getDictionaryAndValuesByCode(String dictCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDictionaryAndValuesByCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictCode", dictCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, Dictionary.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param dictionary
	 * @return
	 */
	public Dictionary saveOrUpdateReturn(Dictionary dictionary) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(dictionary));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				Dictionary tempdictionary = JsonUtil.jsonToBean(result, Dictionary.class);
				return tempdictionary;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<Dictionary> getDictionaryListOrderByCreateTime() {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDictionaryListOrderByCreateTime");
		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Dictionary.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据字典编号获得数据字典值列表
	 * @author wangxiang
	 * @param dicCurrency
	 * @return
	 */
	public List<Dictionary> getDictValueListByDicCode(String dicCurrency) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDictValueListByDicCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dicCurrency", dicCurrency);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Dictionary.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据字典编码，获得有效字典值集合。
	 * @author guoyr
	 * @param dictCode 字典编码
	 * @return List<DictionaryValue>
	 */
	public List<DictionaryValue> getDictionaryValueList(String dictCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDictionaryValueList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("dictCode", dictCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, DictionaryValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
