package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.EncEnvelope;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class EncEnvelopeService {
	
	static final String URL = "encEnvelope";
	
	private Logger logger = Logger.getLogger(EncEnvelopeService.class);
	
	/**
	 * @Description:  上传投标信封
	 * @author mazc
	 * @param encEnverlope
	 * @return 
	 */
	public boolean uploadEncEnvelope(EncEnvelope encEnverlope){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/uploadEncEnvelope");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(encEnverlope));
			return ResultStatus.getReultStatusBoolean(result);	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
		
	}
	
	/**
	 * @Description: 删除项目的投标信封信息
	 * @author mazc
	 * @param tenderId 
	 */
	public boolean deleteTenderEnvelop(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteTenderEnvelop");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 删除供应商的投标信封信息
	 * @author mazc
	 * @param tenderId
	 * @param supplierId 
	 */
	public boolean deleteSupplierEnvelop(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteSupplierEnvelop");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}

	/**
	 * @Description: 获得投标信封
	 * @author wangxiang
	 * @param string
	 * @param supplierId
	 * @return 
	 */
	public EncEnvelope getEnEnvalopeByTenderIdSupplierId(String tenderId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEnEnvalopeByTenderIdSupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, EncEnvelope.class);
			} 
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
		return null;
	}
	
	public boolean deleteByTenderIdAndSupplierId(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteByTenderIdAndSupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
}
