package com.gx.obe.web.service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.EvaluationFactorItem;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class EvaluationFactorItemService {
	
	static final String URL = "evaluationFactorItem";
	
	private Logger logger = Logger.getLogger(EvaluationFactorItemService.class);
	
	
	/**
	 * @Description: 智能计算得分
	 * @author mazc
	 * @param supplierId
	 * @param factorCode
	 * @param tenderId
	 * @return 
	 */
	public BigDecimal getAIScore(String supplierId, String factorCode, String tenderId, BigDecimal highestScore){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAIScore");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("supplierId", supplierId);
		param.put("factorCode", factorCode);
		param.put("tenderId", tenderId);
		param.put("highestScore", highestScore);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return JsonUtil.jsonToBean(result, BigDecimal.class);			
			}
			return BigDecimal.ZERO;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return BigDecimal.ZERO;
		}
 		 
	}
	public List<EvaluationFactorItem> getItemByTenderIdAndSupplierIdAndfactorCode(String tenderId,String supplierId,String factorCode){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getItemByTenderIdAndSupplierIdAndfactorCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("supplierId", supplierId);
		param.put("factorCode", factorCode);
		param.put("tenderId", tenderId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, EvaluationFactorItem.class);			
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	public int batchSave(List<EvaluationFactorItem> list){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);			
			}
			return 0;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	public boolean deleteByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
}
