package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.InquireEnvelop;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class InquireEnvelopService {
	
	static final String URL = "inquireEnvelop";
	
	private Logger logger = Logger.getLogger(InquireEnvelopService.class);
	
	
	
	/**
	 * @Description: 获得询标函列表
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param supplierId
	 * @param stepId
	 * @return
	 */
	public List<InquireEnvelop> getInquireEnvelopList(String tenderId, String userId, String supplierId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getInquireEnvelopList");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("supplierId", supplierId);
		param.put("stepId", stepId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, InquireEnvelop.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);	
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean saveOrUpdate(InquireEnvelop inquireEnvelop){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(inquireEnvelop));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	 /**   
	 * @Title: updateAssignProperty   
	 * @Description: 更新分配属性
	 * @param: @param        
	 * @return: void      
	 * @throws   
	 */  
	public boolean updateAssignProperty(InquireEnvelop inquireEnvelop ,String [] attributes){
		InquireEnvelop tempInquireEnvelop = null;
		try {
			WebReflecUtill<InquireEnvelop> utill = new WebReflecUtill<InquireEnvelop>();
			tempInquireEnvelop =  (InquireEnvelop) utill.reflex(inquireEnvelop, attributes,InquireEnvelop.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != tempInquireEnvelop){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tempInquireEnvelop));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
}
