package com.gx.obe.web.service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.Machine;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.DateUtil;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.Condition;

/** 
 * @Description: 
 * @author mazc 
 */
public class MachineService {
	
	static final String URL = "machine";
	
	private Logger logger = Logger.getLogger(MachineService.class);
	
	
	/**
	 * @Description: 获得评标机位集合
	 * @author mazc
	 * @param tenderId 项目ID
	 * @param isUsed 是否使用
	 * @param machineType 类型
	 * @return List<Machine>
	 */
	public List<Machine> getProjectMachineList(String tenderId, String isUsed, String machineType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getProjectMachineList");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("isUsed", isUsed);
		param.put("machineType", machineType);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得当前项目下已登录的机位
	 * @author mazc
	 * @param tenderId 项目
	 * @param loginTime 登录时间
	 * @return
	 */
	public List<Machine> getProjectLoginedMachineList(String tenderId, Date loginTime){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getProjectLoginedMachineList");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("loginTime", DateUtil.formatDateTime(loginTime));
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得指定评标室内的机位列表
	 * @author mazc
	 * @param roomeId
	 * @return
	 */
	public List<Machine> getEvaluationRoomMachineList(String roomeId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvaluationRoomMachineList");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roomeId", roomeId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 批量保存已申请机位信息
	 * @author mazc
	 * @param list
	 * @return
	 */
	public int saveMachineList(List<Machine> list){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/uploadDecEnvelope");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	/** 
	 * @Description: 删除评标室的机位
	 * @author mazc
	 * @param roomId
	 * @return 
	 */
	public int deleteEvaluationRoomMachine(String roomId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteEvaluationRoomMachine");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roomId", roomId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 验证是否已经申请过该 机位
	 * @author mazc 
	 */
	public boolean isExist(String machineMac ,String machineIp,String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isExist");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("machineMac", machineMac);
		param.put("machineIp", machineIp);
		param.put("useStatus", useStatus);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
 	}
	 
	public Machine saveOrUpdateReturn(Machine machine){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");	
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(machine));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	public Machine applyMachine(Machine machine){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/applyMachine");	
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(machine));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param machineMac
	 * @param useStatus
	 * @return 
	 */
	public List<String> getEvalRoomIdByMachineMacAndUseStatus(String machineMac, String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvalRoomIdByMachineMacAndUseStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("machineMac", machineMac);
 		param.put("useStatus", useStatus);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, String.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param roomeId
	 * @return 
	 */
	public List<Machine> getMachineByUseStatusAndOrderby(String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMachineByUseStatusAndOrderby");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("useStatus", useStatus);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	public Machine getMachineByMacOrNotEQ(String machineMac,String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMachineByMacOrNotEQ");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("machineMac", machineMac);
		if(null != id){
			param.put("id", id);
		}
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Machine.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	public List<String> getEvalRoomIdByMachineNameAndEvalRoomId(String machineName, String evalRoomId,String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvalRoomIdByMachineNameAndEvalRoomId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("machineMac", machineName);
 		param.put("evalRoomId", evalRoomId);
 		if(null != id){
 			param.put("id", id);
 		}
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, String.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	public int updateCondition(Condition condition){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateCondition");	
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(condition));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	
	}
	
}
