package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.MenuFunction;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/**  
 * @Title:  MenuService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    菜单服务类  
 * @author: XiaoMaPro     
 * @date:   May 9, 2019 7:21:38 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class MenuFunctionService {
	
	static final String URL = "menuFunction";
	private Logger logger = Logger.getLogger(MenuFunctionService.class);
	 /**   
	 * @Title: getMenuFunctionMap   
	 * @Description: 通过菜单id 获取菜单功能列表，以及菜单状态
	 * @param: @param menuId
	 * @param: @return      
	 * @return: Map<String,String>      
	 * @throws   
	 */  
	public 	Map<String, String> getMenuFunctionMap(String menuId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMenuFunctions");
		Map<String, String> functions = null;
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);	
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				functions = JsonUtil.strToMap(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null == functions){
				functions = new HashMap<String, String>();
			}
		}
		
		return functions;
	}
	
	/**
	 * @Description: 获得最大序号
	 * @author mazc
	 * @param menuId
	 * @return 
	 */
	public int getMaxSortNo(String menuId){ 
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxSortNo");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);	
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 是否统一编码
	 * @author mazc
	 * @param menuId
	 * @param functionId
	 * @param functionCode
	 * @return 
	 */
	public boolean isUniqueFunctionCode(String menuId, String functionId, String functionCode){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueFunctionCode");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		param.put("functionId", functionId);
		param.put("functionCode", functionCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);	
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 根据menuId 查询menuFunctionList
	 * @author wangxiang
	 * @param menuId
	 * @return 
	 */
	public List<MenuFunction> getMenuFunctionListByMenuId(String menuId) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMenuFunctionListByMenuId");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, MenuFunction.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 批量保存
	 * @author wangxiang
	 * @param menuFunctionList
	 * @return 
	 */
	public int batchSave(List<MenuFunction> menuFunctionList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(menuFunctionList));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 删除
	 * @author wangxiang
	 * @param id
	 * @return 
	 */
	public boolean deleteById(String id) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}


	
	
	public boolean insert(MenuFunction menuFunction){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(menuFunction));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	public boolean saveOrUpdate(MenuFunction menuFunction){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(menuFunction));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	  /**
	 * @Description: 交换两个功能按钮顺序
	 * @author mazc
	 * @param source
	 * @param target
	 * @return 
	 */
	public boolean changeResourceSortNo(MenuFunction source, MenuFunction target) {
	        String strWebServerUrl = Constants.getServiceUrl(URL + "/changeResourceSortNo");
	        Map<String, Object> param = new HashMap<String, Object>();
	        param.put("sourceId", source.getId());
	        param.put("targetId", target.getId());
	        try {
	            String result = NetworkRequest.get(strWebServerUrl, param);
	            return ResultStatus.getReultStatusBoolean(result);
	        } catch (Exception e) {
	        	logger.error(e.getMessage(), e);
	        	return false;
	        }
	  }
	  
	
}
