package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.CommonEnum;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.ObjectUtils;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.entity.auth.Menu;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;

/**  
 * @Title:  MenuService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    菜单服务类  
 * @author: XiaoMaPro     
 * @date:   May 9, 2019 7:21:38 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class MenuService {
	
	static final String URL = "authMenu";
	
	private Logger logger = Logger.getLogger(MenuService.class);

	public List<Menu> getUserRoleMenuList(String userId, String roleId, String menuCode){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserRoleMenuList");
		List<Menu> menuList = null;
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("roleId", roleId);
//		param.put("useStatus", CommonEnum.REAL_STATUS);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				menuList = JsonUtil.strToList(result, Menu.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally{
			if(null != menuList && menuList.size() > 0){
				menuList = initChildResource(menuList , null);
			}
			if(null != menuCode && menuCode.length() > 0){
				menuList = ChildMenuList(menuList, menuCode);
			}
		}
		return menuList;
	}
	public List<Menu> getUserResourceMenuList(String userId, String roleType){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserMenuListByRoleType");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("roleType", roleType);
		param.put("useStatus", CommonEnum.REAL_STATUS);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	
	/**
	 * @Description: 菜单信息封装树节点(双重循环实现拼接)
	 * @param list
	 * @return
	 */
	public List<Menu> initChildResource(List<Menu> list, String parentId){
		List<Menu> menuList = null;
		if(null != list && list.size() > 0){
			menuList = new ArrayList<Menu>();
			for(Menu parentMenu : list){
				for(Menu subResource : list){
					if(StringUtils.isNotEmpty(subResource.getParentId()) && parentMenu.getId().equals(subResource.getParentId())){
						parentMenu.addChild(subResource);
						subResource.setParentMenu(parentMenu);
					}
				}
				if(ObjectUtils.equals(ObjectUtils.getObjString(parentId), ObjectUtils.getObjString(parentMenu.getParentId()))){
					menuList.add(parentMenu);
				}
			}
		}
		return menuList;
	}
	
	
	public List<Menu> ChildMenuList(List<Menu> userResourceList,String parentMenuId){
		List<Menu> menuList = new ArrayList<Menu>();
		if(null == parentMenuId){
			if(null != userResourceList && userResourceList.size() == 1){
				List<Menu> subMenuList = userResourceList.get(0).getChildList();
				if(null != subMenuList && subMenuList.size() > 0){
					return subMenuList;
				}
			}
			return userResourceList;
		}else {
			if(null != userResourceList){
				for(Menu menu : userResourceList){
					if(parentMenuId.equals(menu.getMenuCode())){
						if(null != menu.getChildList() && menu.getChildList().size() > 0){
							menuList.addAll(menu.getChildList());
						}else {
							menuList.add(menu);
						}
					}
				}
			}
		}
		return menuList;
	}	
	
	/**
	 * @Description: 获取顶级菜单信息
	 * @author wangxiang
	 * @return
	 */
	public List<Menu> getTopResourceList(){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTopResourceList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", null);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Menu.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获取子级菜单信息
	 * @author wangxiang
	 * @param parentId
	 * @return
	 */
	public List<Menu> getChildResourceList(String parentId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getChildResourceList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Menu.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获得全部菜单信息(包含子菜单和父级菜单信息)
	 * @author wangxiang
	 * @param type
	 * @return 
	 */
	public List<Menu> getAllResourceList(String type){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getAllResourceList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("type", type);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				List<Menu> menuList = JsonUtil.jsonToList(result, Menu.class);
				if(null != menuList){
					return initChildResource(menuList, null);
				}
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获得菜单的最大序号
	 * @author wangxiang
	 * @param parentId
	 * @return
	 */
	public int getMaxResourceSortNo(String parentId, String menuType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMaxResourceSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		param.put("menuType", menuType);
		try{
			String result = NetworkRequest.get(strWebServerUrl , param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	/**
	 * @Description: 交换两个菜单的排序
	 * @author wangxiang
	 * @param source
	 * @param target
	 */
    public boolean changeResourceSortNo(Menu source, Menu target) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/changeResourceSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("sourceId", source.getId());
        param.put("targetId", target.getId());
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
	
	/**
	 * @Description: 查询用户权限菜单
	 * @author wangxiang
	 * @param userId
	 * @param roleType
	 * @param parentMenuId
	 * @return 
	 */
	public List<Menu> getUserResourceList(String userId, String roleType, String parentMenuId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserResourceList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("roleType", roleType);
		try{
			logger.error("开始调用服务器接口", null);
			String result = NetworkRequest.get(strWebServerUrl, param);
			logger.error("服务器接口返回数据为：" + result, null);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				List<Menu> menuList = new ArrayList<Menu>();
				List<Menu> userResourceList = null;
				userResourceList = JsonUtil.jsonToList(result, Menu.class);
				if(null != userResourceList && userResourceList.size() > 0){
					userResourceList = initChildResource(userResourceList, null);
				}
				if(null == parentMenuId){
					if(null != userResourceList && userResourceList.size() == 1){
						List<Menu> subMenuList = userResourceList.get(0).getChildList();
						if(null != subMenuList && subMenuList.size() > 0){
							return subMenuList;
						}
					}
					return userResourceList;
				}else {
					if(null != userResourceList){
						for(Menu menu : userResourceList){
							if(parentMenuId.equals(menu.getMenuCode())){
								if(null != menu.getChildList() && menu.getChildList().size() > 0){
									menuList.addAll(menu.getChildList());
								}else {
									menuList.add(menu);
								}
							}
						}
					}
				}
				return menuList;
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 根据类型获得菜单列表
	 * @author wangxiang
	 * @param menuType
	 * @return 
	 */
	public List<Menu> getMenuListByMenuType(String menuType){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMenuListByMenuType");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuType", menuType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 菜单编号是否唯一
	 * @author wangxiang
	 * @param menuId
	 * @param menuCode
	 * @return 
	 */
	public boolean isUniqueMenuCode(String menuId, String menuCode){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueMenuCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		param.put("menuCode", menuCode);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 根据菜单编码获得菜单
	 * @author wangxiang
	 * @param menuCode
	 * @return 
	 */
	public Menu getMenuByMenuCode(String menuCode){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMenuByMenuCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuCode", menuCode);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return JsonUtil.jsonToBean(result, Menu.class);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据类型获得菜单列表
	 * @author wangxiang
	 * @param menuType
	 * @return 
	 */
	public List<Menu> getMenuListByMenuCode(String menuCode){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMenuListByMenuCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuCode", menuCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得下级菜单列表
	 * @author wangxiang
	 * @param menuType
	 * @return 
	 */
	public List<Menu> getMenuChildList(String parentId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMenuChildList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得菜单下的功能集
	 * @author wangxiang
	 * @param menuId
	 * @return 
	 */
	public Map<String, String> getMenuFunctionMap(String menuId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMenuFunctionMap");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean insert(Menu menu){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(menu));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public Menu getById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public Menu saveOrUpdateNoEmptyReturn(Menu menu){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateNoEmptyReturn");
			try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.objectToStr(menu));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 * @param list
	 * @param attributes
	 * @return 
	 */
	public boolean  batchUpdateProperty(List<Menu> list ,String [] attributes){
	    String strWebServerUrl = Constants.getServiceUrl( URL + "/batchUpdateProperty");
	    BatchUpdatePropertyVo<Menu> batchUpdatePropertyVo = new BatchUpdatePropertyVo<Menu>();
	    batchUpdatePropertyVo.setEntityList(list);
	    batchUpdatePropertyVo.setAttributes(attributes);
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.objectToStr(batchUpdatePropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean updateAssignProperty(Menu menu ,String [] attributes){
		Menu tempMenu = null;
		try {
			WebReflecUtill<Menu> utill = new WebReflecUtill<Menu>();
			tempMenu =  (Menu) utill.reflex(menu, attributes,Menu.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != tempMenu){
 			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tempMenu));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	} 
	
	/**
	 * @Description: 根据menucode获取菜单
	 * @author mazc
	 * @param menuCode
	 * @return 
	 */
	public Menu getMenutByMenuCode(String menuCode){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMenutByMenuCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuCode", menuCode);
		try{
			String result = NetworkRequest.get(strWebServerUrl,param );
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Menu.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description: 根据menuId 删除
	 * @author wangxiang
	 * @param menuId 
	 */
	public Integer deleteByMenuId(String menuId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteByMenuId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("menuId", menuId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}
}
