package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.ProjectEvaluationRoom;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class ProjectEvaluationRoomService {
	
	static final String URL = "projectEvaluationRoom";
	
	private Logger logger = Logger.getLogger(ProjectEvaluationRoomService.class);
	/**
	 * @Description: 是否存在主评标室
	 * @author mazc
	 * @param tenderId 项目ID
	 * @return
	 */
	public boolean isExistPrimaryRoom(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isExistPrimaryRoom");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得项目与评标室关联数据
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<ProjectEvaluationRoom> getProjectEvalRoomList(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getProjectEvalRoomList");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ProjectEvaluationRoom.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");	
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	public int deleteByTenderIdAndEvaluationRoomId(String tenderId,String evaluationRoomId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteByTenderIdAndEvaluationRoomId");	
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("evaluationRoomId", evaluationRoomId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	 /**   
	 * @Title: updateAssignProperty   
	 * @Description: 更新分配属性
	 * @param: @param tenderProjectRuleEntity      
	 * @return: void      
	 * @throws   
	 */  
	public boolean updateAssignProperty(ProjectEvaluationRoom projectEvaluationRoom ,String [] attributes){
		ProjectEvaluationRoom tempProjectEvaluationRoom = null;
		try {
			WebReflecUtill<ProjectEvaluationRoom> utill = new WebReflecUtill<ProjectEvaluationRoom>();
			tempProjectEvaluationRoom =  (ProjectEvaluationRoom) utill.reflex(projectEvaluationRoom, attributes,ProjectEvaluationRoom.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != tempProjectEvaluationRoom){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tempProjectEvaluationRoom));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
	
	public boolean saveOrUpdate(ProjectEvaluationRoom projectEvaluationRoom){
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
			try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(projectEvaluationRoom));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public int batchSave(List<ProjectEvaluationRoom> list){
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
			try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
}
