package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.DateUtils;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.tender.TenderProjectRuleEntity;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/**  
 * @Title:  ProjectRuleService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    项目规则  
 * @author: XiaoMaPro     
 * @date:   May 7, 2019 1:16:51 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
/** 
 * @Description: 
 * @author mazc 
 */
public class ProjectRuleService {
	static final String URL = "projectRule";
	private Logger logger = Logger.getLogger(ProjectRuleService.class);

	 /**   
	 * @Title: findByTenderID   
	 * @Description: 通过项目id查找项目规则
	 * @param: @param tenderId
	 * @param: @return      
	 * @return: TenderProjectRuleEntity      
	 * @throws   
	 */  
	public TenderProjectRuleEntity getProjectRule(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getProjectRule");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectRuleEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}
	
	 /**   
	 * @Title: insert   
	 * @Description: 创建新的项目规则
	 * @param: @param tenderProjectRuleEntity
	 * @param: @return      
	 * @return: TenderProjectRuleEntity      
	 * @throws   
	 */  
	public TenderProjectRuleEntity insert(TenderProjectRuleEntity tenderProjectRuleEntity){
		if(StringUtils.isEmpty(tenderProjectRuleEntity.getId())){
			tenderProjectRuleEntity.setId(UuidUtils.getUUID());
		}
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectRuleEntity));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectRuleEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param tenderProjectRuleEntity
	 * @param attributes
	 * @return 
	 */
	public boolean updateAssignProperty(TenderProjectRuleEntity tenderProjectRuleEntity, String[] attributes) {
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<TenderProjectRuleEntity> vo = new UpdateAssignPropertyVo<TenderProjectRuleEntity>();
		vo.setEntity(tenderProjectRuleEntity);
		vo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean updateAssignPropertyByProjectId(String projectId, TenderProjectRuleEntity tenderProjectRuleEntity, String [] attributes){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignPropertyByProjectId");
		UpdateAssignPropertyVo<TenderProjectRuleEntity> vo = new UpdateAssignPropertyVo<TenderProjectRuleEntity>();
		vo.setEntity(tenderProjectRuleEntity);
		vo.setAttributes(attributes);
		vo.setProjectId(projectId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
 		}
	}
	
	/**
	 * @Description: id批量更新
	 * @author mazc
	 * @param tenderRuleList
	 * @param attributes
	 * @return 
	 */
	public boolean batchUpdateProperty(List<TenderProjectRuleEntity> tenderRuleList, String[] attributes){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
		BatchUpdatePropertyVo<TenderProjectRuleEntity> vo = new  BatchUpdatePropertyVo<TenderProjectRuleEntity>();
		vo.setAttributes(attributes);
		vo.setEntityList(tenderRuleList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
 		}
 	}
	
	public boolean updataRule(TenderProjectRuleEntity tenderProjectRuleEntity){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateRule");
 		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectRuleEntity));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	public boolean updataRule(TenderProjectRuleEntity tenderProjectRuleEntity ,List<Object> list ,String [] attributes){
		TenderProjectRuleEntity ruleEntity = null;
		 if(null != attributes && attributes.length > 0){
			 try {
				 WebReflecUtill<TenderProjectRuleEntity> utill = new WebReflecUtill<TenderProjectRuleEntity>();
				 ruleEntity =  (TenderProjectRuleEntity) utill.reflex(tenderProjectRuleEntity, attributes,TenderProjectRuleEntity.class);
			 } catch (Exception e) {
				 e.printStackTrace();
				 return false;
			 }			 
		 }else{
			 ruleEntity = tenderProjectRuleEntity;
		 }
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateRuleList");
		//请求地址
		RequestBody<TenderProjectRuleEntity> requestBody = new RequestBody<TenderProjectRuleEntity>();
		requestBody.setEntity(ruleEntity);
		if(null != list){
			requestBody.setList(list);			
		}
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody)); 
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 是否匿名显示
	 * @author guoyr
	 * @param tenderId
	 * @param dbColumnName
	 * @return 
	 */
	public boolean isAnonymous(String tenderId){
		boolean isAnonymous = false;
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isAnonymous");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);		
			isAnonymous = ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	
		
		return isAnonymous;
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param tenderProjectEntity
	 * @return 
	 */
	public boolean saveOrUpdate(TenderProjectRuleEntity tenderProjectRuleEntity){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectRuleEntity));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	public TenderProjectRuleEntity saveOrUpdateReturn(TenderProjectRuleEntity tenderProjectRuleEntity){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectRuleEntity));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectRuleEntity.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return tenderProjectRuleEntity;
	}
	
	/**
	 * @Description: 获得项目的开标时间
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	public Date getBidOpeningTime(String tenderId){
		return getBidOpeningTime(tenderId, null);
	}
	/**
	 * @Description: 获得项目的开标时间
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	public Date getBidOpeningTime(String tenderId, String bidopeningStage){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidOpeningTime");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidopeningStage", bidopeningStage);
		String result  = null;
		try {
			result = NetworkRequest.get(strWebServerUrl,param);
			return DateUtils.toDate(result);
		} catch (Exception e) {
			logger.error(result + e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得项目的开标时间
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	public List<Date> getProjectBidOpeningTime(String projectId, String bidopeningStage){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getProjectBidOpeningTime");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("bidopeningStage", bidopeningStage);
		List<Date> openingTimeList = new ArrayList<Date>();
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			List<String> dateStringList = JsonUtil.StrToCollection(result, String.class);
			if(null != dateStringList) {
				for(String openingTimeStr : dateStringList) {
					openingTimeList.add(DateUtils.toDate(openingTimeStr));
				}
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return openingTimeList;
	}
	/**
	 * @Description: 更新时间
	 * @author mazc
	 * @param tenderIdList
	 * @param date
	 * @param dbColumnName 更新数据库字段
	 * @return 
	 */
	public int updateBidOpeningTimeOrOpeningStartTime(List<Object> tenderIdList,Date date,String dbColumnName){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateBidOpeningTimeOrOpeningStartTime");
		RequestBody<Date> requestBody = new RequestBody<Date>();
		requestBody.setEntity(date);
		requestBody.setList(tenderIdList);
		requestBody.setParam("dbColumnName", dbColumnName);
		try {
			String result = NetworkRequest.post(strWebServerUrl,JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusOK(result)){	
				return Integer.valueOf(result);						
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
		return 0;
	}
	
 	/**
 	 * @Description: 更新evalMethodType、evalMethodName数据
 	 * @author mazc
 	 * @param evalMethod
 	 * @param evalMethodName
 	 * @param tenderId
 	 * @return 
 	 */
 	public boolean updateEvalMethod(String evalMethod , String evalMethodName, String tenderId) {
 		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateEvalMethod");
 		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("tenderId", tenderId);
		param.put("evalMethod", evalMethod);
		param.put("evalMethodName", evalMethodName);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.getReultStatusOK(result)){	
				return ResultStatus.getReultStatusBoolean(result);						
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}
	/**
	 * @Description: 是否到达某个时间
	 * @author guoyr
	 * @param tenderId
	 * @param DB_TIME 项目规则表中所对应的时间的字段名称
	 * @return
	 */
	public boolean isStartTime(String tenderId, String DB_TIME){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isStartTime");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("dbColumnName", DB_TIME);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			return ResultStatus.isReultStatusInteger(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
 	}
	
	public static void main(String[] args) {
		ProjectRuleService projectRuleService = new ProjectRuleService();
		List<Object> list = new ArrayList<Object>();
		list.add("1");
		list.add("2");
		list.add("3");
		list.add("4");
		projectRuleService.updateBidOpeningTimeOrOpeningStartTime(list,new Date(),"BID_OPENING_START_TIME");
		
// 		TenderProjectRuleEntity tenderProjectRuleEntity = new TenderProjectRuleEntity();
//		tenderProjectRuleEntity.setSignEndTime(new Date());
//	
// 		tenderProjectRuleEntity.setId("aaaaaaa");
//		projectRuleService.updateAssignProperty(tenderProjectRuleEntity, new String[]{"AA","signEndTime","id"});
//		tenderProjectRuleEntity.setTenderId("7b6b31a50cae437d93fe9de0cfde7286");
//		tenderProjectRuleService.insert(tenderProjectRuleEntity);
//		List<Object> lists = new ArrayList<Object>();
//		lists.add("af296c8221934926be238df1d6c5e0d2");
//		lists.add("b482b8d9cdfe4e21a8121e68f7412dcd");
//		tenderProjectRuleService.updataRule(tenderProjectRuleEntity, lists,null);
	}
}
