package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.BidPriceRound;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.utils.ResultStatus;

public class ReBidPriceRoundService {
	
	private Logger logger = Logger.getLogger(ReBidPriceRoundService.class);
	static final String URL = "reBidPriceRound";
	
	/**添加轮次
	 * @param tenderId
	 * @param round
	 * @return
	 */
	public boolean moveHisBidPrice(String tenderId,List<Supplier> supplierList,int round){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/moveHisBidPrice");
		RequestBody<Supplier> requestBody = new RequestBody<Supplier>();
		requestBody.setEntityList(supplierList);
		requestBody.setParam("tenderId", tenderId);
		requestBody.setParam("round", round);
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 获得项目的最大伦次
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	public int getMaxRound(String tenderId){
		int maxRound = 1;
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxRound");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			maxRound = Integer.valueOf(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}finally {
			if(maxRound < 1){
				maxRound = 1;
			}
		}
		return maxRound;
	}
	
	/**
	 * @Description: 复原初始报价
	 * @author wangxiang
	 * @return 
	 */
	public boolean moveInitBidPrice(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/moveInitBidPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	/**
	 * @Description: 插入新一轮报价
	 * @author guoyr
	 * @param bidPriceRound
	 * @param useLastBidPrice 使用最新报价
	 * @return 
	 */
	public boolean insertNewBidpriceRound(BidPriceRound bidPriceRound, String tenderId, List<Supplier> supplierList ,List<Supplier> evaluationStepSupplierList){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertNewBidpriceRound");
		try{
			 RequestBody<BidPriceRound> requestBody = new RequestBody<BidPriceRound>();
			 requestBody.setEntity(bidPriceRound);
			 requestBody.setParam("tenderId", tenderId);
//			 requestBody.setParam("useLastBidPrice", useLastBidPrice);
			 if(null != supplierList){
				 StringBuilder supplierIds = new StringBuilder();
				 for(Supplier supplier : supplierList){
					 if(supplierIds.length() > 0){
						 supplierIds.append(",");
					 }
					 supplierIds.append(supplier.getId());
				 }
				 requestBody.setParam("supplierIds", supplierIds.toString());
			 }
			 if(null != evaluationStepSupplierList){
				 StringBuilder supplierIds = new StringBuilder();
				 for(Supplier supplier : evaluationStepSupplierList){
					 if(supplierIds.length() > 0){
						 supplierIds.append(",");
					 }
					 supplierIds.append(supplier.getId());
				 }
				 requestBody.setParam("evaluationStepSupplierIds", supplierIds.toString());
			 }
			 
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	
	
	/**
	 * @Description: 插入新一轮本地报价
	 * @return 
	 */
	public boolean insertNewLocalBidpriceRound(BidPriceRound bidPriceRound, String tenderId, List<Supplier> supplierList ){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertNewLocalBidpriceRound");
		try{
			 RequestBody<BidPriceRound> requestBody = new RequestBody<BidPriceRound>();
			 requestBody.setEntity(bidPriceRound);
			 requestBody.setParam("tenderId", tenderId);
 			 if(null != supplierList){
				 StringBuilder supplierIds = new StringBuilder();
				 for(Supplier supplier : supplierList){
					 if(supplierIds.length() > 0){
						 supplierIds.append(",");
					 }
					 supplierIds.append(supplier.getId());
				 }
				 requestBody.setParam("supplierIds", supplierIds.toString());
			 }
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	
	
	
	
	/**
	 * @Description: 
	 * @author guoyr
	 * @param tenderId
	 * @param round
	 * @return 
	 */
	@Deprecated
	public BidPriceRound getBidPriceRoundByIndex(String tenderId, int round){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBidPriceRoundByIndex");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("roundNo", round);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, BidPriceRound.class);			
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	public List<BidPriceRound> getBidPriceRoundList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBidPriceRoundList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, BidPriceRound.class);			
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	 
	public boolean updateAssignProperty(BidPriceRound bidPriceRound ,String [] attributes){
		BidPriceRound tempBidPriceRound = null;
		try {
			WebReflecUtill<BidPriceRound> utill = new WebReflecUtill<BidPriceRound>();
			tempBidPriceRound =  (BidPriceRound) utill.reflex(bidPriceRound, attributes,BidPriceRound.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != tempBidPriceRound){
 			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tempBidPriceRound));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	} 
	
	public boolean completeCurrentRound(BidPriceRound bidPriceRound) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/completeCurrentRound");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(bidPriceRound));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
 	}
	
	
//	public static void main(String[] args) {
//		ReBidPriceRoundService reBidPriceRoundService = new ReBidPriceRoundService();
//		BidPriceRound bidPriceRound = new BidPriceRound();
//		bidPriceRound.setId(IDUtils.getId());
//		bidPriceRound.setRoundEndTime(new Date());
//		bidPriceRound.setRoundNo(2);
//		bidPriceRound.setRoundMemo("ceshi");
//		bidPriceRound.setRoundStatus("01");
//		bidPriceRound.setTenderId("75742aa8b1434cf69589bd56a8ea2c8e");
//		bidPriceRound.setRoundName("roundName");
//
//		String tenderId = "75742aa8b1434cf69589bd56a8ea2c8e";
//		
//		List<Supplier> supplierList = new ArrayList<Supplier>();
//		Supplier Supplier1 = new Supplier();
//		Supplier1.setId("2eda73658fa44fae8ed6e94b8dc12998");
//		Supplier1.setAddress("asefasdf");
//		Supplier1.setSupplierName("投标人10");
//		Supplier1.setOrgCode("123456789876");
//		Supplier1.setTenderId("75742aa8b1434cf69589bd56a8ea2c8e");
//		Supplier1.setLinker("1");
//		Supplier1.setLinkerTel("13333333333");
//		Supplier1.setZipcode("111111");
//		Supplier1.setApplyUrl("测试--大唐东营2×1000MW新建工程项目");
//		supplierList.add(Supplier1);
//		
//		Supplier Supplier2 = new Supplier();
//		Supplier2.setId("f19a7aa0f5b942d29d690bd85d349e35");
//		Supplier2.setAddress("asefasdf");
//		Supplier2.setSupplierName("投标人5");
//		Supplier2.setOrgCode("123456789876");
//		Supplier2.setTenderId("75742aa8b1434cf69589bd56a8ea2c8e");
//		Supplier2.setLinker("1");
//		Supplier2.setLinkerTel("13333333333");
//		Supplier2.setZipcode("111111");
//		Supplier2.setApplyUrl("测试--大唐东营2×1000MW新建工程项目");
//		supplierList.add(Supplier2);
//		
//		Supplier Supplier3 = new Supplier();
//		Supplier3.setId("f5e72bf468c54db6a34f657a01d72c31");
//		Supplier3.setAddress("asefasdf");
//		Supplier3.setSupplierName("投标人14");
//		Supplier3.setOrgCode("123456789876");
//		Supplier3.setTenderId("75742aa8b1434cf69589bd56a8ea2c8e");
//		Supplier3.setLinker("1");
//		Supplier3.setLinkerTel("13333333333");
//		Supplier3.setZipcode("111111");
//		Supplier3.setApplyUrl("测试--大唐东营2×1000MW新建工程项目");
//		supplierList.add(Supplier3);
//		
//		reBidPriceRoundService.insertNewBidpriceRound(bidPriceRound, tenderId, supplierList);
//	}
}
