package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.RevokeRecord;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class RevokeRecordService {
	
	static final String URL = "revokeRecord";
	
	private Logger logger = Logger.getLogger(RevokeRecordService.class);
	/**
	 * @Description: 是否发起项目废标
	 * @author mazc
	 * @param tenderId 项目ID
	 * @param revokeType 废标状态(01：废标；02：取消废标)
	 * @return boolean
	 */
	public boolean isStartRevoke(String tenderId, String revokeType){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isStartRevoke");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("revokeType", revokeType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 根据废标状态，获得废标记录集合。 
	 * @author mazc
	 * @param tenderId 项目ID
	 * @param revokeType 废标状态(01：废标；02：取消废标)
	 * @return List<RevokeRecord>
	 */
	public List<RevokeRecord> getRevokeRecordList(String tenderId, String revokeType){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getRevokeRecordList");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("revokeType", revokeType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, RevokeRecord.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据废标状态，删除废标记录。 
	 * @author mazc
	 * @param tenderId 项目ID
	 * @param revokeType 废标状态(01：废标；02：取消废标)
	 * @return int
	 */
	public int delRevokeRecord(String tenderId, String revokeType){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/delRevokeRecord");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("revokeType", revokeType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
}
