package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.auth.AuthRole;
import com.gx.obe.web.utils.ResultStatus;

/**  
 * @Title:  RoleService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    角色管理  
 * @author: XiaoMaPro     
 * @date:   Apr 29, 2019 6:32:26 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class RoleService {
	
	static final String URL = "authRole";
	
	private Logger logger = Logger.getLogger(RoleService.class);

	 /**   
	 * @Title: getRoleListByRoleCode   
	 * @Description: 获得指定编号的角色列表
	 * @param: @return      
	 * @return: List<AuthRole>      
	 * @throws   
	 */  
	public List<AuthRole> getRoleListByRoleCode(String[] ROLE_CODE) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getRoleListByRoleCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("ROLE_CODE", ROLE_CODE );
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.strToList(result, AuthRole.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description:  保存或更新
	 * @author mazc
	 * @return 
	 */
	public AuthRole saveOrUpdateNoEmptyReturn(AuthRole authRole){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(authRole));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.jsonToBean(result, AuthRole.class);	 
 			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
		return null;
	}
	
	/**
	 * @Description: 根据角色类型获取角色列表 
	 * @author mazc
	 * @param roleType
	 * @return 
	 */
	public List<AuthRole> getRoleListByRoleType(String roleType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getRoleListByRoleType");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roleType", roleType );
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.strToList(result, AuthRole.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description:  根据加色名字查找角色列表
	 * @author mazc
	 * @param roleName
	 * @return 
	 */
	public List<AuthRole> getQueryRoleListByRoleName(String roleName){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getQueryRoleListByRoleName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roleName", roleName );
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.strToList(result, AuthRole.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 通过id删除角色
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public boolean deleteRole(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id );
		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description:  根据角色状态获取列表
	 * @author mazc
	 * @param roleName
	 * @return 
	 */
	public List<AuthRole> getRoleListByuseStatus(String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getRoleListByuseStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("useStatus", useStatus );
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.jsonToList(result, AuthRole.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 修改角色状态
	 * @author mazc
	 * @param useStatus
	 * @param roleId
	 * @return 
	 */
	public boolean updateRoleuseStatus(String useStatus,String roleId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateRoleuseStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("useStatus", useStatus );
		param.put("roleId", roleId );
		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
}
