package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.Struct;
import com.gx.obe.web.utils.ResultStatus;

public class StructService {
	
	static final String URL = "struct";
	
	private Logger logger = Logger.getLogger(StructService.class);
	
	
	/**
	 * @Description: 根据供应商id和指标id获取结构化数据列表
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param factorId
	 * @return 
	 */
	public List<Struct> getStructBySupplierIdAndFactorIdList(String tenderId, String supplierId, String factorId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getStructBySupplierIdAndFactorIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
		param.put("supplierId", supplierId );
		param.put("factorId", factorId );
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Struct.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	public int batchSave(List<Struct>  list){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);				
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	/**
	 * @Description:  根据id更新指定字段
	 * @author mazc
	 * @param Struct
	 * @param strs
	 * @return 
	 */
	public boolean updateAssignProperty(Struct struct, String[] strs) {
		Struct structTemp = null;
		try {
			WebReflecUtill<Struct> utill = new WebReflecUtill<Struct>();
			structTemp = (Struct) utill.reflex(struct, strs,Struct.class);
		} catch (Exception e) {
			return false;
		}			
		if(null != structTemp){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(structTemp));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
}
