package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.Supervise;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class SuperviseService {
	
	static final String URL = "supervise";
	
	private Logger logger = Logger.getLogger(SuperviseService.class);
	
	
	/**
	 * @Description: 查询监督人列表
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<Supervise> getSuperviseList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSuperviseList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
	 
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Supervise.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 删除监督人
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return 
	 */
	public boolean deleteSupervise(String tenderId, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteSupervise");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	 
	public boolean insert(Supervise supervise){
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supervise));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public List<Object> getSuperviseIdByTenderIdOrUserId(String tenderId,String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSuperviseIdByTenderIdOrUserId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
		if(StringUtils.isNotEmpty(userId)){
			param.put("userId", userId);
		}
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	 /**   
	 * @Title: batchCreateSave   
	 * @Description: 批量添加
	 * @param: @param userRoleList      
	 * @return: void      
	 * @throws   
	 */  
	public int batchSave(List<Supervise> list){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			 if(ResultStatus.isReultStatusInteger(result)){	
				 return Integer.valueOf(result);
			 }
			 return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
}
