package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.SupplierEvaluationFactor;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchSaveOrUpdateVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/** 
 * @Description: 供应商评审指标服务
 * @author mazc 
 */
public class SupplierEvaluationFactorService {
	
	static final String URL = "supplierEvaluationFactor";
	
	private Logger logger = Logger.getLogger(SupplierEvaluationFactorService.class);
	
	/**
	 * @Description: 获得已评审的结果
	 * @author mazc
	 * @param factorCode
	 * @param supplierId
	 * @return 
	 */
	public List<SupplierEvaluationFactor> getSupplierEvaluationFactorByFactorCodeAndSupplierId(String factorCode , String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getByFactorCodeAndSupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("factorCode", factorCode );
		param.put("supplierId", supplierId );
		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.jsonToList(result, SupplierEvaluationFactor.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param supplierEvaluationFactorList
	 * @param strings 
	 * @return 
	 */
	public int batchSaveOrUpdate(List<SupplierEvaluationFactor> supplierEvaluationFactorList, String... attributes){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSaveOrUpdate");
		BatchSaveOrUpdateVo<SupplierEvaluationFactor> batchSaveOrUpdateVo = new BatchSaveOrUpdateVo<SupplierEvaluationFactor>();
		batchSaveOrUpdateVo.setEntityList(supplierEvaluationFactorList);
		batchSaveOrUpdateVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchSaveOrUpdateVo));
			if(ResultStatus.isReultStatusInteger(result)){	
 				return Integer.valueOf(result);
 			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	public boolean insert(SupplierEvaluationFactor supplierEvaluationFactor){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplierEvaluationFactor));
			if(ResultStatus.isReultStatusInteger(result)){	
 				return ResultStatus.getReultStatusBoolean(result);
 			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}

    /**
     * @Description: 指定字段修改
     * @author chenxw
     * @param supplierEvaluationFactor
     * @param attributes
     * @return 
     */
    public boolean updateAssignProperty(SupplierEvaluationFactor supplierEvaluationFactor, String[] attributes) {
        //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
        UpdateAssignPropertyVo<SupplierEvaluationFactor> updateAssignPropertyVo = new UpdateAssignPropertyVo<SupplierEvaluationFactor>();
        updateAssignPropertyVo.setEntity(supplierEvaluationFactor);
        updateAssignPropertyVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            if (ResultStatus.getReultStatusBoolean(result)) {
                return true;
            }
            return false;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
	
	/**
	 * @Description: 通过tenderId 获取
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<SupplierEvaluationFactor> getEntityListByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEntityListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
 		try {
 			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
 				return JsonUtil.jsonToList(result, SupplierEvaluationFactor.class);	 
 			}
 			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: id批量更新
	 * @author mazc
	 * @param tenderProjectList
	 * @param attributes
	 * @return 
	 */
	public int batchUpdateProperty(List<SupplierEvaluationFactor> supplierEvaluationFactorList, String[] attributes){
		List<SupplierEvaluationFactor>  newTenderProjectList;
		if(null != attributes && attributes.length > 0){
			newTenderProjectList  = new ArrayList<SupplierEvaluationFactor>();
			for(SupplierEvaluationFactor supplierEvaluationFactor : supplierEvaluationFactorList){
				WebReflecUtill<SupplierEvaluationFactor> utill = new WebReflecUtill<SupplierEvaluationFactor>();
				SupplierEvaluationFactor ruleEntity =  (SupplierEvaluationFactor) utill.reflex(supplierEvaluationFactor, attributes,SupplierEvaluationFactor.class);
				if(null != ruleEntity){
					newTenderProjectList.add(ruleEntity);
				}
			}
 		}else{
 			newTenderProjectList = supplierEvaluationFactorList;
		}	
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSaveOrUpdate");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(newTenderProjectList));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	/**
	 * @Description: 通过TenderId 删除
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public int deleteByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId );
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	public int batchSave(List<SupplierEvaluationFactor> supplierEvaluationFactorList ){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplierEvaluationFactorList));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
}
