package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.web.entity.SupplierEvaluationResult;
import com.gx.obe.web.utils.ResultStatus;

public class SupplierEvaluationResultService {
	static final String URL = "supplierEvaluationResult";
	private Logger logger = Logger.getLogger(SupplierEvaluationResultService.class);
	
	/**
	 * @Description: 申请编辑供应商的评审意见
	 * @author wangxiang
	 * @param applyUserId
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public boolean applyEditSupplierEvaluationResult(String tenderId, String supplierId, String applyUserId, String opinionEditor){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/applyEditSupplierEvaluationResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("applyUserId", applyUserId);
		param.put("opinionEditor", opinionEditor);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return Integer.valueOf(result) > 0 ;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 统计初审通过（不通过）的供应商数量
	 * @author wangxaing
	 * @param tenderId
	 * @param type
	 * @return
	 */
	public Integer getSupplierQualifiedCount(String tenderId, String accessment){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierQualifiedCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("accessment", accessment);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return Integer.valueOf(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}
	
	/**
	 * @Description: 释放编辑供应商评审意见权限
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @param applyUserId
	 * @return 
	 */
	public boolean releaseEditSupplierEvaluationResult(String tenderId, String supplierId, String applyUserId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/releaseEditSupplierEvaluationResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("applyUserId", applyUserId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存供应商的评审意见
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @param biddingRequest
	 * @param evaluationOpinion
	 * @return 
	 */
	public boolean saveSupplierEvaluationOpinion(boolean isSubmit, String tenderId, String supplierId, String biddingRequest, String evaluationOpinion,String vetoType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveSupplierEvaluationOpinion");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("isSubmit", isSubmit);
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("biddingRequest", biddingRequest);
		param.put("evaluationOpinion", evaluationOpinion);
		param.put("vetoType", vetoType);
		try{
			String result = NetworkRequest.post(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 修改供应商的废标状态
	 * @author wangxiang
	 * @param tenderId
	 * @param stepIndex 
	 */
	public boolean updateSupplierEvaluationAccessmentStatus(String tenderId, int stepIndex){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateSupplierEvaluationAccessmentStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepIndex", stepIndex);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean saveOrUpdate(SupplierEvaluationResult supplierEvaluationResult){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplierEvaluationResult));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	/**
	 * @Description: id批量更新
	 * @author mazc
 	 * @param attributes
	 * @return 
	 */
	public int batchUpdateProperty(List<SupplierEvaluationResult> supplierEvaluationResultList, String[] attributes){
		List<SupplierEvaluationResult>  newSupplierEvaluationResultList;
		if(null != attributes && attributes.length > 0){
			newSupplierEvaluationResultList  = new ArrayList<SupplierEvaluationResult>();
			for(SupplierEvaluationResult supplierEvaluationResult : supplierEvaluationResultList){
				WebReflecUtill<SupplierEvaluationResult> utill = new WebReflecUtill<SupplierEvaluationResult>();
				SupplierEvaluationResult ruleEntity =  (SupplierEvaluationResult) utill.reflex(supplierEvaluationResult, attributes,SupplierEvaluationResult.class);
				if(null != ruleEntity){
					newSupplierEvaluationResultList.add(ruleEntity);
				}
			}
 		}else{
 			newSupplierEvaluationResultList = supplierEvaluationResultList;
		}	
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(newSupplierEvaluationResultList));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	
	public SupplierEvaluationResult getSupplierEvaluationResultByTenderIdAndSupplierId(String tenderId,String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierEvaluationResultByTenderIdAndSupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, SupplierEvaluationResult.class);
			}
			return null;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	
	public SupplierEvaluationResult getSupplierEvaluationResultBySupplierId( String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierEvaluationResultBySupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, SupplierEvaluationResult.class);
			}
			return null;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public List<SupplierEvaluationResult> getSupplierEvaluationResultListByTenderId( String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierEvaluationResultListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierEvaluationResult.class);
			}
			return null;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<SupplierEvaluationResult> getSupplierEvaluationResultListByTenderIdAndAccessment( String tenderId ,String accessment){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierEvaluationResultListByTenderIdAndAccessment");
		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("tenderId", tenderId);
 		param.put("accessment", accessment);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierEvaluationResult.class);
			}
			return null;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public List<SupplierEvaluationResult> getSupplierEvaluationResultListTenderIdAndeSortNo( String tenderId ,int sortNo){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierEvaluationResultListTenderIdAndeSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("tenderId", tenderId);
 		param.put("sortNo", sortNo);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierEvaluationResult.class);
			}
			return null;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
}
