package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.SupplierOpeningResult;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchSaveOrUpdateVo;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

public class SupplierOpeningResultService {
	static final String URL = "supplierOpeningResult";
	private Logger logger = Logger.getLogger(SupplierOpeningResultService.class);
	
    public int batchUpdateProperty(List<SupplierOpeningResult> supplierOpeningResultList, String[] attributes) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
        BatchUpdatePropertyVo<SupplierOpeningResult> batchUpdatePropertyVo = new BatchUpdatePropertyVo<SupplierOpeningResult>();
        batchUpdatePropertyVo.setEntityList(supplierOpeningResultList);
        batchUpdatePropertyVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchUpdatePropertyVo));
            return Integer.valueOf(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }

	/**
	 * @Description: 批量更新或保存
	 * @author wangxiang
	 * @param supplierOpeningResultList
	 * @param attributes 
	 */
    public Integer batchSaveOrUpdate(List<SupplierOpeningResult> supplierOpeningResultList, String[] attributes) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSaveOrUpdate");
        BatchSaveOrUpdateVo<SupplierOpeningResult> batchSaveOrUpdateVo = new BatchSaveOrUpdateVo<SupplierOpeningResult>();
        batchSaveOrUpdateVo.setEntityList(supplierOpeningResultList);
        batchSaveOrUpdateVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchSaveOrUpdateVo));
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            return 0;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return 0;
        }
    }

	/**
	 * @Description: 获取投标人开标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public SupplierOpeningResult getSupplierOpeningResult(String tenderId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, SupplierOpeningResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param openbidResult
	 * @param strings
	 * @return 
	 */
    public boolean updateAssignProperty(SupplierOpeningResult openbidResult, String[] attributes) {
        //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
        UpdateAssignPropertyVo<SupplierOpeningResult> updateAssignPropertyVo = new UpdateAssignPropertyVo<SupplierOpeningResult>();
        updateAssignPropertyVo.setEntity(openbidResult);
        updateAssignPropertyVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }

	/**
	 * @Description: 保存或者更新后返回
	 * @author wangxiang
	 * @param supplierOpeningResult
	 * @return 
	 */
	public SupplierOpeningResult saveOrUpdateReturn(SupplierOpeningResult supplierOpeningResult) {
		if(null != supplierOpeningResult){
			String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplierOpeningResult));
				if(ResultStatus.getReultStatusBoolean(result)){
					return supplierOpeningResult;
				}else{
					return null;
				}
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return null;
			}
		}else{
			return null;
		}
	}
	
	/**
	 * @Description: 查询或获取供应商开标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public SupplierOpeningResult queryOrCreateSupplierOpeningResult(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/queryOrCreateSupplierOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, SupplierOpeningResult.class);
			}else{
				return null;
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 获得开标结果主键
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public String getSupplierOpeningResultId(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierOpeningResultId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return JsonUtil.jsonObjectToStr(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 删除供应商开标结果
	 * @author wangxiang
	 * @param tenderId 
	 */
	public boolean deleteSupplierBidOpeningResult(String tenderId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteSupplierBidOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 修改供应商的总价
	 * @author wangxiang
	 * @param tenderId
	 * @param bidPrice
	 * @param evalPrice 
	 */
	public Integer updateSupplierSumPrice(String tenderId, boolean bidPrice, boolean evalPrice){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateSupplierSumPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidPrice", bidPrice);
		param.put("evalPrice", evalPrice);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return Integer.valueOf(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}
	
	
	public Integer updateSupplierSumPriceAndSupplierId(String tenderId, String supplierId, boolean bidPrice, boolean evalPrice){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateSupplierSumPriceAndSupplierId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("bidPrice", bidPrice);
		param.put("evalPrice", evalPrice);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return Integer.valueOf(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}
	
	/**
	 * @Description: 获取开标结果列表
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	public List<SupplierOpeningResult> getSupplierOpeningResultList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierOpeningResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierOpeningResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	public boolean insert(SupplierOpeningResult supplierOpeningResult){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplierOpeningResult));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
 
	/**
	 * @Description: 
	 * @author mazc
	 * @param 
	 * @return 
	 */
	public SupplierOpeningResult saveOrUpdateNoEmptyReturn(SupplierOpeningResult supplierOpeningResult){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateNoEmptyReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl ,JsonUtil.jsonObjectToStr(supplierOpeningResult));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, SupplierOpeningResult.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<SupplierOpeningResult> getSupplierOpeningResultListByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierOpeningResultListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierOpeningResult.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<SupplierOpeningResult> getSupplierOpeningResultListByTenderIdAndBidOpeningStatus(String tenderId, String bidOpeningStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSupplierOpeningResultListByTenderIdAndBidOpeningStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidOpeningStatus", bidOpeningStatus);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SupplierOpeningResult.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
