package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchSaveOrUpdateVo;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.EvaluationSupplierVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;
import com.gx.utils.NowTimeUtils;

/**
 * @Description:供应商服务数据接口
 * @author mazc
 */
public class SupplierService {

	static final String URL = "supplier";
	private Logger logger = Logger.getLogger(SupplierService.class);

	/**
	 * @Description: 获得要开标的所有投标人列表，包括开标结果
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getSupplierOpenBidList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierListWithOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 查询项目或标段下的投标人
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getSupplierList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 查询项目或标段下的投标人
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getSupplierByStatusList(String tenderId, String status) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierByStatusList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("status", status);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 查询项目或标段下的投标人
	 * @author chenxw
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getAllSupplierList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param supplierList
	 * @param attributes   要跟新的字段
	 */
	public Integer batchSaveOrUpdate(List<Supplier> supplierList, String[] attributes) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSaveOrUpdate");
		BatchSaveOrUpdateVo<Supplier> batchSaveOrUpdateVo = new BatchSaveOrUpdateVo<Supplier>();
		batchSaveOrUpdateVo.setEntityList(supplierList);
		batchSaveOrUpdateVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchSaveOrUpdateVo));
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("batchSaveOrUpdate");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 * @param supplierList
	 * @param attributes
	 * @return
	 */
	public int batchUpdateProperty(List<Supplier> supplierList, String[] attributes) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
		BatchUpdatePropertyVo<Supplier> batchUpdatePropertyVo = new BatchUpdatePropertyVo<Supplier>();
		batchUpdatePropertyVo.setEntityList(supplierList);
		batchUpdatePropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchUpdatePropertyVo));
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("batchSaveOrUpdate");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 获得开标成功的投标人列表
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getOpenBidSuccessSupplier(String tenderId) {
		return getOpenBidSuccessSupplier(tenderId, null);
	}

	/**
	 * @Description: 获得开标成功的投标人列表（区分明暗标）
	 * @author wangxiang
	 * @param tenderId
	 * @param bidFileType
	 * @return
	 */
	public List<Supplier> getOpenBidSuccessSupplier(String tenderId, String bidFileType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getOpeningSuccessSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidFileType", bidFileType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 按照签到顺序排序
	 * @author wangxiang
	 * @param id
	 * @param b
	 */
	public boolean sortSupplierBySignTime(String tenderProjectId, boolean order) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/sortSupplierBySignTime");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderProjectId", tenderProjectId);
		param.put("order", order);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 批量删除供应商
	 * @author wangxiang
	 * @param supplierList
	 * @return
	 */
	public boolean batchDeleteSupplierList(List<Supplier> supplierList) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchDeleteSupplierList");
		try {
			List<String> supplierIdList = new ArrayList<String>();
			for (Supplier supplier : supplierList) {
				supplierIdList.add(supplier.getId());
			}
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("supplierIdList", supplierIdList);
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

	/**
	 * @Description: 批量删除供应商
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public boolean deleteAllSupplierByTenderId(String tenderId) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteAllSupplierByTenderId");
		try {
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("tenderId", tenderId);
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

	/**
	 * @Description: 删除指定供应商
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 */
	public boolean removeSupplier(String tenderId, String supplierId) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/delete");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 获得所有未投标的投标人
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getAllUnTenderSupplierList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllUnTenderSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param supplier
	 * @param attributes
	 * @return
	 */
	public boolean updateAssignProperty(Supplier supplier, String[] attributes) {
		// 登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<Supplier> updateAssignPropertyVo = new UpdateAssignPropertyVo<Supplier>();
		updateAssignPropertyVo.setEntity(supplier);
		updateAssignPropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 验证供应商属性是否唯一
	 * @author wangxiang
	 * @param tenderId    项目
	 * @param supplierId  主键
	 * @param column      数据库字段
	 * @param columnValue 字段值
	 * @return
	 */
	public boolean isUniqueSupplier(String tenderId, String supplierId, String column, String columnValue) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueSupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("column", column);
		param.put("columnValue", columnValue);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 获得指定评标步骤下的供应商列表
	 * @author wangxiang
	 * @param tenderId
	 * @param stepIndex
	 * @return
	 */
	public List<Supplier> getEvaluationStepSupplierList(String tenderId, EvaluationStep evaluationStep) {
		List<Supplier> supplierList = null;
		EvaluationSupplierVo evaluationSupplierVo = new EvaluationSupplierVo(tenderId, evaluationStep);
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepSupplierList");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationSupplierVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				supplierList = JsonUtil.jsonToList(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		} finally {
			if (null == supplierList) {
				supplierList = new ArrayList<Supplier>();
			}
		}
		return supplierList;
	}

	/**
	 * @Description: 获得投标人的开标结果和评标结果
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public List<Supplier> getSupplierOpenbidAndEvaluateResultList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierListWithOpeningEvaluationResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得投标人的最大序号
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int getMaxSupplierSortNo(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxSupplierSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("getMaxSupplierSortNo");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 获得指定步骤评审不通过的投标人
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId   指定的评标步骤
	 * @return
	 */
	public List<Supplier> getDisAccessmentSupplier(String tenderId, String stepId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getDisAccessmentSupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 *   通过轮次id 获取供应商列表
	 * @param roundId
	 * @return
	 */
	public List<Supplier> getPrivceRoundSupplierList(String roundId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getPrivceRoundSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roundId", roundId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	

	/**
	 * @Description: 根据项目Id，获得项目下所有分包的投标人集合(去重复)
	 * @author wangxiang
	 * @param tenderParentId 项目Id
	 * @return List<Supplier>
	 */
	public List<Supplier> getSupplierListByTenderProject(String tenderParentId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierListByParentProjectId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderParentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 模糊查询投标人名称或编码，获得项目下的投标人列表。
	 * @author wangxiang
	 * @param tenderId 项目ID
	 * @param content  查询条件(投标人名称和编码)
	 * @return List<Supplier>
	 */
	public List<Supplier> getSupplierListByName(String tenderId, String content) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierListByName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("content", content);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 根据父项目id查询所有包件下的投标人信息
	 * @author wangxiang
	 * @param parentId
	 * @return
	 */
	public List<Map<String, Object>> getparentSupplierByParentTenderId(String parentId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getParentProjectSupplieList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", parentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToListMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 保存下载供应商信息
	 * @author wangxiang
	 * @param supplier
	 * @return
	 */
	public boolean saveDownLoadSupplier(Supplier supplier) {
		if (null != supplier.getId() && !"".equals(supplier.getId())) {
			supplier.setModifyTime(NowTimeUtils.getNowDate());// 设置更新时间
			return saveOrUpdate(supplier) > 0;
		} else {
			supplier.setId(UuidUtils.getUUID());
			supplier.setCreateTime(NowTimeUtils.getNowDate());// 添加创建时间
			return insert(supplier) > 0;
		}
	}

	/**
	 * @Description: 修改或者更新
	 * @author wangxiang
	 * @param supplier
	 * @return
	 */
	public int saveOrUpdate(Supplier supplier) {
		// 获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplier));
			if (result.trim().equals("true")) {
				return 1;
			}
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 插入
	 * @author wangxiang
	 * @param supplier
	 * @return
	 */
	private int insert(Supplier supplier) {
		// 获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(supplier));
			if (result.trim().equals("true")) {
				return 1;
			}
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 获得报名供应商的个数
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int getSupplierCount(String tenderId) {
		// 获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("getSupplierCount");
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 获得未废标且已签到的供应商家数
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int getSupplierSignCount(String tenderId) {
		// 获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierSignCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("getSupplierSignCount");
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 获得推荐的供应商列表
	 * @author wangxiang
	 * @param tenderId
	 * @param stepIndex
	 * @return
	 */
	public List<Supplier> getRecommendSupplierList(String tenderId, int stepIndex) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getRecommendSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepIndex", stepIndex);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 初始化供应商开标结果
	 * @author wangxiang
	 * @param tenderId
	 */
	public void initSupplierBidOpeningResult(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/initSupplierBidOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			NetworkRequest.get(strWebServerUrl, param);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return;
		}
	}

	/**
	 * @Description: 通过项目id查找项目下所有包件中资审为通过供应商数量
	 * @author wangxiang
	 * @param tenderParentId
	 * @param type           [01：通过；02：不通过]
	 * @return
	 */
	public List<Supplier> getComplianceFailSupplierCount(String tenderParentId, String accessment) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getComplianceFailSupplierCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderParentId", tenderParentId);
		param.put("accessment", accessment);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得整个项目下开标成功的投标人列表
	 * @author wangxiang
	 * @param tenderParentId
	 * @return
	 */
	public List<Supplier> getOpenBidSuccessByParentId(String tenderParentId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getOpenBidSuccessByParentId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderParentId", tenderParentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得项目所有有效的投标人列表
	 * @author wangxiang
	 * @param tenderParentId
	 * @return
	 */
	@Deprecated
	public List<Supplier> getAllSupplierListByParentId(String tenderParentId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getParentProjectSupplieList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderParentId", tenderParentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Supplier.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得供应商开标信息
	 * @author wangxaing
	 * @param tenderId
	 * @return
	 */
	public List<Map<String, Object>> getSupplierBidOpeningInfoList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierBidOpeningInfoList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToListMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 根据包件id查询该包件下，供应商投标人数
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int getBidSupplierCount(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBidSupplierCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("getBidSupplierCount");
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 根据包件id查询该包件下，供应商投标人数
	 * @author wangxiang
	 * @param tenderId
	 * @param economicsFlag
	 * @return
	 */
	public int getSupplierBusinessDecryptCount(String tenderId, boolean economicsFlag) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierBusinessDecryptCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("priceBidStatus", economicsFlag);
		try {
			String result = NetworkRequest.post(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("getSupplierBusinessDecryptCount");
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}

	/**
	 * @Description: 根据主键查找
	 * @author wangxiang
	 * @param id
	 * @return
	 */
	public Supplier getById(String id) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 批量修改
	 * @author chenxw
	 * @param existSupplierList
	 * @return
	 */
	public int batchUpdate(List<Supplier> existSupplierList) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(existSupplierList));
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("batchSaveOrUpdate");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 批量插入
	 * @author chenxw
	 * @param newSupplierList
	 * @return
	 */
	public int batchSave(List<Supplier> newSupplierList) {
		// 请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(newSupplierList));
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("batchSaveOrUpdate");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 验证投标人名称是否唯一
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @param supplierName
	 * @return
	 */
	public boolean isUniqueSupplierByName(String tenderId, String supplierId, String supplierName) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueSupplierByName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("supplierName", supplierName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 根据项目ID orgCode 查询
	 * @author wangxiang
	 * @param tenderId
	 * @param orgCode
	 * @return
	 */
	public Supplier getSupplierByOrgCode(String tenderId, String orgCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierByOrgCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("orgCode", orgCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, Supplier.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 返回id orgcode集合
	 * @author wangxiang
	 * @param id
	 * @param strings
	 * @return
	 */
	public List<Map<String, Object>> getAllSupplierToMap(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToListMap(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	public List<Map<String, Object>> queryToMap(String tenderId, boolean hasParent) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/queryToMap");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("hasParent", hasParent);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToListMap(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 返回商务标开标成功数量
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int queryBidOpenSuccessCount(String tenderId, String bidType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/queryBidOpenSuccessCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidType", bidType);
		try {
			String result = NetworkRequest.post(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("queryBidOpenSuccessCount");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 返回经济标开标成功数量
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	public int queryPriceBidStatusOpenSuccessCount(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/queryPriceBidStatusOpenSuccessCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, param);
			if (ResultStatus.isReultStatusInteger(result)) {
				return Integer.valueOf(result);
			}
			logger.error("queryPriceBidStatusOpenSuccessCount");
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
}

class SupplierComparator implements Comparator<Supplier> {

	public int compare(Supplier supplier1, Supplier supplier2) {
		if (null == supplier1.getSealedBidCode() || null == supplier2.getSealedBidCode()) {
			return 0;
		}
		int comp = supplier1.getSealedBidCode().compareToIgnoreCase(supplier2.getSealedBidCode());
		if (comp < 0) {
			return -1;
		} else if (comp > 0) {
			return 1;
		}
		return 0;
	}
}
