package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.SysConfig;
import com.gx.obe.web.entity.SysConfigValue;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;

/**
 * @Description:
 * @author mazc
 */
public class SysConfigService {
	static final String URL = "sysConfig";
	
	private Logger logger = Logger.getLogger(SysConfigService.class);
	
	
	/**
	 * @Description: 根据编码，获得数据字典对象。
	 * @author mazc
	 * @param configCode
	 * @return
	 */
	public SysConfig getSysConfigByCode(String configCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getConfigByCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configCode", configCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToBean(result, SysConfig.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
	}
	
	/**
	 * @Description: 根据字典编码，获得有效字典值集合。
	 * @author guoyr
	 * @param configCode 字典编码
	 * @return List<SysConfigValue>
	 */
	public List<SysConfigValue> getConfigValueListByConfigCode(String configCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getConfigValueListByConfigCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configCode", configCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, SysConfigValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
