package com.gx.obe.web.service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.DateUtils;
import com.gx.obe.web.entity.SysConfigValue;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/** 
 * @Description: 
 * @author mazc 
 */
public class SysConfigValueService {
	
	static final String URL = "sysConfigValue";
	
	private Logger logger = Logger.getLogger(SysConfigValueService.class);
	
	/**
	 * @Description: 根据字典编号获得系统配置列表
	 * @author wangxiang
	 * @param configCode
	 * @return 
	 */
	public List<SysConfigValue> getConfigValueListByConfigCode(String configCode){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getConfigValueListByConfigCode");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configCode", configCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){
				return JsonUtil.jsonToList(result, SysConfigValue.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 验证字典值名称唯一性
	 * @author mazc
	 * @param id
	 * @param configValueCode
	 * @return boolean true：是唯一；false:不是唯一
	 */
	public boolean isUniqueConfigValueCode(String configId, String id, String configValueCode){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isUniqueConfigValueCode");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configId", configId);
		param.put("id", id);
		param.put("configValueCode", configValueCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);		
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;		
		}
	}
	
	/**
	 * @Description: 获得系统配置的最大序号
	 * @author mazc
	 * @return
	 */
	public int getMaxConfigValueSortNo(String configId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxConfigValueSortNo");
		try {
			Map<String, Object> param = new HashMap<String, Object>();
			param.put("configId", configId);
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;		
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;		
		}
	}
	/**
	 * @Description: 获得系统配置的最晚修改时间
	 * @author mazc
	 * @return
	 */
	public Date getLatestModifyTime(String configCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getLatestModifyTime");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configCode", configCode);
		try {
			return DateUtils.toDate(NetworkRequest.get(strWebServerUrl, param));
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 交换系统配置的排序
	 * @author mazc
	 * @param sourceDictValue
	 * @param targetDictValue
	 */
	public boolean changeSysConfigValueSortNo(int sourceSortNo, String sourceid, int targetSortNo, String targetId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/changeSysConfigValueSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sourceSortNo", sourceSortNo);
		param.put("sourceId", sourceid);
		param.put("targetSortNo", targetSortNo);
		param.put("targetId", targetId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得字典ID下的字典值集合
	 * @author mazc
	 * @return List<SysConfigValue>
	 */
	public List<SysConfigValue> getConfigValueListByConfigId(String configId, String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getConfigValueListByConfigId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("configId", configId);
		param.put("useStatus", useStatus);
 
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, SysConfigValue.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean insert(SysConfigValue sysConfigValue){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(sysConfigValue));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	public boolean updateAssignProperty(SysConfigValue sysConfigValue ,String [] attributes){
		
		if(null != sysConfigValue){
			UpdateAssignPropertyVo<SysConfigValue> vo = new UpdateAssignPropertyVo<SysConfigValue>();
			vo.setEntity(sysConfigValue);
			vo.setAttributes(attributes);
 			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
}
