package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.Task;
import com.gx.obe.web.service.evaluation.EvaluationStepService;
import com.gx.obe.web.utils.ResultStatus;

public class TaskService {
	
	private static final String URL = "obeTask";
	
	private Logger logger = Logger.getLogger(EvaluationStepService.class);
	
	/**
	 * @Description: 插入
	 * @author chenxw
	 * @param evaluationStep
	 * @return
	 */
	public boolean insert(Task task) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(task));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 获取待办列表
	 * @author chenxw
	 * @param userId
	 * @return 
	 */
	public List<Task> getTaskList(String userId, String state) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTaskList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("state", state);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, Task.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return new ArrayList<>();
	}
	
	/**
	 * @Description: 获取代办数量
	 * @author chenxw
	 * @param userId
	 * @param state
	 * @return 
	 */
	public int getTaskCount(String userId, String state) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTaskCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("state", state);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return Integer.valueOf(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return 0;
	}

	/**
	 * @Description: 修改待办状态
	 * @author chenxw
	 * @param taskId
	 * @param state 
	 */
	public void updateTaskState(String taskId, String state) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateTaskState");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("taskId", taskId);
		param.put("state", state);
		try {
			NetworkRequest.get(strWebServerUrl, param);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}
	
}
