package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.TemplateLibraryFile;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class TemplateLibraryFileService {
	static final String URL = "templateFile";
	private Logger logger = Logger.getLogger(TemplateLibraryFileService.class);
	
	/**
	 * @Description: 根据模板库 组，查询当前组下的模板信息
	 * @author mazc
	 * @param groupId
	 * @return
	 */
	public List<TemplateLibraryFile> getTemplateLibraryFileListByGroupID(String groupId) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTemplateLibraryFileListByGroupID");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("groupId", groupId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TemplateLibraryFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据模板库组id，文件名称，查询模板信息
	 * @author mazc
	 * @param groupId
	 * @param templateLibraryFileName
	 * @return
	 */
	public List<TemplateLibraryFile> getTemplateLibraryFileByFileName(String groupId, String templateFileName) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTemplateLibraryFileByFileName");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("groupId", groupId);
		param.put("templateFileName", templateFileName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TemplateLibraryFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据模板库组id，删除当前组 下的所有模板
	 * @author mazc	
	 * @param groupId
	 * @return
	 */
	public int delTemplateLibraryFileByGroupId(String groupId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/delTemplateLibraryFileByGroupId");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("groupId", groupId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);	
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}

	/**
	 * @Description: 根据模板id删除模板
	 * @author mazc
	 * @param id
	 * @return
	 */
	public int deleteTemplateLibraryFileByObjId(String id){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteTemplateLibraryFileByObjId");
		//请求地址
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);	
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param 
	 * @return 
	 */
	public TemplateLibraryFile saveOrUpdateNoEmptyReturn(TemplateLibraryFile templateLibraryFile){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateNoEmptyReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl ,JsonUtil.jsonObjectToStr(templateLibraryFile));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TemplateLibraryFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
}
