package com.gx.obe.web.service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.enumeration.UserEnum;
import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.CommonEnum;
import com.gx.obe.config.ConfigConstants;
import com.gx.obe.config.utils.PropertiesUtils;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.DateUtils;
import com.gx.obe.web.entity.Page;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.Result.ResultEntity;
import com.gx.obe.web.entity.auth.AuthUser;
import com.gx.obe.web.entity.price.BidPrice;
import com.gx.obe.web.entity.tender.TenderProjectEntity;
import com.gx.obe.web.entity.tender.TenderProjectRuleEntity;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.ImportBidOpenResultVo;
import com.gx.obe.web.vo.SaveDownLoadProjectVo;
import com.gx.obe.web.vo.TenderPackOpeningInfo;
import com.gx.obe.web.vo.TenderPackPriceFactorVo;
import com.gx.obe.web.vo.TenderProjectVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/**  
 * @Title:  TenderProjectService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    项目管理服务接口  
 * @author: XiaoMaPro     
 * @date:   Apr 30, 2019 3:36:39 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class TenderProjectService {
	
	static final String URL = "tenderProject";
	
	private Logger logger = Logger.getLogger(TenderProjectService.class);
	 /**   
	 * @Description: 按分页查询项目
	 * @param: @param userId
	 * @param: @param useSatus
	 * @param: @param searchKey
	 * @param: @param startTime
	 * @param: @param endTime
	 * @param: @param pageNo
	 * @param: @param pageSize
	 * @param: @return      
	 * @return: Page<TenderProjectVo>      
	 * @throws   
	 */  
	@SuppressWarnings("unchecked")
	public Page<TenderProjectVo> getMyOpeningProjectPageList(String userId, String openingStatus, String searchKey, Date startTime, Date endTime ,int pageNo , int pageSize) {

		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getOpeningProjectPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		if(PropertiesUtils.getProperty(ConfigConstants.USE_OPENING_USER, "00").equals("01")) {
			param.put("userType", UserEnum.ROLE_TYPE_OPENING_MANAGER);
		}else {
			param.put("userType", UserEnum.ROLE_TYPE_EVALUATION_MANAGER);
		}
		param.put("openingStatus", openingStatus);
		param.put("searchKey", searchKey);			
		param.put("startTime", DateUtils.getTimestampFormat(startTime));
		param.put("endTime", DateUtils.getTimestampFormat(endTime));
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);

		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**   
	 * @Description: 按分页查询开标项目标段
	 * @param: @param userId
	 * @param: @param useSatus
	 * @param: @param searchKey
	 * @param: @param startTime
	 * @param: @param endTime
	 * @param: @param pageNo
	 * @param: @param pageSize
	 * @param: @return      
	 * @return: Page<TenderProjectVo>      
	 * @throws   
	 */  
	@SuppressWarnings("unchecked")
	public Page<TenderProjectVo> getOpeningTenderPackPageList(String parentId, String openingStatus, String searchKey, int pageNo , int pageSize) {
		
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getOpeningTenderPackPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		param.put("userType", Constants.USER.getUserType());
		param.put("openingStatus", openingStatus);
		param.put("searchKey", searchKey);			
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**   
	 * @Description: 按分页查询评标项目标段
	 * @param: @param userId
	 * @param: @param useSatus
	 * @param: @param searchKey
	 * @param: @param startTime
	 * @param: @param endTime
	 * @param: @param pageNo
	 * @param: @param pageSize
	 * @param: @return      
	 * @return: Page<TenderProjectVo>      
	 * @throws   
	 */  
	@SuppressWarnings("unchecked")
	public Page<TenderProjectVo> getEvaluatoinTenderPackPageList(String parentId, String evaluationStatus, String searchKey, int pageNo , int pageSize) {
		
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderPackPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		param.put("userType", Constants.USER.getUserType());
		param.put("openingStatus", CommonEnum.COMPLETE);
		param.put("evaluationStatus", evaluationStatus);
		param.put("searchKey", searchKey);			
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**   
	 * @Description: 按分页查询评标项目标段
	 * @param: @param userId
	 * @param: @param useSatus
	 * @param: @param searchKey
	 * @param: @param startTime
	 * @param: @param endTime
	 * @param: @param pageNo
	 * @param: @param pageSize
	 * @param: @return      
	 * @return: Page<TenderProjectVo>      
	 * @throws   
	 */  
	@SuppressWarnings("unchecked")
	public Page<TenderProjectVo> getTenderPackPageList(String parentId, String evaluationStatus, String searchKey, int pageNo , int pageSize) {
		
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderPackPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		param.put("userType", Constants.USER.getUserType());
		param.put("userId", Constants.USER.getId());
		param.put("evaluationStatus", evaluationStatus);
		param.put("searchKey", searchKey);			
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
		/**   
		 * @Description: 按分页查询项目
		 * @param: @param userId
		 * @param: @param useSatus
		 * @param: @param searchKey
		 * @param: @param startTime
		 * @param: @param endTime
		 * @param: @param pageNo
		 * @param: @param pageSize
		 * @param: @return      
		 * @return: Page<TenderProjectVo>      
		 * @throws   
		 */  
		@SuppressWarnings("unchecked")
		public Page<TenderProjectVo> getMyProjectPageList(String userId, String evaluationStatus, String searchKey, Date startTime, Date endTime ,int pageNo , int pageSize) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMyProjectPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("userType", Constants.USER.getUserType());
		param.put("evaluationStatus", evaluationStatus);
		param.put("searchKey", searchKey);			
		param.put("startTime", DateUtils.getTimestampFormat(startTime));
		param.put("endTime", DateUtils.getTimestampFormat(endTime));
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);

		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
 
	/**
	 * @Description: id批量更新
	 * @author mazc
	 * @param tenderProjectList
	 * @param attributes
	 * @return 
	 */
	public boolean batchUpdateProperty(List<TenderProjectEntity> tenderProjectList, String[] attributes){
//		List<TenderProjectEntity>  newTenderProjectList;
//		if(null != attributes && attributes.length > 0){
//			newTenderProjectList  = new ArrayList<TenderProjectEntity>();
//			for(TenderProjectEntity tenderProject : tenderProjectList){
//				WebReflecUtill<TenderProjectEntity> utill = new WebReflecUtill<TenderProjectEntity>();
//				TenderProjectEntity propertyEntity =  (TenderProjectEntity) utill.reflex(tenderProject, attributes,TenderProjectEntity.class);
//				if(null != propertyEntity){
//					newTenderProjectList.add(propertyEntity);
//				}
//			}
// 		}else{
// 			newTenderProjectList = tenderProjectList;
//		}	
//		//请求地址
//		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdate");
//		try{
//			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(newTenderProjectList));
//			if(ResultStatus.isReultStatusInteger(result)){	
//				return Integer.valueOf(result);
//			}
//			return 0;
//		} catch (Exception e) {
//			logger.error(e.getMessage(), e);
//			return 0;
//		}	
		
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
		BatchUpdatePropertyVo<TenderProjectEntity> vo = new  BatchUpdatePropertyVo<TenderProjectEntity>();
		vo.setAttributes(attributes);
		vo.setEntityList(tenderProjectList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
 		}
		return false;
	}
	
	/**
	 * @Description: 更新
	 * @author mazc
	 * @param tenderProjectList
	 * @param attributes
	 * @param column where 字段
	 * @return 
	 */
	public int updateByParendId(TenderProjectEntity tenderProjectList, String[] attributes,String parendId){
		WebReflecUtill<TenderProjectEntity> utill = new WebReflecUtill<TenderProjectEntity>();
		TenderProjectEntity ruleEntity =  (TenderProjectEntity) utill.reflex(tenderProjectList, attributes,TenderProjectEntity.class);		
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateByParendId");
		RequestBody<TenderProjectEntity> requestBody = new RequestBody<TenderProjectEntity>();
		requestBody.setEntity(ruleEntity);
		requestBody.setParam("parendId", parendId);
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	
	/**
	 * @Description: 获得分包项目
	 * @author mazc
	 * @param parentId
	 * @return 
	 */
	public List<TenderProjectEntity> getSubPackageList(String parentId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSubPackageList");

		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	 /**   
	 * @Description: 按分页查询监督人项目
	 * @param: @return      
	 * @return: Page<TenderProjectVo>      
	 * @throws   
	 */  
	@SuppressWarnings("unchecked")
	public Page<TenderProjectVo> getSuperviseProjectPageList(String userId, String evaluationStatus, String searchKey, Date startTime, Date endTime, int pageNo, int pageSize){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSuperviseProjectPageList");
		//请求参数
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("evaluationStatus", evaluationStatus);
		param.put("searchKey", searchKey);			
		param.put("startTime", DateUtils.getTimestampFormat(startTime));
		param.put("endTime", DateUtils.getTimestampFormat(endTime));
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}
	
	public Page<TenderProjectEntity> getSubPackagePageList(String tenderId ,int pageNo, int pageSize){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSubPackagePageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectEntity.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得可唱标的包件
	 * @author mazc
	 * @param tenderId
	 * @param pageNo
	 * @param pageSize
	 * @return 
	 */
	public Page<TenderProjectEntity> getSignBidTenderPackagePageList(String tenderId ,int pageNo, int pageSize){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSignBidTenderPackagePageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectEntity.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description: 按分页查询评标项目
	 * @author mazc
	 * @param userId
	 * @param useSatus
	 * @param searchKey
	 * @param pageNo
	 * @param pageSize
	 * @return 
	 */
	public Page<TenderProjectVo> getEvaluationProjectPageList(String userId, String userType, String evaluationStatus, String searchKey, Date startTime, Date endTime ,int pageNo , int pageSize){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationProjectPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("userType", Constants.USER.getUserType());
		param.put("evaluationStatus", evaluationStatus);
		param.put("searchKey", searchKey);			
		param.put("startTime", DateUtils.getTimestampFormat(startTime));
		param.put("endTime", DateUtils.getTimestampFormat(endTime));
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
//	public Page<TenderProjectVo> getEvaluationProjectPageList(AuthUser user, String useSatus, String searchKey, int pageNo, int pageSize){
//		//获取服务器地址
//		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationProjectPageList");
////		strWebServerUrl = "http://127.0.0.1:8081/"+ URL + "/getEvaluationProjectPageList";
//		RequestBody<AuthUser> requestBody = new RequestBody<AuthUser>();
//		requestBody.setEntity(user);
//		requestBody.setParam("useSatus", useSatus);
//		if(StringUtils.isNotEmpty(searchKey)){
//			requestBody.setParam("searchKey", searchKey);			
//		}
//		requestBody.setParam("pageNo", pageNo);
//		requestBody.setParam("pageSize", pageSize);
//		try{
//			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
//			if(ResultStatus.getReultStatusIsNotEmpty(result)){
//				Map<String, Class> classMap = new HashMap<String, Class>();
//				classMap.put("records", TenderProjectVo.class);
//				return JsonUtil.strToObject(result, Page.class, classMap);
//			}
//		} catch (Exception e) {
//			logger.error(e.getMessage(), e);
//			return null;
//		}
//		return null;
//	}
	
	
	public TenderProjectEntity getTenderProjectInfo(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderProjectInfo");
		//登陆请求地址
// 		strWebServerUrl = "http://127.0.0.1:8081/"+ URL + "/projectinfo";
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean isUniqueTenderProject(String id,String parentId, String tenderNO, String phaseType ){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isUnique");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		param.put("parentId", parentId);
		param.put("useStatus", CommonEnum.REAL_STATUS);
		param.put("tenderNO", tenderNO);
		param.put("phaseType", phaseType);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public TenderProjectEntity insert(TenderProjectEntity tenderProjectEntity){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertTenderProject");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectEntity));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public void update(TenderProjectEntity tenderProjectEntity){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/update");
		try{
			NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectEntity));
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return ;
		}
	}
		
	public void updateTenderType(String tenderType, String parentId ,String useStatus){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateTenderType");
//		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/updatetendertype"; 
		//请求参数
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderType", tenderType);
		param.put("parentId", parentId);
		param.put("useStatus",useStatus);
		try{
			NetworkRequest.post(strWebServerUrl, param);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return ;
		}
	}
	
	 /**   
	 * @Title: queryTenderIdList   
	 * @Description: 通过父id查询子项目id
	 * @param: @param parentId
	 * @param: @return      
	 * @return: List<String> 子项目id列表
	 * @throws   
	 */  
	public List<Object> queryTenderIdList(String parentId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSubPackIdList");
		//请求参数
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 通过id 删除项目同时删除子项目
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public boolean removeTenderProject(String id){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteProject");
 		//请求参数
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	 /**   
	 * @Description: 更新分配属性
	 * @param: @param tenderProjectRuleEntity      
	 * @return: void      
	 * @throws   
	 */  
	public boolean updateAssignProperty(TenderProjectEntity tenderProjectEntity ,String [] attributes){
        //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
        UpdateAssignPropertyVo<TenderProjectEntity> updateAssignPropertyVo = new UpdateAssignPropertyVo<TenderProjectEntity>();
        updateAssignPropertyVo.setEntity(tenderProjectEntity);
        updateAssignPropertyVo.setAttributes(attributes);
        try{
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
	}
	
	public boolean isInProgress(String tenderId, String stepType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isInEvaluation");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		if(null != stepType){
			param.put("stepType", stepType);			
		}
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获取标段价格指标信息
	 * @author mazc
	 * @param tenderParentId
	 * @param auditType
	 * @return 
	 */
	public List<TenderPackPriceFactorVo> getTenderPackPriceFactorInfoList(String tenderParentId,String auditType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderPackPriceFactorList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderParentId", tenderParentId);
		param.put("auditType", auditType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderPackPriceFactorVo.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	@Deprecated
	public boolean updateDownLoadProject(TenderProjectEntity tenderProject ,TenderProjectRuleEntity projectRule){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateDownLoadProject");
//		strWebServerUrl = "http://127.0.0.1:8081/" + URL + "/updateDownLoadProject"; 
		RequestBody<Object> requestBody = new RequestBody<Object>();
		requestBody.setParam("tenderProjectEntity", tenderProject);
		requestBody.setParam("tenderProjectRuleEntity", projectRule);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public TenderProjectEntity getById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getById");
//		strWebServerUrl = "http://127.0.0.1:8081/" + URL + "/findBidOpeningStatusById"; 
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}

	}
	
	
	/**
	 * @Description:  通过Tenderid 获取开标状态
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public String getBidOpeningStatusByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getBidOpeningStatusById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return result;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}

	}
	
	/**
	 * @Description: 按分页查询评标项目的分包
	 * @author mazc
	 * @param userId
	 * @param projectId
	 * @param useSatus
	 * @param pageNo
	 * @param pageSize 
	 */
	public Page<TenderProjectVo>  getEvaluationPackageList(String userId, String projectId, String evaluationStatus, int pageNo, int pageSize){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertEvaluationTenderPackPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("projectId", projectId);
		param.put("evaluationStatus", evaluationStatus);
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", TenderProjectVo.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获取开标不足三家供应商的标段
	 * @author mazc
	 * @param parentId
	 * @return 
	 */
	public List<TenderProjectEntity> getUnEnoughSupplierList(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUnEnoughSupplierList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 查询标包信息并对字段排序
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<TenderProjectEntity> getPackageByTenderId(String tenderId, String[] columns){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getPackageByTenderIdOrderbyAsc");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("columns", columns);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param tenderProjectEntity
	 * @return 
	 */
	public boolean saveOrUpdate(TenderProjectEntity tenderProjectEntity){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tenderProjectEntity));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得专家的评审项目列表
	 * @author mazc
	 * @param userId 用户Id
	 * @param searchKey
	 * @param macName
	 * @return 
	 */
	public List<TenderProjectEntity> getExpertTenderProjectList(String userId, String searchKey, String macName){  
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertTenderProjectList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("searchKey", searchKey);
		param.put("macName", macName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**
	 * @Description: 查找和当前品目相同的相同分包
	 * @author mazc
	 * @return 
	 */
	
	public List<TenderProjectEntity> getPurcategoryNamesAndParentId(String parentId,String purcategoryNames,String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getPurcategoryNamesAndParentId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("parentId", parentId);
		param.put("purcategoryNames", purcategoryNames);
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 修改开标状态
	 * @author mazc
	 * @param tenderId
	 * @param parentId
	 * @param bidOpeningStatus
	 * @return 
	 */
	public int updateBidopeningStatus(String tenderId, String parentId, String bidOpeningStatus){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateBidOpeningStatus");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("parentId", parentId);
		param.put("bidOpeningStatus", bidOpeningStatus);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusOK(result)){	
				return Integer.valueOf(result);						
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
 
	/**
	 * @Description: 修改开标解密状态
	 * @author mazc
	 * @param tenderProject 阶段类型
	 * @param bidopeningStage
	 * @param status 解密状态
	 */
	public int updateBidOpeningStatus(TenderProjectEntity tenderProject, String bidopeningStage, String status){
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateBidOpeningDecodeStatus");
		RequestBody<TenderProjectEntity> requestBody = new RequestBody<TenderProjectEntity>();
		requestBody.setEntity(tenderProject);
		requestBody.setParam("bidopeningStage", bidopeningStage);
		requestBody.setParam("status", status);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusOK(result)){	
				return Integer.valueOf(result);						
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 获得项目下的所有包件的开标信息
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	public List<TenderPackOpeningInfo> getTenderPackOpeningInfoList(String projectId, String bidopeningStage){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderPackOpeningInfoList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("bidopeningStage", bidopeningStage);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderPackOpeningInfo.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}
	
	/**
	 * @Description:  获得包件的开标信息
	 * @author mazc
	 * @param tenderId
	 * @param bidopeningStage
	 * @return 
	 */
	public TenderPackOpeningInfo getTenderPackOpeningInfo(String tenderId, String bidopeningStage){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderPackOpeningInfo");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("bidopeningStage", bidopeningStage);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderPackOpeningInfo.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
 
	/**
	 * @Description: 获得父级项目的开标信息
	 * @author mazc
	 * @param tenderProject
	 * @param bidopeningStage
	 * @return 
	 */
	public TenderPackOpeningInfo getTenderProjectOpeningInfo(TenderProjectEntity tenderProject, String bidopeningStage){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderProjectOpeningInfo");
		RequestBody<TenderProjectEntity> requestBody = new RequestBody<TenderProjectEntity>();
		requestBody.setEntity(tenderProject);
		requestBody.setParam("bidopeningStage", bidopeningStage);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderPackOpeningInfo.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
 
	/**
	 * @Description:  获得包件的开标信息
	 * @author mazc
	 * @param projectId
	 * @return 
	 */
	public List<TenderProjectEntity> getTenderPackBidOpeningInfoList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderPackBidOpeningInfoList");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/** 
	 * @Description: 是否完成开标
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isBidOpeningComplate(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isBidOpeningComplate");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		
	}
	/** 
	 * @Description: 是否获取了最新的投标信息
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isGetLatestBidinfo(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isGetLatestBidinfo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 评标是否结束
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isEvaluationComplate(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isEvaluationComplate");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 通过 tenderNo、phaseType、tenderNumber 查询项目信息
	 * @author mazc
	 * @param tenderNo
	 * @param phaseType
	 * @param tenderNumber
	 * @return 
	 */
	public TenderProjectEntity getTenderProjectByPhaseTypeTenderNumber(String tenderNo ,String phaseType,String tenderNumber) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTenderProjectByPhaseTypeTenderNumber");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderNo", tenderNo);
		param.put("phaseType", phaseType);
		param.put("tenderNumber", tenderNumber);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}
	
	/**
	 * @Description: 根据项目tenderNo和父ID，获得项目ID。
	 * @author mazc
	 * @param tenderNo
	 * @param parentId
	 * @return 
	 */
	public List<Object> queryTenderIdListByTenderNoAndparentId(String tenderNo,String parentId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderIdListByTenderNoAndparentId");
		//请求参数
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderNo", tenderNo);
		param.put("parentId", parentId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 导入开标结果
	 * @author mazc
	 * @param tenderProject
	 * @param supplierList
	 * @param bidPriceList
	 * @param bidOpeningStage
	 * @return 
	 */
	public boolean importBidOpenResult(TenderProjectEntity tenderProject, List<Supplier> supplierList, List<BidPrice> bidPriceList, String bidOpeningStage){
		ImportBidOpenResultVo  importBidOpenResultVo = new ImportBidOpenResultVo();
		importBidOpenResultVo.setBidOpeningStage(bidOpeningStage);
		importBidOpenResultVo.setBidPriceList(bidPriceList);
		importBidOpenResultVo.setSupplierList(supplierList);
		importBidOpenResultVo.setTenderProject(tenderProject);
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/importBidOpenResult");	
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(importBidOpenResultVo));
			return ResultStatus.getReultStatusBoolean(result);
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
 	}
	
	public TenderProjectEntity saveDownLoadProject(TenderProjectEntity tenderProject,TenderProjectEntity childTenderProject, TenderProjectRuleEntity parentRule, TenderProjectRuleEntity childRule){
		SaveDownLoadProjectVo saveDownLoadProjectVo = new SaveDownLoadProjectVo();
		saveDownLoadProjectVo.setParentRule(parentRule);
		saveDownLoadProjectVo.setChildRule(childRule);
		saveDownLoadProjectVo.setTenderProject(tenderProject);
		saveDownLoadProjectVo.setChildTenderProject(childTenderProject);
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveDownLoadProject");	
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.objectToStr(saveDownLoadProjectVo));
			Map<String, Class> classMap = new HashMap<String, Class>();
			classMap.put("data", TenderProjectEntity.class);
			ResultEntity<TenderProjectEntity> x = JsonUtil.strToObject(result, ResultEntity.class, classMap);
			if(x.getCode() == ResultEntity.SUCCESS){
				return x.getData();
			}
			return tenderProject;
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return tenderProject;
		}
	}
	
 
	/**
	 * @Description: 删除开标结果
	 * @author mazc
	 * @param tenderId 
	 */
	public int deleteBidOpeningResult(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteBidOpeningResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 获得项目列表
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	public List<TenderProjectEntity> getTenderProjectList(String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderProjectList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 获得当前项目下所有标段评标信息
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	public List<Map<String, Object>> getTenderPackEvaluationInfoList(String projectId, String withoutTenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderPackEvaluationInfoList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("withoutTenderId", withoutTenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToListMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	public List<Map<String, Object>> getReportTenderPackInfoList(String projectId, String withoutTenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getReportTenderPackInfoList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("withoutTenderId", withoutTenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToListMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得当前项目下所有标段专家信息
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	public List<Map<String, Object>> getTenderPackExpertInfoList(String projectId, String withoutTenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderPackExpertInfoList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("withoutTenderId", withoutTenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToListMap(result);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	
	/**
	 * @Description: 查询所有有评审专家的项目
	 * @author mazc
	 * @return 
	 */
	public List<TenderProjectEntity> getTenderProjectByExpert(){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderProjectByExpert");
		Map<String, Object> param = new HashMap<String, Object>();
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 重新开始评审
	 * @author mazc
	 * @param tenderId
	 * @param cleanData 
	 */
	public void restartEvaluation(String tenderId, boolean cleanData){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/restartEvaluation");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("cleanData", cleanData);
		try{
			NetworkRequest.get(strWebServerUrl, param);
 		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return;
 		}
	}
	
	/**
	 * @Description: 如果是带包件的项目，则将所有包件的项目信息来源都进行修改
	 * @author mazc
	 * @param serverId
	 * @param serverAccount
	 * @param serverPassword
	 * @param parentId
	 * @return 
	 */
	public int updateServerContent(String serverId ,String serverAccount,String serverPassword,String parentId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateServerContent");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("serverId", serverId);
		param.put("serverAccount", serverAccount);
		param.put("serverPassword", serverPassword);
		param.put("parentId", parentId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 验证是否存在
	 * @author mazc
	 * @param tenderNo
	 * @param parentId
	 * @param phaseType
	 * @param tenderNoNumber
	 * @return 
	 */
	public TenderProjectEntity valProjectExist(String tenderNo, String parentId, String phaseType, String tenderNumber) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/valProjectExist");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderNo", tenderNo);
		param.put("phaseType", phaseType);
		param.put("tenderNumber", tenderNumber);
		param.put("parentId", parentId);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TenderProjectEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
 	}
	
	/**
	 * @Description: 修改项目的进度状态
	 * @author mazc
	 * @param tenderId
	 * @param status
	 * @return 
	 */
	public int updateEvaluateStatus(String tenderId, String status) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateEvaluateStatus");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("status", status);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 验证项目是否已经完成指定阶段的开标
	 * @param tenderId
	 * @param bidopeningStage
	 * @return
	 */
	public boolean isComplateProjectOpeningByStage(String projectId, String bidopeningStage) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isComplateProjectOpeningByStage");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("bidopeningStage", bidopeningStage);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description 修改项目完成评标的状态
	 * @param id
	 * @param parentId
	 * @param archiveStatus
	 * @return
	 */
	public boolean updateEvaluationComplateStatus(String tenderId, String parentId, String archiveStatus) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateEvaluationComplateStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("parentId", parentId);
		param.put("archiveStatus", archiveStatus);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
	public static void main(String[] args) {
		TenderProjectService  tenderProjectService = new TenderProjectService();
		TenderProjectEntity a = tenderProjectService.getById("23276c68ff564c888203c025d27f7e37");
		
		tenderProjectService.getTenderProjectOpeningInfo(a,"01");
		
//		tenderProjectService.removeTenderProject("15754937189");
//		 List<Object> list = tenderProjectService.queryTenderIdList("23276c68ff564c888203c025d27f7e37");
//		 for(Object str : list){
//			 System.out.println(str.toString());
//		 }
//		TenderProjectEntity tenderProjectEntity = new TenderProjectEntity();
//		tenderProjectEntity.setId("465464564546565464565");
//		tenderProjectEntity.setUseStatus("05");
		
//		tenderProjectService.Update(tenderProjectEntity);
//		tenderProjectEntity.setTenderNo("NO:12311123112");
//		tenderProjectEntity.setTenderName("XiaoMa Pro");
//		TenderProjectEntity  temTenderProjectEntity = tenderProjectService.insert(tenderProjectEntity);
//		TenderProjectEntity  temTenderProjectEntity = tenderProjectService.getTenderProjectInfo("7db1d53512da4ae2b9ee4bb64e03ba93");
//		System.out.println(temTenderProjectEntity.getTenderName());
//		tenderProjectService.updateTenderType("88", "7f4b7dfae77b40bda783ad14587b5ab6", "01");
//		TenderProjectRuleEntity tenderProjectRuleEntity = new TenderProjectRuleEntity();
//		tenderProjectRuleEntity.setId("21321643164316");
//		tenderProjectRuleEntity.setBidOpeningType("afaf");
//		
//		tenderProjectService.updateDownLoadProject(tenderProjectEntity,tenderProjectRuleEntity);
		AuthUser user = new AuthUser();
		user.setUserType("05");
		user.setId("b4b4f7e26b9e42fd9b9636b1572fc376");
	}
	
	/**
	 * @Description: 评标是否结束
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isUploadEvalResult(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isUploadEvalResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
}

