package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.TorrentFile;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.utils.ResultStatus;

public class TorrentFileService {
	static final String URL = "torrentFile";
	private Logger logger = Logger.getLogger(TorrentFileService.class);
	
	/**
	 * @Description: 通过主键删除
	 * @author mazc
	 * @param uTorrentFileId
	 * @return 
	 */
	public int deleteTorrentFileById(List<String> uTorrentFileId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteTorrentFileById");
 		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(uTorrentFileId));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);	
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 获取项目经理所拥有的项目的种子文件
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	public List<TorrentFile> getTorrentFileListByManager(String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTorrentFileListByManager");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToList(result, TorrentFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public TorrentFile getTorrentFileByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTorrentFileByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToBean(result, TorrentFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public  List<TorrentFile> getTorrentFileAllOrderByFileName(){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTorrentFileAllOrderByFileName");
 		try{
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){	
				return JsonUtil.jsonToList(result, TorrentFile.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public int batchSaveOrUpdate(List<TorrentFile> list){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSaveOrUpdate");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);	
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
}
