package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.entity.TransactionServer;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class TransactionServerService {
	static final String URL = "transactionServer";
	
	private Logger logger = Logger.getLogger(TransactionServerService.class);
	
	
	public TransactionServer findById(String strServerId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getById");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", strServerId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 交换两个执行交易系统的排序
	 * @author mazc
	 * @param source
	 * @param target 
	 */
	public boolean changeTransactionServerSortNo(String sourceSortNo, String sourceid, String targetSortNo, String targetId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/changeTransactionServerSortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sourceSortNo", sourceSortNo);
		param.put("sourceid", sourceid);
		param.put("targetSortNo", targetSortNo);
		param.put("targetId", targetId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
 
	/**
	 * @Description: 获得执行交易系统的最大序号
	 * @author mazc
	 * @return 
	 */
	public int getMaxTransactionServerSortNo(){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxTransactionServerSortNo");
		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 获得当前平台的服务信息
	 * @author mazc
	 * @param serName
	 * @param serverAddress
	 * @return 
	 */
	public TransactionServer getCurPlatformTransactionServer(String serName, String serverAddress){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getCurPlatformTransactionServer");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("serName", serName);
		param.put("serverAddress", serverAddress);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得指定状态的服务
	 * @author wangxiang
	 * @param realStatus
	 * @return 
	 */
	public List<TransactionServer> getStatusServerOrderBySortNo(String realStatus) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getStatusServerOrderBySortNo");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("realStatus", realStatus);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 根据ID查询
	 * @author wangxiang
	 * @param transactionServerId
	 * @return 
	 */
	public TransactionServer getById(String transactionServerId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", transactionServerId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TransactionServer.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 按照获得当前平台的服务信息
	 * @author mazc
	 * @param serName
	 * @param serverAddress
	 * @return 
	 */
	public TransactionServer getTransactionServerByServerAddress(String serverAddress){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTransactionServerByServerAddress");
 		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("serverAddress", serverAddress);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	public boolean deleteById(String id){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	
 
	/**
	 * @Description:  根据id更新指定字段
	 * @author mazc
	 * @param transactionServer
	 * @param strs
	 * @return 
	 */
	public boolean updateAssignProperty(TransactionServer transactionServer, String[] strs) {
		TransactionServer transactionServerTemp = null;
		try {
			WebReflecUtill<TransactionServer> utill = new WebReflecUtill<TransactionServer>();
			transactionServerTemp = (TransactionServer) utill.reflex(transactionServer, strs,TransactionServer.class);
		} catch (Exception e) {
			return false;
		}			
		if(null != transactionServerTemp){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(transactionServerTemp));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}

	
	public List<TransactionServer> getTransactionServerEntityAllOrderBySortNo() {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTransactionServerEntityAllOrderBySortNo");
		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	
	public TransactionServer saveOrUpdateReturn(TransactionServer transactionServer){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(transactionServer));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, TransactionServer.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<Object> getIdList(String serverName , String id){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getIdList");
 		Map<String, Object> param = new HashMap<String, Object>();
 		param.put("serverName", serverName);
 		if(StringUtils.isNotEmpty(id)){
 			param.put("id", id); 			
 		}
		try { 
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Object.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}