package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.auth.AuthLoginRecordEntity;
import com.gx.obe.web.utils.ResultStatus;

/**  
 * @Title:  UserLoginRecordService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    登录记录  
 * @author: XiaoMaPro     
 * @date:   May 8, 2019 10:51:36 AM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class UserLoginRecordService {
	
	static final String URL = "loginRecord";
	
	private Logger logger = Logger.getLogger(UserLoginRecordService.class);

	
	 /**   
	 * @Title: getAccountByLoginInfo   
	 * @Description: 通过登陆户账号 登陆类型查询
	 * @param: @param userAccount
	 * @param: @param loginSysType
	 * @param: @return  登陆信息
	 * @return: AuthLoginRecordEntity      
	 * @throws   
	 */  
	public AuthLoginRecordEntity getAccountByLoginInfo(String userAccount , String loginSysType){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/accountbyinfo");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		param.put("loginSysType", loginSysType);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, AuthLoginRecordEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	 /**   
	 * @Title: deleteAccountByLoginInfo   
	 * @Description: 通过登陆户账号 登陆类型删除信息
	 * @param: @param userAccount
	 * @param: @param loginSysType      
	 * @return: void      
	 * @throws   
	 */  
	public void deleteAccountByLoginInfo(String userAccount , String loginSysType){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deletebyinfo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		param.put("loginSysType", loginSysType);
		try{
			NetworkRequest.get(strWebServerUrl, param);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return ;
		}
 	}
	
	 /**   
	 * @Title: insert   
	 * @Description: 插入登陆记录
	 * @param: @param authLoginRecordEntity      
	 * @return: void      
	 * @throws   
	 */  
	public void insert(AuthLoginRecordEntity authLoginRecordEntity){
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try{
			NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(authLoginRecordEntity));
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return ;
		}
	}
	
	/**
	 * @Description: 根据项目id获取项目经理登录信息
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public AuthLoginRecordEntity getLoginRecordByTenderId(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getLoginRecordByTenderId");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, AuthLoginRecordEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}


	/**
	 * @Description: 注销登录
	 * @author mazc
	 * @param account
	 * @param sysType 
	 */
	public void logout(String account, String sysType, String loginRecordId,String applyUserId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/logout");		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("account", account);
		param.put("sysType", sysType);
		param.put("applyUserId", applyUserId);
		param.put("loginRecordId", loginRecordId);
 		try{
			 NetworkRequest.get(strWebServerUrl, param);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}
 
	/**
	 * @Description: 获得评标室已登录的专家记录
	 * @author mazc
	 * @param evaluationRoomId
	 * @return 
	 */
	public List<AuthLoginRecordEntity> getLoginRecordByEvalBidRoomId(String evaluationRoomId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getLoginRecordByEvalBidRoomId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("evaluationRoomId", evaluationRoomId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthLoginRecordEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
	}
	
	/**
	 * @Description: 获得评标室已登录的专家记录
	 * @author mazc
	 * @param evaluationRoomId
	 * @return 
	 */
	public List<AuthLoginRecordEntity> getLoginRecordAllList(){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getLoginRecordAllList");
 		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthLoginRecordEntity.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	
	/**
	 * @Description:  是否已被注销
	 * @author mazc
	 * @param account
	 * @param sysType
	 * @param loginRecordId
	 * @return 
	 */
	public boolean isLogout(String account, String sysType ,String loginRecordId){
//	    return false;
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isLogout");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("account", account);
		param.put("sysType", sysType);
 		param.put("loginRecordId", loginRecordId);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
}
