package com.gx.obe.web.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.auth.AuthRole;
import com.gx.obe.web.entity.auth.AuthUserRole;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.utils.NowTimeUtils;

/**  
 * @Title:  UserRoleService.java   
 * @Package com.gx.obe.web.service   
 * @Description:    用户角色管理  
 * @author: XiaoMaPro     
 * @date:   Apr 29, 2019 6:43:32 PM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class UserRoleService {
	static final String URL = "authUserRole";
	private Logger logger = Logger.getLogger(UserRoleService.class);

	 /**   
	 * @Title: createUserRole   
	 * @Description: 为用户设置角色
	 * @param:       
	 * @return: void      
	 * @throws   
	 */  
	public void createUserRole(String USER_ID, String[] ROLE_CODE){
		RoleService roleService = new RoleService();
		List<AuthRole> authRoleList = roleService.getRoleListByRoleCode(ROLE_CODE);
		List<AuthUserRole> userRoleList = new ArrayList<AuthUserRole>();

		if(null != authRoleList && authRoleList.size() > 0){
			Date nowDate = NowTimeUtils.getNowDate();
			for(AuthRole role : authRoleList){
				AuthUserRole authRole = new AuthUserRole();
				authRole.setId(UuidUtils.getUUID());
				authRole.setRoleId(role.getId());
				authRole.setUserId(USER_ID);
				authRole.setCreateTime(nowDate);
				authRole.setCreateUserId(Constants.USER.getId());
				userRoleList.add(authRole);
			}
		}
		if(userRoleList.size() > 0){
			//执行批量插入
			batchSave(userRoleList);
		}
	}
	
	 /**   
	 * @Title: batchCreateSave   
	 * @Description: 批量添加用户角色信息
	 * @param: @param userRoleList      
	 * @return: void      
	 * @throws   
	 */  
	public int batchSave(List<AuthUserRole> list){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSave");
 		//登陆请求地址
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(list));//.obejctListToStr()
			 if(ResultStatus.isReultStatusInteger(result)){	
					return Integer.valueOf(result);
				}
				return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	/**
	 * @Description: 为用户设置角色
	 * @author mazc
	 * @param userId
	 * @param roleCode
	 * @param curUserIs 创建用户id
	 */
	public int initUserRole(String userId, String roleCode){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/initUserRole");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("roleCode", roleCode);
		param.put("createUserId",Constants.USER.getId());
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);//.obejctListToStr()
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	public List<String> getUserRoleIdList(String userId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getUserRoleIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, String.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 为用户授权
	 * @author mazc
	 * @param userId
	 * @param roleList
	 * @return 
	 */
	public boolean authorizedRoleForUser(String userId, List<AuthRole> roleList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/authorizedRoleForUser");
		RequestBody<AuthRole> requesBody = new RequestBody<AuthRole>();
		requesBody.setEntityList(roleList);
		requesBody.setParam("userId",userId);
		requesBody.setParam("curUserIs",Constants.USER.getId());
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requesBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public static void main(String[] args) {
		AuthUserRole authUserRole = new AuthUserRole();
		authUserRole.setCreateUserId("aaaaaaaaaaaaaaaaaa");
//		authUserRole.setCreateTime(new Date());
//		authUserRole.setModifyTime(new Date());
		authUserRole.setModifyUserId("aaaaaaaaaaa");
		authUserRole.setRoleId("aaaaaaaaaaafw");
		authUserRole.setUserId("aaaaaaaaaaaaaa");
		authUserRole.setId("a1111234");
		List<Object> list = new ArrayList<Object>();
		list.add(authUserRole);
		
		UserRoleService userRoleService = new UserRoleService ();
		
//		userRoleService.batchCreateSave(list);
	}
}
