package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.vo.AuthUserVo;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.Page;
import com.gx.obe.web.entity.Result.ResultEntity;
import com.gx.obe.web.entity.auth.AuthRole;
import com.gx.obe.web.entity.auth.AuthUser;
import com.gx.obe.web.entity.expert.Expert;
import com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;
import com.gx.obe.web.vo.UpdateExpertInfoVo;

/**  
 * @Title:  UserLoginServiceImp.java   
 * @Package com.gx.obe.web.service   
 * @Description:    用户接口  
 * @author: XiaoMaPro     
 * @date:   Apr 29, 2019 10:19:01 AM   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
public class UserService {
	
	static final String URL = "authUser";
	private Logger logger = Logger.getLogger(UserService.class);
	
	
	/**
	 * @Description: 用户登录
	 * @author mazc
	 * @param USER_ACCOUNT
	 * @param USER_PASSWORD
	 * @return 
	 */
	public ResultEntity<AuthUserVo> loginUserAndPassword(String USER_ACCOUNT, String USER_PASSWORD) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL +"/login/login");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("USER_ACCOUNT", USER_ACCOUNT);
		param.put("USER_PASSWORD", USER_PASSWORD);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("data", AuthUserVo.class);
				return JsonUtil.strToObject(result, ResultEntity.class, classMap);
			}
			return new  ResultEntity<AuthUserVo>(null,"登录失败",ResultEntity.FAIL);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return new  ResultEntity<AuthUserVo>(null,"登录失败",ResultEntity.FAIL);
		}
	}
	
	
	
	
	 /**   
	 * @Title: valLoginNameAndPwd   
	 * @Description: 通过用户名密码登陆
	 * @param: @param USER_ACCOUNT 登陆用户民
	 * @param: @param USER_PASSWORD 登陆密码（加密后）
	 * @param: @return      
	 * @return: AuthUser      
	 * @throws   
	 */  
	public AuthUser valLoginNameAndPwd(String USER_ACCOUNT, String USER_PASSWORD) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL +"/login");
		//添加请求参数{USER_ACCOUNT：登陆名 ，USER_PASSWORD ：用户密码(加密后) }
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("USER_ACCOUNT", USER_ACCOUNT);
		param.put("USER_PASSWORD", USER_PASSWORD);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUserVo vo = JsonUtil.jsonToBean(result, AuthUserVo.class);	
				Constants.TOKEN = vo.getAtuokthen();
				if(null != vo.getAuthUserEntity()) {
					return vo.getAuthUserEntity();
				}else {
					return JsonUtil.jsonToBean(result, AuthUser.class);	
				}
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	/**   
	 * @Title: valLoginNameAndPwd   
	 * @Description: 通过用户名密码登陆
	 * @param: @param USER_ACCOUNT 登陆用户民
	 * @param: @param USER_PASSWORD 登陆密码（加密后）
	 * @param: @return      
	 * @return: AuthUser      
	 * @throws   
	 */  
	public AuthUser loginRemote(AuthUser authUser) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL +"/loginRemote");
		try{
			String result = NetworkRequest.post(strWebServerUrl,  JsonUtil.jsonObjectToStr(authUser));
//			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUserVo vo = JsonUtil.jsonToBean(result, AuthUserVo.class);	
				Constants.TOKEN = vo.getAtuokthen();
				if(null != vo.getAuthUserEntity()) {
					return vo.getAuthUserEntity();
				}else {
					return JsonUtil.jsonToBean(result, AuthUser.class);	
				}
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 通过用户id获取用户信息
	 * @author mazc
	 * @param id
	 * @return 
	 */
	public AuthUser findById(String id){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL +"/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, AuthUser.class);	
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	 /**   
	 * @Title: getUserRoleList   
	 * @Description: 获得用户在指定终端的角色列表
	 * @param: @param TERMINAL_TYPE 终端类型
	 * @param: @param USER_ID	用户ID	
	 * @param: @param ROLE_TYPE ROLE类型
	 * @param: @return      
	 * @return: List<Object>      
	 * @throws   
	 */  
	public List<AuthRole> getUserRoleList(String terminalType, String userId, String ignoreRoleType){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getUserRoleList");
		//param
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("terminalType", terminalType);
		param.put("userId", userId);
		param.put("ignoreRoleType", ignoreRoleType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthRole.class);
//				return JsonUtil.StrToCollection(result, String.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	
	}
	
	 /**   
	 * @Title: existUserAccount   
	 * @Description: 根据用户名查询用户信息判断用户是否存在
	 * @param: @param USER_ACCOUNT 用户名
	 * @param: @return      
	 * @return: boolean      
	 * @throws   
	 *  
	 */  
	public boolean existUserAccount(String userAccount){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/valUserAccount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		try{	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser user =  JsonUtil.jsonToBean(result, AuthUser.class);
				if(user != null){
					return true;	
				}			
			}
			return false;	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 
	 * @author chenxw
	 * @param USER_ACCOUNT
	 * @param USER_PASSWORD
	 * @return 
	 */
	public boolean updatePassword(String USER_ACCOUNT, String USER_PASSWORD){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updatePassword");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", USER_ACCOUNT);
		param.put("userPassword", USER_PASSWORD);
		try{
			String result =NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public AuthUser createUserInfo(AuthUser user){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
//		//param
//		Map<String, Object> param = new HashMap<String, Object>();
//		param.put("userId", IDUtils.getId());
//		param.put("userAccount", user.getUserAccount());
//		param.put("userAccount", user.getUserAccount());
//		param.put("userPassword", user.getUserPassword());	
//		param.put("userName", user.getUserName());
//		param.put("gender", user.getGender());
//		param.put("company", user.getCompany());
//		param.put("userIdcard", user.getUserIdcard());
//		param.put("phone", user.getPhone());
//		param.put("userType", user.getUserType());
//		param.put("professionalTitle", user.getProfessionalTitle());
//		param.put("avatar", user.getAvatar());	
//		param.put("specialty", user.getSpecialty());
//		param.put("areaCode", user.getAreaCode());
//		param.put("useStatus", user.getUseStatus());
//		param.put("bindingCa", user.getBindingCa());
//		param.put("createTime", user.getCreateTime());
//		param.put("modifyTime", user.getModifyTime());
//		param.put("defaultPassword", user.getDefaultPassword());
//		
		user.setId(UuidUtils.getUUID());
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.objectToStr(user));
			if(ResultStatus.getReultStatusBoolean(result)){
				return user;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public Integer updateUserInfo(AuthUser user) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateUser");
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.objectToStr(user));
			if(result.trim().equals("true")){
				return 1;
			}
			return -1;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public AuthUser findUserByIdCardLogin(String idCard , String passWord){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findUserByIdCardLogin");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("idCard", idCard);
		param.put("passWord", passWord);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 更新分配属性
	 * @author chenxw
	 * @param authUser
	 * @param attributes
	 * @return 
	 */
    public boolean updateAssignProperty(AuthUser authUser, String[] attributes) {
        //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
        
        UpdateAssignPropertyVo<AuthUser> updateAssignPropertyVo = new UpdateAssignPropertyVo<AuthUser>();
        updateAssignPropertyVo.setEntity(authUser);
        updateAssignPropertyVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
	
	public boolean valLoginAuthority (String userId, String terminal){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/valLoginAuthority");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("terminal", terminal);
		try{	
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);	
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public AuthUser caLogin(String caName, String certId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/caLogin");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("caName", caName);
		param.put("certId", certId);
		try{	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 验证用户名或者身份证号是否存在
	 * @author mazc
	 * @param idCard
	 * @return 
	 */
	public AuthUser getUserByIdCard(String idCard){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserByIdCard");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("idCard", idCard);
		try{	
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 验证账号和身份证号是否重复
	 * @author mazc 
	 */
	public int valAccountAndIdCard(String userAccount, String id, String userIdcard) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/valAccountAndIdCard");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		param.put("id", id);
		param.put("userIdcard", userIdcard);
		try{
			String result = NetworkRequest.get(strWebServerUrl , param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}		
	}
	
	/**
	 * @Description: 列出所有的指定状态的用户
	 * @author mazc
	 * @param useStatus
	 * @return 
	 */
	public List<AuthUser> getUserAllByStatus(String useStatus,String userType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserAllByStatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("useStatus", useStatus);
		param.put("userType", userType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public AuthUser getUserByName(String userName){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserByName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userName", userName);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
	
	
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param authUser
	 * @return 
	 */
	public AuthUser saveOrUpdateReturn(AuthUser authUser){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
		try{
			String result = NetworkRequest.post(strWebServerUrl,  JsonUtil.jsonObjectToStr(authUser));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
	
	
	/**
	 * @Description: 通过UserAccount获取用户信息
	 * @author mazc
	 * @param userAccount
	 * @return 
	 */
	public AuthUser getUserByUserAccount(String userAccount){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserByUserAccount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
	
	/**
	 * @Description: 列出所有的指定状态的用户
	 * @author mazc
	 * @param useStatus
	 * @return 
	 */
	public List<AuthUser> getUserAllByUserAccount(String userAccount){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserAllByUserAccount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	
	/**
	 * @Description: 列出所有的指定状态的用户
	 * @author mazc
	 * @param useStatus
	 * @return 
	 */
	public List<AuthUser> getUserAllByUserTypeUserNameOrUserAccount(String userAccount ,String userName, String userType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserAllByUserTypeUserNameOrUserAccount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccount", userAccount);
		param.put("userName", userName);
		param.put("userType", userType);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	

	/**
	 * @Description: 通过项目ID，查询当前项目下所有专家的用户信息
	 * @author mazc
	 * @param projectId
	 * @return 
	 */
	public List<AuthUser> getExpertByProjectId(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertByProjectId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description:  获取当前系统临时用户数量
	 * @author mazc
	 * @return 
	 */
	public int getTempUserNum(){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getTempUserNum");
		try{
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}		
	}
	 
	/**
	 * @Description: 通过账号或者身份证验证用户是否存在
	 * @author mazc
	 * @param userAccont
	 * @param idCard
	 * @return 
	 */
	public AuthUser getUserByIdOrAccont(String userAccont, String idCard){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserByIdOrAccont");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userAccont", userAccont);
		param.put("idCard", idCard);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				AuthUser tempuser = JsonUtil.jsonToBean(result, AuthUser.class);					
				return tempuser;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
	
	
	/**
	 * @Description: 根据用户名和用户类型，获得用户列表
	 * @author mazc
	 * @param userType
	 * @param userName
	 * @return 
	 */
	public List<AuthUser> getUserListByUserName(String userType, String userName) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserListByUserName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userType", userType);
		param.put("userName", userName);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 更新使用状态
	 * @author mazc
	 * @param id
	 * @param useStatus
	 * @return 
	 */
	public int updateUsestatus(String id ,String useStatus) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateUsestatus");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		param.put("useStatus", useStatus);
		try{
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}		
	}
	public Page<AuthUser> getUserPageList(String account,String userName,String roleType, int pageNo, int pageSize){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserPageList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("account", account);
		param.put("userName", userName);
		param.put("roleType", roleType);			
		param.put("pageNo", pageNo);
		param.put("pageSize", pageSize);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				Map<String, Class> classMap = new HashMap<String, Class>();
				classMap.put("records", AuthUser.class);
				return JsonUtil.strToObject(result, Page.class, classMap);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @param id
	 * @return
	 */
	public List<AuthUser> getGroupItemUserList(String id) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getGroupItemUserList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * 更新专家
	 * @param selectExpert
	 * @param curExpert
	 * @param updateUser
	 * @return
	 */
	public boolean updateExpertInfo(Expert selectExpert, Expert curExpert, AuthUser updateUser) {
		  //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateExpertInfo");
        
        UpdateExpertInfoVo updateExpertInfoVo = new UpdateExpertInfoVo();
        updateExpertInfoVo.setSelectExpert(selectExpert);
        updateExpertInfoVo.setCurExpert(curExpert);
        updateExpertInfoVo.setUser(updateUser);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateExpertInfoVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
	}
	
	
 }
