package com.gx.obe.web.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.Worker;
import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;

public class WorkerService {
	static final String URL = "workMember";
	
	private Logger logger = Logger.getLogger(WorkerService.class);
 	

	/**
	 * @Description: 返回指定类型的工作人员
	 * @author mazc
	 * @param tenderId
	 * @param workerType
	 * @return 
	 */
	public List<Worker> getWorkerList(boolean isParentProject,String tenderId, String workerType){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getWorkerList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("workerType", workerType);
		param.put("isParentProject", isParentProject);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Worker.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 返回指定项目的工作人员
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return 
	 */
	public Worker getWorker(String tenderId, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getWorker");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Worker.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 删除工作人员
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param wokerType
	 * @return 
	 */
	public boolean deleteWorker(String tenderId, String userId,String wokerType){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/deleteWorker");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("wokerType", wokerType);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 删除工作人员
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param wokerType
	 * @return 
	 */
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 删除所有工作人员
	 * @author mazc
	 * @param tenderId
	 * @param wokerType
	 * @return 
	 */
	public boolean delAllWorkers(String tenderId,String wokerType,String monitorType){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/delAllWorkers");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("wokerType", wokerType);
		param.put("monitorType", monitorType);
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public int batchSave(List<Worker> workerList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(workerList));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	} 
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param supplierEvaluationFactorList
	 * @return 
	 */
	public int batchSaveOrUpdate(List<Worker> workerList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSaveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(workerList));
			if(ResultStatus.isReultStatusInteger(result)){	
 				return Integer.valueOf(result);
 			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	
	public int insert(Worker worker){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSaveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(worker));
			if(ResultStatus.isReultStatusInteger(result)){	
 				return Integer.valueOf(result);
 			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}	
	}
	
	
	public boolean saveOrUpdate(Worker worker){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(worker));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}	
	}
	
	public Worker saveOrUpdateReturn(Worker worker){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(worker));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Worker.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}
	/** 
	 * @Description:  根据id更新指定字段
	 * @author wangxiang
	 * @param supplier
	 * @param strs
	 * @return 
	 */
	public boolean updateAssignProperty(Worker worker, String[] strs) {
		Worker workerTemp = null;
		try {
			WebReflecUtill<Worker> utill = new WebReflecUtill<Worker>();
			workerTemp =  (Worker) utill.reflex(worker, strs,Worker.class);
		} catch (Exception e) {
			return false;
		}			
		if(null != workerTemp){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(workerTemp));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
	
	public Worker getWorkerByUserIdAndTenderIdOrMemberType(String userId,String tenderId,String memberType){
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getWorkerByUserIdAndTenderIdOrMemberType");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userId", userId);
		param.put("tenderId", tenderId);
		param.put("memberType", memberType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Worker.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}	
	}

	public List<Worker> getWorkerListByProjectId(boolean isParentProject,String id, String worker) {
		String strWebServerUrl = Constants.getServiceUrl( URL +"/getWorkerList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", id);
		param.put("workerType", worker);
		param.put("isParentProject", isParentProject);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Worker.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
