package com.gx.obe.web.service.award;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.auard.AwardCertificate;
import com.gx.obe.web.utils.ResultStatus;

/**
 * @Description:
 * @author mazc
 */
public class AwardCertificateService {
	
	static final String URL = "awardCertificate";
	
	private Logger logger = Logger.getLogger(AwardCertificateService.class);
	
	/**
	 * @Description: 获得当前奖项类型下全部供应商
	 * @author mazc
	 * @param awardName
	 * @return
	 */
	public List<AwardCertificate> getAwardCertificateList(String awardName) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAwardCertificateList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("awardName", awardName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, AwardCertificate.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 是否含有此供应商
	 * @author mazc
	 * @param orgName
	 * @param awardName
	 * @return
	 */
	public boolean isHasSupplier(String orgName, String awardName) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isHasSupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("orgName", orgName);
		param.put("awardName", awardName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获取全部
	 * @author mazc
	 * @return
	 */
	public List<AwardCertificate> getAllList() {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllList");
		Map<String, Object> param = new HashMap<String, Object>();
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, AwardCertificate.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 查找奖项企业
	 * @author mazc
	 * @param awardName
	 * @param awardType
	 * @return
	 */
	public AwardCertificate getAwardCertificate(String awardName, String awardType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAwardCertificate");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("awardName", awardName);
		param.put("awardType", awardType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToBean(result, AwardCertificate.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存下载供应商信息
	 * @author mazc
	 * @param awardCertificate
	 * @return
	 */
	public String saveDownLoadAwardCertificate(AwardCertificate awardCertificate) {
		StringBuffer buffer = new StringBuffer();
		if (null != awardCertificate.getId() && !"".equals(awardCertificate.getId())) {
			String strWebServerUrl = Constants.getServiceUrl(URL + "/updateById");
			try {
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(awardCertificate));
				if (ResultStatus.isReultStatusInteger(result)) {
					int iCount = Integer.valueOf(result);
					if (iCount == 1) {
						buffer.append("√ [" + awardCertificate.getOrgName() + "] 信息更新成功！");
					} else {
						buffer.append("× [" + awardCertificate.getOrgName() + "] 信息更新失败！");
					}
					
				}
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return null;
			}
		} else {
			awardCertificate.setId(UuidUtils.getUUID());
			String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
			try {
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(awardCertificate));
				if (ResultStatus.isReultStatusInteger(result)) {
					int iCount = Integer.valueOf(result);
					if (iCount == 1) {
						buffer.append("√ [" + awardCertificate.getOrgName() + "] 下载成功！");
					} else {
						buffer.append("× [" + awardCertificate.getOrgName() + "] 下载失败！");
					}
				}
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return null;
			}
		}
		
		return buffer.toString();
	}
	
	/**
	 * @Description: 是否含有此供应商
	 * @author mazc
	 * @param orgName
	 * @param awardName
	 * @return
	 */
	public boolean hasSupplier(String orgName, String awardName) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/hasSupplier");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("orgName", orgName);
		param.put("awardName", awardName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 更新分配属性
	 * @author mazc
	 * @param awardCertificate
	 * @param attributes
	 * @return
	 */
	public boolean updateAssignProperty(AwardCertificate awardCertificate, String[] attributes) {
		AwardCertificate ruleEntity = null;
		try {
			WebReflecUtill<AwardCertificate> utill = new WebReflecUtill<AwardCertificate>();
			ruleEntity = (AwardCertificate) utill.reflex(awardCertificate, attributes, AwardCertificate.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
		if (null != ruleEntity) {
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl(URL + "/updateById");
			try {
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(ruleEntity));
				if (ResultStatus.getReultStatusBoolean(result)) {
					return true;
				}
				return false;
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
	
	/**
	 * @Description: 插入
	 * @author mazc
	 * @param awardCertificate
	 * @return
	 */
	public boolean insert(AwardCertificate awardCertificate) {
		if (null == awardCertificate.getId() || "".equals(awardCertificate.getId())) {
			awardCertificate.setId(UuidUtils.getUUID());
		}
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(awardCertificate));
			if (ResultStatus.getReultStatusBoolean(result)) {
				return true;
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存
	 * @author mazc
	 * @param awardCertificate
	 * @return
	 */
	public AwardCertificate saveOrUpdateReturn(AwardCertificate awardCertificate) {
		//登陆请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(awardCertificate));
			if (ResultStatus.getReultStatusBoolean(result)) {
				return awardCertificate;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
}
