package com.gx.obe.web.service.boq;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.boq.BillTable;
import com.gx.obe.web.utils.ResultStatus;

public class BillTableService {
	
	private static final String URL = "obeBillTable";
	
	private Logger logger = Logger.getLogger(BillTableService.class);
	
	/**
	 * @Description: 获得供应商全部分布分项的清单列表
	 * @param tenderId
	 * @param supplierId
	 * @return
	 */
	public List<BillTable> getAllBillTableQDList(String tenderId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllBillTableQDList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得招标项目的分布分项的清单列表
	 * @author guoyr
	 * @param projectId
	 * @return
	 */
	public List<BillTable> getTenderProjectBillTableQdList(String tenderId, String projectCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderProjectBillTableQdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("projectCode", projectCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得分布分项的清单列表
	 * @author guoyr
	 * @param projectId
	 * @return
	 */
	public List<BillTable> getBillTableQdList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBillTableQdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 根据工程项目编号"，获得分部分项信息(分布工程、清单、定额、工料机)
	 * @author guoyr
	 * @param dxgcCode 单项工程编号
	 * @param dwgcCode 单位工程编号
	 * @return List<BillTable>
	 */
	public List<BillTable> getBillTableList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBillTableList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得供应商全部分布分项的清单列表
	 * @author mazc
	 * @param constructionIds
	 * @return
	 */
	public List<BillTable> getBillTableBTConstructionIdsList(List<String> constructionIds) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBillTableList");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(constructionIds));
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得分布分项的清单和定额列表
	 * @author guoyr
	 * @param projectId
	 * @return
	 */
	public List<BillTable> getBillTableQdAndDeList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getBillTableQdAndDeList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, BillTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
}
