package com.gx.obe.web.service.boq;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.boq.AnalyzeDataSource;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.boq.ConstructProject;
import com.gx.obe.web.utils.ResultStatus;

public class ConstructProjectService {
	
	private static final String URL = "obeConstructProject";
	
	private Logger logger = Logger.getLogger(ConstructProjectService.class);
	
	/**
	 * @Description: 删除所有清单内容
	 * @param tenderId
	 * @param supplierId 为空时表示删除招标清单，不为空时表示删除供应商下清单
	 * @param deleteAllProject 删除项目所有所有清单内容（含招标和供应商）
	 * @return
	 */
	public int deleteAllConstructProjectDetail(String tenderId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteAllConstructProjectDetail");
		Map<String, Object> paramMap = new HashMap<String, Object>();
		paramMap.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, paramMap);
			if (ResultStatus.getReultStatusOK(result)) {
				return Integer.valueOf(result);
			}
		} catch (Exception e) {
			logger.error("删除所有清单内容失败！", e);
		}
		return 0;
	}
	
	/**
	 * @Description: 保存工程项目及明细
	 * @author mazc
	 * @param analyzeBOQThread
	 * @return
	 */
	public boolean saveConstructProjectDetail(AnalyzeDataSource analyzeDataSource) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveConstructProjectDetail");
		try {
			return ResultStatus.getReultStatusBoolean(NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(analyzeDataSource)));
		} catch (Exception e) {
			logger.error("保存工程项目及明细！", e);
		}
		return false;
	}

	/**
	 * @Description:  根据项目Id和供应商Id，获得工程信息(包括单项和单位工程)。
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @return
	 */
	public ConstructProject getAllConstructProject(String tenderId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllConstructProject");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToBean(result, ConstructProject.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
}
