package com.gx.obe.web.service.boq;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.boq.ExtraTable;
import com.gx.obe.web.utils.ResultStatus;

public class ExtraTableService {
	
	private static final String URL = "obeExtraTable";
	
	private Logger logger = Logger.getLogger(ExtraTableService.class);
	
	/**
	 * @Description: 获得供应商全部其他项目清单
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return
	 */
	public List<ExtraTable> getAllExtraTableQDList(String tenderId, String supplierId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllExtraTableQDList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, ExtraTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: : 获得招标项目的其他项目的清单列表
	 * @author mazc
	 * @param tenderId
	 * @param projectCode
	 * @return
	 */
	public List<ExtraTable> getTenderProjectExtraTableQdList(String tenderId, String projectCode) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderProjectExtraTableQdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("projectCode", projectCode);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, ExtraTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 根据项目Id， 获得其他项目信息。
	 * @author guoyr
	 * @param projectId
	 * @return List<ExtraTable>
	 */
	public List<ExtraTable> getExtraTableListByProjectId(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getExtraTableListByProjectId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, ExtraTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
}
