package com.gx.obe.web.service.boq;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.boq.MaterialSummary;
import com.gx.obe.web.utils.ResultStatus;

public class MaterialSummaryService {
	
	private static final String URL = "obeMaterialSummary";
	
	private Logger logger = Logger.getLogger(MaterialSummaryService.class);
	
	/**
	 * @Description: 根据工程Id，获得指定类型的工料机汇总。
	 * @author guoyr
	 * @param projectId
	 * @param kind 材料类型(00：其他；01：人工；02：材料；03：机械；04：主材；05：设备)
	 * @return List<MaterialSummary>
	 */
	public List<MaterialSummary> getMaterialSummaryList(String projectId, String kind) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaterialSummaryList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("kind", kind);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MaterialSummary.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 根据工程Id，获得指定类型的工料机汇总。
	 * @author guoyr
	 * @param projectId
	 * @param kind 材料类型(00：其他；01：人工；02：材料；03：机械；04：主材；05：设备)
	 * @return List<MaterialSummary>
	 */
	public MaterialSummary getMaterialSummary(String projectId, String kind) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaterialSummary");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("kind", kind);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToBean(result, MaterialSummary.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 根据工程Id，获得工料机汇总。
	 * @author guoyr
	 * @param projectId
	 * @return List<MaterialSummary>
	 */
	public List<MaterialSummary> getMaterialSummaryAndChildList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaterialSummaryAndChildList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MaterialSummary.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
}
