package com.gx.obe.web.service.boq;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.boq.MeasureTable;
import com.gx.obe.web.utils.ResultStatus;

public class MeasureTableService {
	
	private static final String URL = "obeMeasureTable";
	
	private Logger logger = Logger.getLogger(MeasureTableService.class);
	
	/**
	 * @Description: 根据措施项目清单列表
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return
	 */
	public List<MeasureTable> getAllMeasureTableQDList(String tenderId, String supplierId, String measureType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllMeasureTableQDList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("measureType", measureType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得招标项目的措施清单列表
	 * @author guoyr
	 * @param tenderId
	 * @param projectCode
	 * @return
	 */
	public List<MeasureTable> getTenderProjectMeasureTableQdList(String tenderId, String projectCode, String measureType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getTenderProjectMeasureTableQdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("projectCode", projectCode);
		param.put("measureType", measureType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得措施的清单列表
	 * @author guoyr
	 * @param projectId
	 * @return
	 */
	public List<MeasureTable> getMeasureTableQdList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMeasureTableQdList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得措施项目(清单、定额、工料机汇总)
	 * @author guoyr
	 * @param projectId
	 * @param measureType
	 * @return
	 */
	public List<MeasureTable> getMeasureTableListByProjectId(String projectId, String measureType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMeasureTableListByProjectId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		param.put("measureType", measureType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 根据项目Id，获得措施项目(清单、定额、工料机汇总)
	 * @author mazc
	 * @param constructionIds
	 * @return
	 */
	public List<MeasureTable> getMeasureTableByConstructionIdsList(List<String> constructionIds, String measureType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMeasureTableByConstructionIdsList");
		RequestBody<String> requestBody = new RequestBody<String>(constructionIds);
		requestBody.setParam("measureType", measureType);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得措施的清单和定额列表
	 * @author guoyr
	 * @param projectId
	 * @return
	 */
	public List<MeasureTable> getMeasureTableQdAndDeList(String projectId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getMeasureTableQdAndDeList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusOK(result)) {
				return JsonUtil.jsonToList(result, MeasureTable.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
}
