package com.gx.obe.web.service.evaluation;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.EvaluationFactorResult;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.utils.ResultStatus;

/**
 * @Description: 评标结果
 * @author mazc
 */
public class EvaluationFactorResultService {
    
    static final String URL = "evaluationFactorResult";
    
    private Logger logger = Logger.getLogger(EvaluationFactorResultService.class);
    
    public List<String> checklObjectiveFactorResult(String tenderProjectId, String stepId, String supplierId, String factorId, String userId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/checklObjectiveFactorResult");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderProjectId", tenderProjectId);
        param.put("stepId", stepId);
        param.put("supplierId", supplierId);
        param.put("factorId", factorId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.StrToCollection(result, String.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得评标结果类型
     * @author wangxiang
     * @param tenderId
     * @param stepId
     * @param supplierId
     * @param factorId
     * @param userId
     * @return
     */
    public List<BigDecimal> getEvaluationScoreListNotUserId(String tenderId, String stepId, String supplierId, String factorId, String userId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationScoreListNotUserId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("supplierId", supplierId);
        param.put("factorId", factorId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, BigDecimal.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 评审当前评标专家所有的评标结果
     * @author mazc
     * @param tenderId
     * @param stepId
     * @param userId
     * @param supplierId
     * @return
     */
    public List<EvaluationFactorResult> getExpertEvaluationFactorResult(String tenderId, String stepId, String userId, String supplierId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertEvaluationFactorResult");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("userId", userId);
        param.put("supplierId", supplierId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationFactorResult.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得按供就商打分结果列表
     * @author guoyr
     * @param projectId
     * @param supplierName
     * @param groupCode
     * @return
     */
    public List<Map<String, Object>> getSupplierEvaluationFactorResult(String projectId, String groupCode, String userId, String supplierName) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierEvaluationFactorResult");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("projectId", projectId);
        param.put("groupCode", groupCode);
        param.put("userId", userId);
        param.put("supplierName", supplierName);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToListMap(result);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存按供应商打分结果
     * @author wangxiang
     * @param parentId
     * @param groupCode
     * @param id
     * @param supplierEvaluationFactorResultList
     */
    public void saveEvaluationResultBySupplier(String parentId, String groupCode, String userId, List<Map<String, Object>> supplierEvaluationFactorResultList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveEvaluationResultBySupplier");
        RequestBody<Map<String, Object>> requestBody = new RequestBody<Map<String, Object>>();
        requestBody.setEntityList(supplierEvaluationFactorResultList);
        requestBody.setParam("projectId", parentId);
        requestBody.setParam("groupCode", groupCode);
        requestBody.setParam("userId", userId);
        try {
            NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }
    
    /**
     * @Description: 获得指标的平均分
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    public List<Map<String, Object>> getEvaluationFactorAvgScoreList(String tenderId, String stepId, String supplierId, boolean removeMaxMin) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationFactorAvgScoreList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("supplierId", supplierId);
        param.put("removeMaxMin", removeMaxMin);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToListMap(result);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 根据指标Id获取对应的指标评审结果
     * @author chenxw
     * @param factorId
     * @return
     */
    public List<EvaluationFactorResult> getEvaluationFactorResultList(String tenderId, String stepId, String factorId) {
        return getEvaluationFactorResultList(tenderId, stepId, factorId, null);
    }
    
    /**
     * @Description: 根据指标Id获取当前专家对应的指标评审结果
     * @author chenxw
     * @param factorId
     * @return
     */
    public List<EvaluationFactorResult> getEvaluationFactorResultList(String tenderId, String stepId, String factorId, String userId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationFactorResultList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("factorId", factorId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationFactorResult.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得评标专家的评标结果列表
     * @author guoyr
     * @param factorType
     */
    public List<EvaluationFactorResult> getExpertEvaluationFactorResult(String tenderId, String factorType) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getResultListByFactorType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("factorType", factorType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationFactorResult.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取指定指标不同评审结果的个数
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param factorId
     * @param userId
     * @param result
     * @param score
     * @return
     */
    public int getSupplierDistinctFactorCount(String tenderId, String stepId, String factorId, String userId, String evalResult, BigDecimal score) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierDistinctFactorCount");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("factorId", factorId);
        param.put("userId", userId);
        param.put("result", evalResult);
        param.put("score", score);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("getSupplierDistinctFactorCount");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 获取同一指标评标结果不同的列表
     * @author mazc
     * @param tenderId
     * @param stepId
     * @param isScoreFactor
     * @return
     */
    public List<Map<String, Object>> getSupplierDistinctFactorResultList(String tenderId, String stepId, boolean isScoreFactor) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierDistinctFactorResultList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("isScoreFactor", isScoreFactor);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToListMap(result);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取得分列表
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @param supplierId
     * @param factorId
     * @return
     */
    public List<BigDecimal> getEvaluationScoreList(String tenderId, String stepId, String supplierId, String factorId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationScoreList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("supplierId", supplierId);
        param.put("factorId", factorId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, BigDecimal.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取评审指标结果
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @return
     */
    public List<EvaluationFactorResult> getEvaluationFactorResultList(String tenderId, String stepId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationFactorResultList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationFactorResult.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
}
