package com.gx.obe.web.service.evaluation;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.EvaluationFactorEnum;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.web.entity.StatusEntity;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.evaluation.EvaluationFactor;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import com.gx.obe.web.entity.tender.TenderProjectEntity;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.ImportEvaluationFactorVo;
import com.gx.obe.web.vo.SaveBusinessFactorVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/**
 * @Description:
 * @author mazc
 */
public class EvaluationFactorService {
    
    static final String URL = "evaluationFactor";
    
    private Logger logger = Logger.getLogger(EvaluationFactorService.class);
    
    /**
     * @Description: 获取项目下指定类型的指标主键
     * @author mazc
     * @return
     */
    public int getFactorCountByTenderId(String tenderId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getFactorCountByTenderId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("getFactorCountByTenderId");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 批量更新
     * @author mazc
     * @param evaluationFactorList
     * @param attributes
     * @return
     */
    public boolean batchUpdateProperty(List<EvaluationFactor> evaluationFactorList, String[] attributes) {
    	  BatchUpdatePropertyVo<EvaluationFactor> batchUpdatePropertyVo = new BatchUpdatePropertyVo<EvaluationFactor>();
          batchUpdatePropertyVo.setEntityList(evaluationFactorList);
          batchUpdatePropertyVo.setAttributes(attributes);
          
          //请求地址
          String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
          try {
        	  String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(batchUpdatePropertyVo));
        	  if (ResultStatus.getReultStatusOK(result) && StatusEntity.TRUE.equals(result)) {
        		  return true;
        	  }
        	  return false;
          } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    public boolean existCreditFactor(String factorId, String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/existCreditFactor");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("evalBidType", EvaluationFactorEnum.EVAL_BID_CREDIT);
        param.put("tenderId", tenderId);
        if (StringUtils.isNotEmpty(factorId)) {
            param.put("factorId", factorId);
        }
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusBoolean(result)) {
                return true;
            }
            return false;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    public void deleteById(String id) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteById");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("id", id);
        try {
            NetworkRequest.get(strWebServerUrl, param);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return;
        }
    }
    
    /**
     * @Description: 更新分配属性
     * @author mazc
     * @param evaluationFactor
     * @param attributes
     * @return
     */
	public boolean updateAssignProperty(EvaluationFactor evaluationFactor, String[] attributes) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<EvaluationFactor> updateAssignPropertyVo = new UpdateAssignPropertyVo<EvaluationFactor>();
		updateAssignPropertyVo.setEntity(evaluationFactor);
		updateAssignPropertyVo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(updateAssignPropertyVo));//.jsonObjectToStr(updateAssignPropertyVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
    
    /**
     * @Description: 通过id 获取评审指标信息
     * @author mazc
     * @param id
     * @return
     */
    public EvaluationFactor findById(String id) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getById");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("id", id);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 通过Tendid parentId 查找 id factorName factorScore factorWeight
     * @author mazc
     * @param tenderId
     * @param evaluationFactor
     * @return
     */
    public List<EvaluationFactor> findTenderAndParentId(String tenderId, String parentId, String[] auditType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findTenderAndParentId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("parentId", parentId);
        if (null != auditType && auditType.length > 0) {
            param.put("auditType", new String[] { EvaluationFactorEnum.AUDIT_SCORE, EvaluationFactorEnum.AUDIT_PRICE });
        }
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    public Integer findItemizedPriceSize(String tenderId, String auditType, String id) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findItemizedPriceSize");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        if (StringUtils.isNotEmpty(id)) {
            param.put("id", id);
        }
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            return 0;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return 0;
        }
    }
    
    /**
     * @Description: 通过idlist 获取评审指标列表
     * @author mazc
     * @param list
     * @return
     */
    public List<EvaluationFactor> findIds(List<String> idList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findBatchIdsList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("idList", idList);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存或新建
     * @author mazc
     * @param factor
     * @return
     */
    public EvaluationFactor saveOrUpdateComplianceEvaluationFactor(EvaluationFactor factor) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdateComplianceEvaluationFactor");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(factor));
            if (ResultStatus.getReultStatusOK(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存或修改打分评审指标
     * @author mazc
     * @param factor
     * @param changeWeigth
     * @return
     */
    public EvaluationFactor saveEvaluationFactor(EvaluationFactor factor, boolean changeWeigth) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveEvaluationFactor");
        RequestBody<EvaluationFactor> requestBody = new RequestBody<EvaluationFactor>();
        requestBody.setEntity(factor);
        requestBody.setParam("changeWeigth", changeWeigth);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 删除
     * @author mazc
     * @param factor
     * @return
     */
    public int deleteEvaluationFactor(EvaluationFactor factor) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteEvaluationFactor");
        try {
        	EvaluationFactor deleteFactor = new EvaluationFactor();
        	deleteFactor.setId(factor.getId());
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(deleteFactor));
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("deleteEvaluationFactor");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 获得价格指标
     * @author guoyr
     * @param tenderId
     * @return
     */
    public EvaluationFactor getPriceEvaluationFactor(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getPriceEvaluationFactor");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 交换两个指标的排序
     * @author chenxw
     * @param source
     * @param target
     */
    public void changeEvaluationFactorSortNo(EvaluationFactor source, EvaluationFactor target) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/changeEvaluationFactorSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("sourceId", source.getId());
        param.put("targetId", target.getId());
        try {
            NetworkRequest.get(strWebServerUrl, param);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }
    
    /**
     * @Description: 获得指标的最大序号
     * @author mazc
     * @param tenderId
     * @param auditType
     * @param parentId
     * @return
     */
    public int getMaxEvaluationFactorSortNo(String tenderId, String auditType, String parentId) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxEvaluationFactorSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        param.put("parentId", parentId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("getMaxEvaluationFactorSortNo");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    /**
     * @Description: 获得指标的最大序号
     * @author mazc
     * @param tenderId
     * @param auditType
     * @param parentId
     * @return
     */
    public int getEvaluationFactorCount(String tenderId, String auditType) {
    	//获取服务器地址
    	String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationFactorCount");
    	Map<String, Object> param = new HashMap<String, Object>();
    	param.put("tenderId", tenderId);
    	param.put("auditType", auditType);
    	try {
    		String result = NetworkRequest.get(strWebServerUrl, param);
    		if (ResultStatus.isReultStatusInteger(result)) {
    			return Integer.valueOf(result);
    		}
    		logger.error("getEvaluationFactorCount");
    		return -1;
    	} catch (Exception e) {
    		logger.error(e.getMessage(), e);
    		return -1;
    	}
    }
    
    /**
     * @Description: 获得全部的指标
     * @author mazc
     * @param tenderId id
     * @param auditType 类型
     * @return
     */
    public List<EvaluationFactor> getAllEvaluationFactorList(String tenderId, String auditType) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllEvaluationFactorList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (result.isEmpty()) {
                return new ArrayList<EvaluationFactor>();
            }
            return JsonUtil.jacksonToList(result, EvaluationFactor.class);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 导入投标报价指标
     * @author mazc
     * @param tenderId
     * @param parentFactor
     * @return
     */
    public int importBidPriceFactor(String tenderId, EvaluationFactor parentFactor) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/importBidPriceFactor");
        RequestBody<EvaluationFactor> requestBody = new RequestBody<EvaluationFactor>();
        requestBody.setEntity(parentFactor);
        requestBody.setParam("tenderId", tenderId);
        try {
        	String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(requestBody));
//            String result = NetworkRequest.get(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("importBidPriceFactor");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 导入指标
     * @author guoyr
     * @param tenderId
     * @param complianceFactorList 符合性指标
     * @param detailFactorList 打分指标
     * @param priceFactorList 价格指标
     * @return
     */
    public boolean importEvaluationFactor(String tenderId, List<EvaluationFactor> complianceFactorList, List<EvaluationFactor> detailFactorList, List<EvaluationFactor> priceFactorList, List<EvaluationFactor> billFactorList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/importEvaluationFactor");
        ImportEvaluationFactorVo importEvaluationFactorVo = new ImportEvaluationFactorVo();
        importEvaluationFactorVo.setTenderId(tenderId);
        importEvaluationFactorVo.setComplianceFactorList(complianceFactorList);
        importEvaluationFactorVo.setDetailFactorList(detailFactorList);
        importEvaluationFactorVo.setPriceFactorList(priceFactorList);
        importEvaluationFactorVo.setBillFactorList(billFactorList);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(importEvaluationFactorVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 删除所有指标
     * @author mazc
     * @param tenderId
     */
    public void delAllEvaluationFactor(String tenderId) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/delAllEvaluationFactor");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            NetworkRequest.get(strWebServerUrl, param);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return;
        }
    }
    
    /**
     * @Description: 按分类删除指标
     * @author mazc
     * @param tenderId
     * @param auditType
     * @return
     */
    public int delEvaluationFactorByType(String tenderId, String auditType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/delEvaluationFactorByType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("delEvaluationFactorByType");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 获得可为评标步骤分配置的指标
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    public List<EvaluationFactor> getFactorListOfEvaluationStep(String tenderId, String auditType, String stepId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getFactorListOfEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @return
     */
    public List<EvaluationFactor> getEvaluationStepFactorTreeList(String tenderId, EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepFactorTreeList");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        requestBody.setParam("tenderId", tenderId);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得专家在指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    public List<EvaluationFactor> getExpertEvaluationStepFactorTreeList(String tenderId, EvaluationStep evaluationStep, String userId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertEvaluationStepFactorTreeList");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        requestBody.setParam("tenderId", tenderId);
        requestBody.setParam("userId", userId);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取项目下指定类型的指标的主键
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    public List<String> getFactorIdList(String tenderId, String auditType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getFactorIdList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, String.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存下载的评审指标
     * @author guoyr
     * @param tenderId
     * @param evaluationFactorList
     * @return
     */
    public int saveDownloadEvaluationFactor(String tenderId, List<EvaluationFactor> evaluationFactorList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveDownloadEvaluationFactor");
        RequestBody<EvaluationFactor> requestBody = new RequestBody<EvaluationFactor>(evaluationFactorList);
        requestBody.setParam("tenderId", tenderId);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("saveDownloadEvaluationFactor");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 获得指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return
     */
    public List<EvaluationFactor> getEvaluationStepFactorList(String tenderId, EvaluationStep evaluationStep, boolean removeTopOnly) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepFactorList");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        requestBody.setParam("tenderId", tenderId);
        requestBody.setParam("removeTopOnly", removeTopOnly);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得专家在指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return
     */
    public List<EvaluationFactor> getExpertEvaluationStepFactorList(String tenderId, EvaluationStep evaluationStep, String userId, boolean removeTopOnly) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertEvaluationStepFactorList");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        requestBody.setParam("tenderId", tenderId);
        requestBody.setParam("userId", userId);
        requestBody.setParam("removeTopOnly", removeTopOnly);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得父级评审指标分值
     * @param tenderId
     * @param stepId
     * @return
     */
    public BigDecimal getParentFactorScore(String tenderId, String stepId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getParentFactorScore");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBigDecimal(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得指定专家对投标人的评标结果
     * @author guoyr
     * @param tenderId
     * @param userId
     * @param supplierId
     * @param stepId
     * @param auditType
     * @return
     */
    public List<EvaluationFactor> getEvaluationFactorResultList(String tenderId, String userId, String supplierId, String stepId, String auditType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationFactorResultList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("userId", userId);
        param.put("supplierId", supplierId);
        param.put("stepId", stepId);
        param.put("auditType", auditType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 验证是否已经存在投标总报价价格指标
     * @author mazc
     * @param tenderId
     * @param factorId
     * @return
     */
    public boolean hasTotalBidPriceFactor(String tenderId, String factorId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/hasTotalBidPriceFactor");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("factorId", factorId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 获得指定指标类形的权重
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    public BigDecimal getWeightByAuditType(String tenderId, String auditType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getWeightByAuditType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("auditType", auditType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBigDecimal(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 根据清单类型获取清单指标
     * @author chenxw
     * @param tenderId
     * @param billType
     * @return
     */
    public EvaluationFactor getBillFactoryByType(String tenderId, String billType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getBillFactoryByType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("billType", billType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }

    /**
     * @Description: 批量保存
     * @author chenxw
     * @param evaluationFactorList
     * @return 
     */
    public boolean batchSave(List<EvaluationFactor> evaluationFactorList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/batchSave");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(evaluationFactorList));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }

    /**
     * @Description: 根据项目id获取指标列表
     * @author chenxw
     * @param tenderId
     * @return 
     */
    public List<EvaluationFactor> getFactorListByTenderId(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getFactorListByTenderId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jacksonToList(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }

    /**
     * @Description: 根据指标编号获取指标
     * @author chenxw
     * @param tenderId
     * @param factorCode
     * @return 
     */
    public EvaluationFactor getFactorByFactorCode(String tenderId, String factorCode) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getFactorByFactorCode");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("factorCode", factorCode);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationFactor.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }

    /**
	 * @Description: 插入
	 * @author chenxw
	 * @param evaluationStep
	 * @return 
	 */
	public boolean insert(EvaluationFactor evaluationFactor) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationFactor));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
    
	/** 
     * @Description: 保存商务指标
     * @author chenxw
     * @param tenderProject
     * @param businessFactor
     * @return 
     */
	public boolean saveBusinessFactor(TenderProjectEntity tenderProject, EvaluationFactor businessFactor) {
		SaveBusinessFactorVo saveBusinessFactorVo = new SaveBusinessFactorVo();
		saveBusinessFactorVo.setTenderProject(tenderProject);
		saveBusinessFactorVo.setBusinessFactor(businessFactor);
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveBusinessFactor");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveBusinessFactorVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

}
