package com.gx.obe.web.service.evaluation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.CollectionUtils;
import com.gx.obe.web.entity.evaluation.EvaluationGroup;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 评审分组数据接口
 * @author mazc 
 */
public class EvaluationGroupService {
	
	static final String URL = "evaluationGroup";

	private Logger logger = Logger.getLogger(EvaluationGroupService.class);
	
	
	/**
     * @Description: 根据用户id获取评审分组
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param stepId
     * @return
     */
    private List<EvaluationGroup> getEvaluationGroupByUserId(String tenderId, String userId, String stepId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationGroupByUserId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("userId", userId);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.strToList(result, EvaluationGroup.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取当前项目（标段）下的评审分组
     * @author chenxw
     * @param tenderId
     * @return
     */
    public Map<String, Map<String, EvaluationGroup>> getGroupTypeMapSupplierMap(String tenderId) {
        List<EvaluationGroup> resultList = getEvaluationGroupByUserId(tenderId, null, null);
        Map<String, Map<String, EvaluationGroup>> groupTypeMapSupplierMap = new HashMap<String, Map<String, EvaluationGroup>>();;
        if (CollectionUtils.isNotNull(resultList)) {
            for (EvaluationGroup evaluationGroup : resultList) {
                String supplierId = evaluationGroup.getSupplierId();
                String evalBidType = evaluationGroup.getEvalBidType();
                if (groupTypeMapSupplierMap.containsKey(supplierId)) {
                    groupTypeMapSupplierMap.get(supplierId).put(evalBidType, evaluationGroup);
                } else {
                    Map<String, EvaluationGroup> groupTypeMap = new HashMap<String, EvaluationGroup>();
                    groupTypeMap.put(evalBidType, evaluationGroup);
                    groupTypeMapSupplierMap.put(supplierId, groupTypeMap);
                }
            }
        }
        return groupTypeMapSupplierMap;
    }
    
    public Map<String, List<String>> getEvalBidTypeListSupplierIdMapByUserId(String tenderId, String userId) {
        List<EvaluationGroup> resultList = getEvaluationGroupByUserId(tenderId, userId, null);
        Map<String, List<String>> evalBidTypeListSupplierIdMap = new HashMap<String, List<String>>();
        if (CollectionUtils.isNotNull(resultList)) {
            for (EvaluationGroup evaluationGroup : resultList) {
                String supplierId = evaluationGroup.getSupplierId();
                String evalBidType = evaluationGroup.getEvalBidType();
                if (evalBidTypeListSupplierIdMap.containsKey(supplierId)) {
                    evalBidTypeListSupplierIdMap.get(supplierId).add(evalBidType);
                } else {
                    List<String> evalBidTypeList = new ArrayList<String>();
                    evalBidTypeList.add(evalBidType);
                    evalBidTypeListSupplierIdMap.put(supplierId, evalBidTypeList);
                }
            }
        }
        return evalBidTypeListSupplierIdMap;
    }
    
    /**
     * @Description: 根据用户id获得评审类型数据
     * @author chenxw
     * @param tenderId
     * @param userId
     * @return
     */
    public Map<String, List<String>> getSupplierIdListEvalBidTypeMapByUserId(String tenderId, String userId, String stepId) {
        List<EvaluationGroup> resultList = getEvaluationGroupByUserId(tenderId, userId, stepId);
        Map<String, List<String>> supplierIdListEvalBidTypeMap = new HashMap<String, List<String>>();
        if (CollectionUtils.isNotNull(resultList)) {
            for (EvaluationGroup evaluationGroup : resultList) {
                String evalBidType = evaluationGroup.getEvalBidType();
                String supplierId = evaluationGroup.getSupplierId();
                if (supplierIdListEvalBidTypeMap.containsKey(evalBidType)) {
                    supplierIdListEvalBidTypeMap.get(evalBidType).add(supplierId);
                } else {
                    List<String> supplierIdList = new ArrayList<String>();
                    supplierIdList.add(supplierId);
                    supplierIdListEvalBidTypeMap.put(evalBidType, supplierIdList);
                }
            }
        }
        return supplierIdListEvalBidTypeMap;
    }
    
    /**
     * @Description: 是否含有当前用户的分组信息
     * @author chenxw
     * @param tenderId
     * @param userId
     * @return
     */
    public boolean isHasEvaluationGroupByUserId(String tenderId, String userId, String stepId) {
        return CollectionUtils.isNotNull(getEvaluationGroupByUserId(tenderId, userId, stepId));
    }
    
    /**
     * @Description: 获取评审分组用户数量
     * @author chenxw
     * @param id
     * @return
     */
    public int getEvaluationGroupUserCount(String tenderId, String stepId) {
        List<EvaluationGroup> resultList = getEvaluationGroupByUserId(tenderId, null, stepId);
        if (CollectionUtils.isNull(resultList)) {
            return 0;
        }
        for (int i = 0; i < resultList.size() - 1; i++) {
            for (int j = resultList.size() - 1; j > i; j--) {
                if (resultList.get(i).getUserId().equals(resultList.get(j).getUserId())) resultList.remove(j);
            }
        }
        return resultList.size();
    }
	
    /**
     * @Description: 批量保存
     * @author wangxiang
     * @param evaluationGroupList
     * @return 
     */
    public int batchSave(List<EvaluationGroup> evaluationGroupList) {
        String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
        try{
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationGroupList));
            if(ResultStatus.isReultStatusInteger(result)){
                 return Integer.valueOf(result);
            }
            return 0;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 删除评审分组
     * @author wangxiang
     * @param tenderId 
     */
    public boolean deleteByTenderId(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteByTenderId");
        //请求参数
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try{
            String result = NetworkRequest.get(strWebServerUrl, param);
            if(ResultStatus.getReultStatusIsNotEmpty(result)){
                 return ResultStatus.isReultStatusInteger(result);
            }
            return false;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 删除评审分组
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @return 
     */
    public int deleteByTenderIdAndStepId(String tenderId,String stepId){
        String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteByTenderIdAndStepId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        try{
            String result = NetworkRequest.get(strWebServerUrl, param);
            if(ResultStatus.isReultStatusInteger(result)){
                 return Integer.valueOf(result);
            }
            return 0;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
}
