package com.gx.obe.web.service.evaluation;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.EvaluationReport;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class EvaluationReportService {
	
	static final String URL = "evaluationReport";
	
	private Logger logger = Logger.getLogger(EvaluationReportService.class);
	
	/**
	 * @Description: 删除专家的评标报表
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param stepId 
	 */
	public boolean deleteUserEvaluationReport(String tenderId, String userId, String stepId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getUserEvaluationReport");
 		Map<String, Object> param = new HashMap<String, Object>();		
		param.put("userId", userId);
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			 return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得专家的评标报表
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param stepId
	 * @return 
	 */
	public EvaluationReport getUserEvaluationReport(String tenderId, String userId, String stepId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getUserEvaluationReport");
 		Map<String, Object> param = new HashMap<String, Object>();		
		param.put("userId", userId);
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, EvaluationReport.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/** 
	 * @Description: 保存专家的评标记录
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param evaluationStepId
	 * @param reportByte
	 * @return 
	 */
	public EvaluationReport insertEvaluationReport(String tenderId, String userId, String evaluationStepId, String reportName, long lastModified, byte[] reportByte){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insertEvaluationReport");
 		EvaluationReport evaluationReport = new EvaluationReport();
		evaluationReport.setId(UuidUtils.getUUID());
		// 这里可以使用系统时间，只用作标识
		evaluationReport.setReportName(reportName);
		evaluationReport.setTenderId(tenderId);
		evaluationReport.setUserId(userId);
		evaluationReport.setStepId(evaluationStepId);
		evaluationReport.setModifyTime(new Date(lastModified));
		evaluationReport.setReportByte(reportByte);
		RequestBody<EvaluationReport> requestBody = new RequestBody<EvaluationReport>();
		requestBody.setEntity(evaluationReport);
		requestBody.setParam("tenderId", tenderId);
		requestBody.setParam("userId", userId);
		requestBody.setParam("evaluationStepId", evaluationStepId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, EvaluationReport.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<EvaluationReport> getEvaluationReportListByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationReportListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();		
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, EvaluationReport.class);
			}
			 return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
		
	}
	
}
