package com.gx.obe.web.service.evaluation;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.evaluation.EvaluationRoom;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 
 * @author mazc 
 */
public class EvaluationRoomService {
	
	static final String URL = "evaluationroom";
	
	private Logger logger = Logger.getLogger(EvaluationRoomService.class);
	 /**   
	 * @Title: getBidOpeningRoomList   
	 * @Description: 通过状态查询开标室列表
	 * @param: @param useStatus
	 * @param: @return      
	 * @return: List<BidOpeningRoom>      
	 * @throws   
	 */  
	public List<EvaluationRoom> getEvaluationRoomList(String useStatus){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/evaluationroomlist");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("useStatus", useStatus);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, EvaluationRoom.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得当前评标区下的全部评标室集合
	 * @author mazc
	 * @param evaluationAreaId
	 * @return
	 */
	public List<EvaluationRoom> getEvaluatoinRoomList(String evaluationAreaId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluatoinRoomListByEvaluationAreaId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("evaluationAreaId", evaluationAreaId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, EvaluationRoom.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		
	}
	
	/**
	 * @Description: 根据项目Id和评标区Id，获得已分配的评标室。
	 * @author mazc
	 * @param tenderId 项目Id
	 * @param evaluationAreaId 评标区Id
	 * @return
	 */
	public List<EvaluationRoom> getProjectEvaluationRoomList(String tenderId, String evaluationAreaId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getProjectEvaluationRoomList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("evaluationAreaId", evaluationAreaId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.strToList(result, EvaluationRoom.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 删除当前评标室
	 * @author mazc
	 * @param tenderId
	 * @return
	 */
	public boolean deleteEvaluationRoom(String roomId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteEvaluationRoom");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("roomId", roomId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);		 
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 查询评标室
	 * @author wangxiang
	 * @param roomId
	 * @param evalRoomName
	 * @return
	 */
	public List<EvaluationRoom> queryEvaluationRoomList(){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/queryEvaluationRoomList");
  		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, EvaluationRoom.class);
			}
			return null;		 
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public EvaluationRoom getById(String id){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, EvaluationRoom.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	} 
	
	public EvaluationRoom saveOrUpdateReturn(EvaluationRoom evaluationRoom){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveOrUpdateReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationRoom));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, EvaluationRoom.class);				
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<Object> getEvaluationRoomIdList(String id ,String evalRoomName,String evaluationAreaId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationRoomIdList");
		Map<String, Object> param = new HashMap<String, Object>();
		if(null != id){
			param.put("id", id);			
		}
		param.put("evalRoomName", evalRoomName);	
		param.put("evaluationAreaId", evaluationAreaId);	
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.StrToCollection(result, Object.class);			
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
