package com.gx.obe.web.service.evaluation;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.EvaluationStepFactor;
import com.gx.obe.business.entity.ExpertEvaluationStep;
import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.EvaluationStepEnum;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.evaluation.EvaluationFactor;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import com.gx.obe.web.entity.tender.TenderProjectEntity;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.BatchUpdatePropertyVo;
import com.gx.obe.web.vo.CreateEvaluationStepsVo;
import com.gx.obe.web.vo.SaveEvaluationStepAndFactorsVo;
import com.gx.obe.web.vo.SaveEvaluationStepVo;
import com.gx.obe.web.vo.SaveWasteBidStepVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

/**
 * @Description:
 * @author mazc
 */
public class EvaluationStepService {
    
    static final String URL = "evaluationStep";
    
    private Logger logger = Logger.getLogger(EvaluationStepService.class);
    
    /**
     * @Description: 获取项目下指定步骤
     * @author mazc
     * @return
     */
    public List<String> getIdByTenderIdCount(String tenderId) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/stepByTenderIdCount");
        //请求地址
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.StrToCollection(result, String.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 通过指标获得该指标所在的评标步骤
     * @author mazc
     * @param tenderId
     * @param factorId
     * @return
     */
    public EvaluationStep getEvaluationStepByFactor(String tenderId, String factorId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findByTenderIdAndFactorId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("factorId", factorId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 查询指定评审类型的评标步骤列表
     * @author mazc
     * @param tenderId
     * @param stepType
     * @return
     */
    public List<EvaluationStep> getEvaluationStepListByType(String tenderId, String stepType) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findEvaluationStepListByType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepType", stepType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 查询评标步骤列表
     * @author mazc
     * @param tenderId
     * @return
     */
    public List<EvaluationStep> getEvaluationStepList(String tenderId) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findEvaluationStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得评审要素下可评审的评标步骤
     * @author mazc
     * @param tenderId
     * @param evalGroup
     * @return
     */
    public List<String> getEvalGroupEvalStepList(String tenderId, String evalGroup) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findEvalGroupEvalStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("evalGroup", evalGroup);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.StrToCollection(result, String.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得指定评标步骤以前未评审的节点
     * @author mazc
     * @param tenderId
     * @param sortNo
     * @return
     */
    public EvaluationStep getPreNoStarEvaluationStep(String tenderId, int sortNo) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findPreNoStarEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("sortNo", sortNo);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    public EvaluationStep getById(String id) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getById");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("id", id);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
        
    }
    
    /**
     * @Description: 获得指定序号的评标步骤
     * @author guoyr
     * @param tenderId
     * @param sortNo
     * @return
     */
    public EvaluationStep getEvaluationStepBySortNo(String tenderId, int sortNo) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepBySortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("sortNo", sortNo);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得评标步骤的最大序号
     * @author guoyr
     * @param tenderId
     * @return
     */
    public int getMaxEvaluationStepSortNo(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getMaxEvaluationStepSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("getMaxEvaluationStepSortNo");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 交换评审结点的顺序
     * @author guoyr
     * @param source
     * @param target
     */
    public boolean changeEvaluationStepSortNo(EvaluationStep source, EvaluationStep target) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/changeEvaluationStepSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("source", source.getId());
        param.put("target", target.getId());
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 删除评标步骤
     * @author guoyr
     * @param EvaluationStep
     * @return
     */
    public boolean deleteEvaluationStep(EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteEvaluationStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 保存签到评标步骤
     * @author guoyr
     * @param evaluationStep
     * @return
     */
    public EvaluationStep saveSignEvaluationStep(EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveSignEvaluationStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存特征码检查评标步骤
     * @author guoyr
     * @param evaluationStep
     * @param stepExpertUserList
     * @param featureItemObjIdList
     * @return
     */
    public EvaluationStep saveFeatureEvaluationStep(EvaluationStep evaluationStep, List<String> stepExpertUserList, List<String> featureItemObjIdList) {
        SaveEvaluationStepVo saveEvaluationStepVo = new SaveEvaluationStepVo();
        saveEvaluationStepVo.setEvaluationStep(evaluationStep);
        saveEvaluationStepVo.setItemObjIdList(featureItemObjIdList);
        saveEvaluationStepVo.setStepExpertUserList(stepExpertUserList);
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveFeatureEvaluationStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveEvaluationStepVo));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存清标检查评标步骤
     * @author guoyr
     * @param evaluationStep
     * @param stepExpertUserList
     * @param cleanTenderItemObjIdList
     * @return
     */
    public EvaluationStep saveCleanTenderEvaluationStep(EvaluationStep evaluationStep, List<String> stepExpertUserList, List<String> cleanTenderItemObjIdList) {
        SaveEvaluationStepVo saveEvaluationStepVo = new SaveEvaluationStepVo();
        saveEvaluationStepVo.setEvaluationStep(evaluationStep);
        saveEvaluationStepVo.setItemObjIdList(cleanTenderItemObjIdList);
        saveEvaluationStepVo.setStepExpertUserList(stepExpertUserList);
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveCleanTenderEvaluationStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveEvaluationStepVo));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存评标步骤和评审指标
     * @author guoyr
     * @param evaluationStep
     * @param evaluationFactorList
     * @return
     */
    public EvaluationStep saveEvaluationStepAndFactors(EvaluationStep evaluationStep, List<EvaluationFactor> evaluationFactorList, List<String> factorWeightList, List<String> stepExpertUserList) {
        SaveEvaluationStepAndFactorsVo saveEvaluationStepAndFactorsVo = new SaveEvaluationStepAndFactorsVo();
        saveEvaluationStepAndFactorsVo.setEvaluationStep(evaluationStep);
//        saveEvaluationStepAndFactorsVo.setEvaluationFactorList(evaluationFactorList);
        if(null != evaluationFactorList) {
        	List<EvaluationFactor> tempEvaluationFactorList = new ArrayList<EvaluationFactor>();
        	for(EvaluationFactor evaluationFactor : evaluationFactorList) {
        		EvaluationFactor tempFactor = new EvaluationFactor();
        		tempFactor.setId(evaluationFactor.getId());;
        		tempFactor.setTenderId(evaluationFactor.getTenderId());
        		tempFactor.setAuditType(evaluationFactor.getAuditType());
        		tempFactor.setFactorType(evaluationFactor.getFactorType());
        		tempEvaluationFactorList.add(tempFactor);
        	}
        	saveEvaluationStepAndFactorsVo.setEvaluationFactorList(tempEvaluationFactorList);
        }
        saveEvaluationStepAndFactorsVo.setFactorWeightList(factorWeightList);
        saveEvaluationStepAndFactorsVo.setStepExpertUserList(stepExpertUserList);
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveEvaluationStepAndFactors");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(saveEvaluationStepAndFactorsVo));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    public EvaluationStep saveTianYanEvaluationStep(EvaluationStep evaluationStep, List<String> stepExpertUserList){
    	 SaveEvaluationStepAndFactorsVo saveEvaluationStepAndFactorsVo = new SaveEvaluationStepAndFactorsVo();
    	 saveEvaluationStepAndFactorsVo.setEvaluationStep(evaluationStep);
    	 saveEvaluationStepAndFactorsVo.setStepExpertUserList(stepExpertUserList);
    	 String strWebServerUrl = Constants.getServiceUrl(URL + "/saveTianYanEvaluationStep");
    	try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jacksonObjectToStr(saveEvaluationStepAndFactorsVo));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存评标步骤
     * @author guoyr
     * @param evaluationStep
     * @return
     */
    public EvaluationStep saveEvaluationStep(EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveEvaluationStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 创建废标步骤
     * @author guoyr
     * @param tenderProjectEntity
     * @param evaluationStep
     */
    public EvaluationStep saveWasteBidStep(TenderProjectEntity tenderProject, EvaluationStep evaluationStep) {
        SaveWasteBidStepVo saveWasteBidStepVo = new SaveWasteBidStepVo();
        saveWasteBidStepVo.setTenderProject(tenderProject);
        saveWasteBidStepVo.setEvaluationStep(evaluationStep);
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveWasteBidStep");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveWasteBidStepVo));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 验证评标步骤的名称是否已经存在
     * @author guoyr
     * @param tenderId
     * @param id
     * @param stepName
     * @return
     */
    public boolean valEvaluationStepNameExist(String tenderId, String id, String stepName) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/valEvaluationStepNameExist");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("id", id);
        param.put("stepName", stepName);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 设置默认评标步骤
     * @author guoyr
     * @param tenderId
     * @return
     */
    public boolean createDefaultEvaluationSteps(String tenderId, String siginStepName, String complianceStepName, String detailStepName, String priceStepName, String recommonedStepName, String SHOW_SUMMARY_COMPLIANCE, String SHOW_SUMMARY_SCORE) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/createDefaultEvaluationSteps");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("siginStepName", siginStepName);
        param.put("complianceStepName", complianceStepName);
        param.put("detailStepName", detailStepName);
        param.put("priceStepName", priceStepName);
        param.put("recommonedStepName", recommonedStepName);
        param.put("SHOW_SUMMARY_COMPLIANCE", SHOW_SUMMARY_COMPLIANCE);
        param.put("SHOW_SUMMARY_SCORE", SHOW_SUMMARY_SCORE);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 设置默认评标步骤
     * @author guoyr
     * @param tenderId
     * @return
     */
    public boolean createEvaluationSteps(String tenderId, List<EvaluationStep> nodeList, List<EvaluationStepFactor> evaluationStepFactorList) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/createEvaluationSteps");
        CreateEvaluationStepsVo createEvaluationStepsVo = new CreateEvaluationStepsVo();
        createEvaluationStepsVo.setTenderId(tenderId);
        createEvaluationStepsVo.setNodeList(nodeList);
        createEvaluationStepsVo.setEvaluationStepFactorList(evaluationStepFactorList);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(createEvaluationStepsVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 清空项目的评标步骤
     * @author guoyr
     * @param tenderId
     * @return
     */
    public boolean deleteAllEvaluationSteps(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteAllEvaluationSteps");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 重新授权评标步骤，并重新授权推荐
     * @author guoyr
     * @param tenderId
     * @param nodeSortNo
     * @param isFilter 是否筛选节点
     */
    public void reBackEvaluationStep(EvaluationStep evaluationStep, ExpertEvaluationStep expertEvaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/reBackEvaluationStep");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        if (expertEvaluationStep != null) {
            requestBody.setParam("userId", expertEvaluationStep.getUserId());
        }
        try {
        	NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }
    
    /**
     * @Description: 获得最后一个评标步骤
     * @author guoyr
     * @param tenderId
     * @return
     */
    public EvaluationStep getLastEvaluationStep(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getLastEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得存在评审不通过投标人的评标步骤
     * @author guoyr
     * @param tenderId
     * @return
     */
    public List<EvaluationStep> getDisAccessmentNode(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getDisAccessmentNode");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 验证评标步骤是否正在评标步骤中被退回
     * @author guoyr
     * @param evaluationStep
     * @return
     */
    public boolean isEvaluationStepRebackedInProgress(EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/isEvaluationStepRebackedInProgress");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 获得评标步骤的权重
     * @author guoyr
     * @param evaluationStep
     * @return
     */
    public BigDecimal getEvaluationStepWeight(EvaluationStep evaluationStep) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepWeight");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
            return ResultStatus.getReultStatusBigDecimal(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得评标步骤的分值
     * @author guoyr
     * @param evaluationStep
     * @param weightScore 权重分值
     * @return
     */
    public BigDecimal getEvaluationStepScore(EvaluationStep evaluationStep, boolean weightScore) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepScore");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>(evaluationStep);
        requestBody.setParam("weightScore", weightScore);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            return ResultStatus.getReultStatusBigDecimal(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 根据项目id,专家用户id(userId)查找当前专家所拥有的评标步骤
     * @author guoyr
     * @param tendertId
     * @param userId
     * @return
     */
    public List<EvaluationStep> getEvaluationStepByUserId(String tenderId, String userId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepByUserId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 根据项目评审点id查询当前评审点所属评标步骤
     * @author guoyr
     * @param tendertId
     * @param factorId
     * @return
     */
    public EvaluationStep getEvaluationStepByFactorId(String tenderId, String factorId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepByFactorId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("factorId", factorId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得已完成步骤最大编号
     * @author wangxiang
     * @param tenderId
     * @param stepStatus
     * @return
     */
    public int getMAXStepCount(String tenderId, String stepStatus) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getMAXStepCount");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepStatus", stepStatus);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            logger.error("getMAXStepCount");
            return -1;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return -1;
        }
    }
    
    /**
     * @Description: 更新添加步骤后后面步骤+1
     * @author wangxiang
     * @param tenderId
     * @param maxComplateIndex
     */
    public void updateSortNo(String tenderId, int maxComplateIndex) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateSortNo");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("maxComplateIndex", maxComplateIndex);
        try {
            NetworkRequest.get(strWebServerUrl, param);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }
    
    /**
     * @Description:获取未完成的评审步骤列表
     * @author chenxw
     * @param tenderId
     * @param stepSortNo
     * @return
     */
    public List<EvaluationStep> getNotComplateStepList(String tenderId, int stepSortNo) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getNotComplateStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepSortNo", stepSortNo);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获取存在废标的未完成评审步骤列表
     * @author chenxw
     * @param tenderId
     * @param stepSortNo
     * @return
     */
    public List<EvaluationStep> getNotComplateFilterStepList(String tenderId, int stepSortNo) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getNotComplateFilterStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepSortNo", stepSortNo);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 当前步骤是否在评审中
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @return
     */
    public boolean isInEvaluationStep(String tenderId, String stepId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/isInEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 删除专家组长评标结果
     * @author chenxw
     * @param tenderId
     */
    public void deleteExpertLeaderEvaluationStepResult(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteExpertLeaderEvaluationStepResult");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
        	NetworkRequest.get(strWebServerUrl, param);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }
    
    /**
     * @Description:是否完成商务技术评审
     * @author guoyr
     * @param tenderId
     * @return
     */
    public boolean isComplateBusAndTecEvaluation(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/isComplateBusAndTecEvaluation");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 获得价格评审和推荐的步骤完成步骤
     * @author wangxiang
     * @param tenderId
     * @return
     */
    public List<EvaluationStep> getPriceOrRecommEvaluationStepList(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getPriceOrRecommEvaluationStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, EvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 批量指定字段修改
     * @author chenxw
     * @param evaluationStepList
     * @param attributes
     * @return 
     */
    public int batchUpdateProperty(List<EvaluationStep> evaluationStepList, String[] attributes) {
        //请求地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/batchUpdateProperty");
        BatchUpdatePropertyVo<EvaluationStep> batchUpdatePropertyVo = new BatchUpdatePropertyVo<EvaluationStep>();
        batchUpdatePropertyVo.setEntityList(evaluationStepList);
        batchUpdatePropertyVo.setAttributes(attributes);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(batchUpdatePropertyVo));
            if (ResultStatus.isReultStatusInteger(result)) {
                return Integer.valueOf(result);
            }
            return 0;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return 0;
        }
    }
    
    /**
     * @Description: 是否完成价格或推荐中标候选人步骤
     * @author chenxw
     * @param tenderId
     * @return
     */
    public boolean isCompletePriceAndRecommonedStep(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/isCompletePriceAndRecommonedStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 是否含有评标步骤
     * @author chenxw
     * @param tenderId
     * @return
     */
    public boolean isHasEvaluationStep(String tenderId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/isHasEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }

    /**
     * @Description: 根据id更新指定字段
     * @author chenxw
     * @param evaluationStep
     * @param strings 
     */
    public boolean updateAssignProperty(EvaluationStep evaluationStep, String[] strs) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
        UpdateAssignPropertyVo<EvaluationStep> updateAssignPropertyVo = new UpdateAssignPropertyVo<EvaluationStep>();
        updateAssignPropertyVo.setEntity(evaluationStep);
        updateAssignPropertyVo.setAttributes(strs);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }

	/**
	 * @Description: 插入
	 * @author chenxw
	 * @param evaluationStep
	 * @return 
	 */
	public boolean insert(EvaluationStep evaluationStep) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(evaluationStep));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * 判断是否存在暗标步骤
	 * 
	 */
	public boolean isSealed(TenderProjectEntity tenderProject) {
		boolean isSealed = false;
		List<EvaluationStep> evaluationStepList = getEvaluationStepList(tenderProject.getId());
		if (null != evaluationStepList && evaluationStepList.size() > 0) {
			for (EvaluationStep evaluationStep : evaluationStepList) {
				isSealed = evaluationStep.getEvaluationParamByKey(EvaluationStepEnum.PARAM_SEALED_BID, Boolean.class);
				if (isSealed) {
					break;
				}
			}
		}
		return isSealed;
	}
	
}
