package com.gx.obe.web.service.expert;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.expert.ExpertEvaluationResult;
import com.gx.obe.web.utils.ResultStatus;

/** 
 * @Description: 专家评标结果服务
 * @author mazc 
 */
public class ExpertEvaluationResultService {
	
	static final String URL = "expertEvaluationResult";
	
	private Logger logger = Logger.getLogger(ExpertEvaluationResultService.class);
	

	/**
	 * @Description: 获得评标专家对指定评标步骤对投标人的评审记录
	 * @author mazc
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return 
	 */
	public List<ExpertEvaluationResult> getStepAllExpertEvaluationResultList(String tenderId, String stepId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getStepAllExpertEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);	 
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;	
	}
	
	/**
	 * @Description: 删除评标专家对指定评标步骤的所有评审记录
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return
	 */
	public int deleteExpertEvaluationResult(String tenderId, String stepId, String userId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteExpertEvaluationResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				ResultStatus.isReultStatusInteger(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
		return 0;
	}
	
	
	/**
	 * @Description: 获得供应商在指定评标步骤的所有专家的评标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @return 
	 */
	public List<ExpertEvaluationResult> getSupplierStepAllExpertEvaluationResultList(String tenderId, String stepId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierStepAllExpertEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 按供应商分组获得每家供应商的评分汇总 
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return 
	 */
	public List<Map<String, Object>> getSupplierSumEvaluationResultList(String tenderId, String stepId, String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierSumEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToListMap(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获得供应商在指定评标步骤的平均得分
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @param removeMaxAndMin
	 * @return 
	 */
	public BigDecimal[] getSupplierStepAvgResult(String tenderId, String stepId, String supplierId, boolean removeMaxAndMin){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierStepAvgResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("supplierId", supplierId);
		param.put("removeMaxAndMin", removeMaxAndMin);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				List<BigDecimal> bidDecimalList = JsonUtil.jsonToList(result,BigDecimal.class);
				if (bidDecimalList.size() > 1) {
				    BigDecimal[] bigDecimals = new BigDecimal[2];
				    bigDecimals[0] = bidDecimalList.get(0);
				    bigDecimals[1] = bidDecimalList.get(1);
				    return bigDecimals;
                }
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return null;
	}
	
	/**
	 * @Description: 获得供应商在指定评标步骤的平均得分
	 * @author guoyr
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @param removeMaxAndMin
	 * @return 
	 */
	public BigDecimal[] getSupplierStepAvgResultByFactor(String tenderId, String stepId, String supplierId, boolean removeMaxAndMin){
		BigDecimal[] bigDecimals = new BigDecimal[]{null,null};
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierStepAvgResultByFactor");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("supplierId", supplierId);
		param.put("removeMaxAndMin", removeMaxAndMin);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				List<BigDecimal> bidDecimalList = JsonUtil.jsonToList(result,BigDecimal.class);
				bigDecimals[0] = bidDecimalList.get(0);
				bigDecimals[1] = bidDecimalList.get(1);
				return bigDecimals;
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	/**
	 * @Description: 删除专家评审结果
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId 
	 * @return 
	 */
	public boolean deleteExpertEvaluationAndFactorResult(String tenderId, String stepId, String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteExpertEvaluationAndFactorResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 新增专家评审结果
	 * @author wangxiang
	 * @param expertEvaluationResult 
	 */
	public boolean insert(ExpertEvaluationResult expertEvaluationResult) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(expertEvaluationResult));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return ResultStatus.getReultStatusBoolean(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		return false;
	}
	
	/**
	 * @Description: 获得所有专家在为指定供应商的评标结果
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	public List<ExpertEvaluationResult> getSupplierAllEvaluationResultList(String tenderId,String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierAllEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获得所有专家的评标结果
	 * @author guoyr
	 * @param tenderId
	 * @return 
	 */
	public List<ExpertEvaluationResult> getAllExpertEvaluationResultList(String tenderId ){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getAllExpertEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}

	/**
	 * @Description: 获得专家为供应商在所有评标步骤下的评审结果列表
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @param userId
	 * @return 
	 */
	public List<ExpertEvaluationResult> getExpertSupplierEvaluationResultList(String tenderId,String supplierId ,String userId ){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertSupplierEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("supplierId", supplierId);
		param.put("userId", userId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	
	/**
	 * @Description: 获得专家在指定评标步骤对供应商的评标结果
	 * @author guoyr
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @param userId
	 * @return 
	 */
	public ExpertEvaluationResult getExpertEvaluationResult(String tenderId,String stepId ,String supplierId ,String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertEvaluationResult");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("supplierId", supplierId);
		param.put("userId", userId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	
	/**
	 * @Description: 获得所有专家在指定步骤下为指定供应商的评标结果列表
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @param stepId
	 * @return 
	 */
	public	List<String> getSupplierStepAllExpertEvaluationAccessmentList(String tenderId ,String stepId, String supplierId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getSupplierStepAllExpertEvaluationAccessmentList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		param.put("supplierId", supplierId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, String.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
 	}
	
	public List<ExpertEvaluationResult> getExpertStepAllSupplierEvaluationResultList(String tenderId, String stepId, String userId){
		String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertStepAllSupplierEvaluationResultList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		param.put("stepId", stepId);
		param.put("userId", userId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertEvaluationResult.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
}
