package com.gx.obe.web.service.expert;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.EditPriceItemResult;
import com.gx.obe.business.entity.ExpertEvaluationStep;
import com.gx.obe.business.entity.SupplierEvaluationStep;
import com.gx.obe.business.vo.Audit;
import com.gx.obe.components.core.Constants;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.util.utils.StringUtils;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.CheckResult;
import com.gx.obe.web.entity.EvaluationFactorResult;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.SupplierEvaluationResult;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import com.gx.obe.web.entity.expert.Expert;
import com.gx.obe.web.entity.expert.ExpertEvaluationResult;
import com.gx.obe.web.entity.price.BidPriceResult;
import com.gx.obe.web.entity.tender.TenderProjectRuleEntity;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.PreEvaluationAuditAdopt;
import com.gx.obe.web.vo.PreEvaluationAuditReturn;
import com.gx.obe.web.vo.SaveBusinessEvaluationResultVo;
import com.gx.obe.web.vo.SaveBusinessVetoEvaluationResultVo;
import com.gx.obe.web.vo.SaveCleanTenderEvaluationResultVo;
import com.gx.obe.web.vo.SaveCorrectEvalPriceResultVo;
import com.gx.obe.web.vo.SaveEditPriceResultVo;
import com.gx.obe.web.vo.SaveEvaluationResultVo;
import com.gx.obe.web.vo.SaveFeatureEvaluationResultVo;
import com.gx.obe.web.vo.SaveLimitPriceEvaluationResultVo;
import com.gx.obe.web.vo.SaveRecommendRankEvaluationResultVo;
import com.gx.obe.web.vo.SubmitBusinessEvaluationResultVo;
import com.gx.obe.web.vo.SubmitBusinessVetoEvaluationResultVo;
import com.gx.obe.web.vo.SubmitCleanTenderEvaluationResultVo;
import com.gx.obe.web.vo.SubmitCreditEvaluationResultVo;
import com.gx.obe.web.vo.SubmitEvaluationResultVo;
import com.gx.obe.web.vo.SubmitFeatureEvaluationResultVo;
import com.gx.obe.web.vo.SubmitRecommendRankEvaluationResultVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

public class ExpertEvaluationStepService {
    
    protected static final String URL = "expertEvaluationStep";
    
    protected static Logger logger = Logger.getLogger(ExpertEvaluationStepService.class);
    
    /**
     * @Description: 获得评审成员的评标步骤列表
     * @author mazc
     * @param tenderId
     * @param userId
     * @return
     */
    public List<ExpertEvaluationStep> getExpertEvaluationStepList(String tenderId, String userId) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/findExpertEvaluationStepList");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, ExpertEvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 修改专家对当前评标步骤的评审进度
     * @author chenxw
     * @param status
     * @param tenderId
     * @param evaluationStep
     * @param userId
     * @return
     */
    public ExpertEvaluationStep updateExpertEvaluationStatus(String status, String tenderId, EvaluationStep evaluationStep, String userId) {
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/updateExpertEvaluationStatus");
        RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
        requestBody.setEntity(evaluationStep);
        requestBody.setParam("status", status);
        requestBody.setParam("userId", userId);
        requestBody.setParam("tenderId", tenderId);
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, ExpertEvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 保存评审结果
     * @author mazc
     * @param tenderId
     * @param userId
     * @param evaluationStep
     * @param expertEvaluationResultMap
     * @param supplierEvaluationFactorResultMap
     * @return
     */
    public boolean saveEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, Map<String, ExpertEvaluationResult> expertEvaluationResultMap, Map<String, Map<String, EvaluationFactorResult>> supplierEvaluationFactorResultMap) {
        SaveEvaluationResultVo saveEvaluationResultVo = new SaveEvaluationResultVo();
        saveEvaluationResultVo.setUserId(userId);
        saveEvaluationResultVo.setTenderId(tenderId);
        saveEvaluationResultVo.setEvaluationStep(evaluationStep);
        saveEvaluationResultVo.setExpertEvaluationResultMap(expertEvaluationResultMap);
        saveEvaluationResultVo.setSupplierEvaluationFactorResultMap(supplierEvaluationFactorResultMap);
        //获取服务器地址
        String strWebServerUrl = Constants.getServiceUrl(URL + "/saveEvaluationResult");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveEvaluationResultVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
        
    }
    
    /**
     * @Description: 提交评标结果
     * @author mazc
     * @param tenderId
     * @param tenderProjectRuleEntity
     * @param userId
     * @param evaluationStep
     * @param supplierList
     * @return
     */
    public boolean submitEvaluationResult(String tenderId, TenderProjectRuleEntity projectRule, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList) {
        SubmitEvaluationResultVo submitEvaluationResultVo = new SubmitEvaluationResultVo(tenderId, projectRule, userId, evaluationStep, supplierList);
        String strWebServerUrl = Constants.getServiceUrl(URL + "/submitEvaluationResult");
        try {
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitEvaluationResultVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }
    
    /**
     * @Description: 获得评审成员对指定项目的指定的评标步骤
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    public ExpertEvaluationStep getExpertEvaluationStep(String tenderId, String stepId, String userId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getExpertEvaluationStep");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        param.put("userId", userId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToBean(result, ExpertEvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 获得指定评标步骤的评审记录
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @return
     */
    public List<ExpertEvaluationStep> getEvaluationStepListByStepId(String tenderId, String stepId) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getEvaluationStepListByStepId");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepId", stepId);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, ExpertEvaluationStep.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
    
    /**
     * @Description: 预评审审核通过
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param curStep 
     */
    public boolean preEvaluationAuditAdopt(String tenderId, String userId, EvaluationStep curStep) {
    	PreEvaluationAuditAdopt preEvaluationAuditAdopt = new PreEvaluationAuditAdopt(tenderId, userId, curStep);
		String strWebServerUrl = Constants.getServiceUrl(URL + "/preEvaluationAuditAdopt");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(preEvaluationAuditAdopt));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
    }
    
    /**
     * @Description: 预评审审核退回
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param stepId
     * @param message 
     */
    public boolean preEvaluationAuditReturn(String tenderId, String userId, EvaluationStep curStep, String message) {
    	PreEvaluationAuditReturn preEvaluationAuditReturn = new PreEvaluationAuditReturn(tenderId, userId, curStep,message);
		String strWebServerUrl = Constants.getServiceUrl(URL + "/preEvaluationAuditReturnStep");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(preEvaluationAuditReturn));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
    }
    
    /**
     * @Description: 预评审审核退回
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param stepId
     * @param message 
     */
    public boolean preEvaluationAuditReturn(String tenderId, String userId, String stepId, String message) {
    	String strWebServerUrl = Constants.getServiceUrl(URL + "/preEvaluationAuditReturnStepId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("stepId", stepId);
		param.put("message", message);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
    }

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param expertEvaluationStep
	 * @param attributes
	 * @return 
	 */
	public boolean updateAssignProperty(ExpertEvaluationStep expertEvaluationStep, String[] attributes) {
        //登陆请求地址
        String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
        UpdateAssignPropertyVo<ExpertEvaluationStep> updateAssignPropertyVo = new UpdateAssignPropertyVo<ExpertEvaluationStep>();
        updateAssignPropertyVo.setEntity(expertEvaluationStep);
        updateAssignPropertyVo.setAttributes(attributes);
        try{
            String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(updateAssignPropertyVo));
            return ResultStatus.getReultStatusBoolean(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return false;
        }
    }

	/**
	 * @Description: 提交评标报价修正
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param b 
	 */
	public boolean saveCorrectEvalPriceResult(String tenderId, String userId, EvaluationStep evaluationStep, boolean b) {
		SaveCorrectEvalPriceResultVo saveCorrectEvalPriceResultVo = new SaveCorrectEvalPriceResultVo(tenderId, userId, evaluationStep, b);
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveCorrectEvalPriceResult");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveCorrectEvalPriceResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 重新修正评标价
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId 
	 */
	public boolean reCorrectEvalPrice(String tenderId, String stepId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/reCorrectEvalPrice");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 删除指定评标步骤
	 * @author wangxiang
	 * @param stepId
	 */
	public boolean deleteById(String stepId) {
		//请求地址
		String strWebServerUrl = Constants.getServiceUrl(URL + "/delete");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", stepId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 
	 * @author wangxiang
	 * @param memberEvaluationStep 
	 */
	public ExpertEvaluationStep saveOrUpdateNoEmpty(ExpertEvaluationStep memberEvaluationStep) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		if(null == memberEvaluationStep.getId()){
			memberEvaluationStep.setId(UuidUtils.getUUID());
		}
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(memberEvaluationStep));
			if(ResultStatus.getReultStatusBoolean(result)){
				return memberEvaluationStep;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得评审成员对指定项目的指定序号的评标步骤
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return
	 */
	public ExpertEvaluationStep getExpertEvaluationStepBySort(String tenderId, int sort, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertEvaluationStepBySort");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("sort", sort);
		param.put("userId", userId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, ExpertEvaluationStep.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 评标专家签到
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @return
	 */
	public boolean expertAvoid(String tenderId, String userId, EvaluationStep evaluationStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/expertAvoid");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);		
		requestBody.setParam("userId", userId);		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return ResultStatus.getReultStatusBoolean(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		return false;
	}
	
	/**
	 * @Description: 获得某一评标步骤评标专家评审完成的数量
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @return
	 */
	public int getExpertEvaluationComplateCount(String tenderId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertEvaluationComplateCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepId", stepId);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
		return 0;
	}
	
	/**
	 * @Description: 评标专家签到
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @return
	 */
	public boolean submitExpertSignEvaluation(String tenderId, String userId, EvaluationStep evaluationStep, String signType, String signResult){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitExpertSignEvaluation");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);		
		requestBody.setParam("userId", userId);		
		requestBody.setParam("signType", signType);		
		requestBody.setParam("signResult", signResult);		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 提交推荐中标候选人结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param supplierEvalResultList
	 * @return
	 */
	public boolean submitRecommonedEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, String evaluationOpinion, List<SupplierEvaluationResult> supplierEvalResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitRecommonedEvaluationResult");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);		
		requestBody.setParam("userId", userId);		
		requestBody.setParam("evaluationOpinion", evaluationOpinion);
		List<Object>  objList =  new ArrayList<Object>();
		for(SupplierEvaluationResult supplierEvaluationResult : supplierEvalResultList){
			if(StringUtils.isEmpty(supplierEvaluationResult.getId())){
				supplierEvaluationResult.setId(UuidUtils.getUUID());
			}
			objList.add(supplierEvaluationResult);
		}
		requestBody.setList(objList);
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 保存特征码检查结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param memberEvaluationStep
	 * @param expertEvaluationResultList
	 * @return
	 */
	public boolean saveFeatureEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<CheckResult> checkResultList, List<ExpertEvaluationResult> expertEvaluationResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveFeatureEvaluationResult");
		SaveFeatureEvaluationResultVo  saveFeatureEvaluationResultVo =  new SaveFeatureEvaluationResultVo(tenderId,userId,evaluationStep,checkResultList,expertEvaluationResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveFeatureEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 提交特征码检查结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param memberEvaluationStep
	 * @param supplierList
	 * @return
	 */
	public boolean submitFeatureEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitFeatureEvaluationResult");
		SubmitFeatureEvaluationResultVo  submitFeatureEvaluationResultvo = new SubmitFeatureEvaluationResultVo(tenderId,userId,evaluationStep,supplierList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitFeatureEvaluationResultvo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存限价检查结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param expertEvaluationResultMap
	 * @return
	 */
	public boolean saveLimitPriceEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, Map<String, ExpertEvaluationResult> expertEvaluationResultMap){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveLimitPriceEvaluationResult");
		SaveLimitPriceEvaluationResultVo  saveLimitPriceEvaluationResultvo = new SaveLimitPriceEvaluationResultVo(tenderId,userId,evaluationStep,expertEvaluationResultMap);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveLimitPriceEvaluationResultvo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 提交限价检查结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param memberEvaluationStep
	 * @param supplierList
	 * @return
	 */
	public boolean submitLimitPriceEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitLimitPriceEvaluationResult");
		SubmitFeatureEvaluationResultVo  submitFeatureEvaluationResultvo = new SubmitFeatureEvaluationResultVo(tenderId,userId,evaluationStep,supplierList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitFeatureEvaluationResultvo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 重新授权专家的评标步骤
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param nodeSortNo
	 * @param ifFilter
	 */
	public boolean reBackExpertEvaluationStep(String tenderId, String stepId, int nodeSortNo, boolean ifFilter, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/reBackExpertEvaluationStep");
		Map<String, Object> param = new HashMap<String, Object>();
	    param.put("tenderId", tenderId);
	    param.put("stepId", stepId);
	    param.put("userId", userId);
	    param.put("nodeSortNo", nodeSortNo);
	    param.put("ifFilter", ifFilter);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 修改专家确认评标价的状态
	 * @author wangxiang
	 * @param status
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return
	 */
	public boolean updateEvalPriceConfirmStatus(String status, String tenderId, String stepId, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateEvalPriceConfirmStatus");
		Map<String, Object> param = new HashMap<String, Object>();
	    param.put("tenderId", tenderId);
	    param.put("stepId", stepId);
	    param.put("userId", userId);
	    param.put("status", status);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 获得专家确认修正评标价结果列表
	 * @author guoyr
	 * @param tenderId
	 * @param stepId
	 * @return
	 */
	public List<ExpertEvaluationStep> getEvalPriceConfirmList(String tenderId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvalPriceConfirmList");
		Map<String, Object> param = new HashMap<String, Object>();
	    param.put("tenderId", tenderId);
	    param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, ExpertEvaluationStep.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 验证是否已经保存过修正评标价
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @return
	 */
	public boolean isSaveCorrectEvalPrice(String tenderId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isSaveCorrectEvalPrice");
		Map<String, Object> param = new HashMap<String, Object>();
	    param.put("tenderId", tenderId);
	    param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	/**
	 * @Description: 获得步骤下已经评审完毕的专家
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @return
	 */
	public List<Expert> getExpertListByStepFinish(String tenderId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertListByStepFinish");
		Map<String, Object> param = new HashMap<String, Object>();
	    param.put("tenderId", tenderId);
	    param.put("stepId", stepId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return JsonUtil.jsonToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 保存推荐排名结果
	 * @author wangxiang
	 * @param evaluationResultList
	 * @return 
	 */
	public boolean saveRecommendRankEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<ExpertEvaluationResult> expertEvaluationResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveRecommendRankEvaluationResult");
		SaveRecommendRankEvaluationResultVo  saveRecommendRankEvaluationResultVo = new SaveRecommendRankEvaluationResultVo(tenderId,userId,evaluationStep,expertEvaluationResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveRecommendRankEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 提交推荐排名结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param supplierList
	 * @param recommendCount 
	 * @return 
	 */
	public boolean submitRecommendRankEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList, int recommendCount){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitRecommendRankEvaluationResult");
		SubmitRecommendRankEvaluationResultVo  submitRecommendRankEvaluationResultVo = new SubmitRecommendRankEvaluationResultVo(tenderId,userId,evaluationStep,supplierList,recommendCount);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitRecommendRankEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存否决投标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param supplierList 
	 * @param evaluationResultList
	 * @return
	 */
	public boolean saveVetoBidEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, Map<String, ExpertEvaluationResult> expertEvaluationResultMap){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveVetoBidEvaluationResult");
		SaveLimitPriceEvaluationResultVo  saveVetoBidEvaluationResultVo = new SaveLimitPriceEvaluationResultVo(tenderId,userId,evaluationStep,expertEvaluationResultMap);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveVetoBidEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 提交否决投标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param memberEvaluationStep
	 * @param supplierList
	 * @return
	 */
	public boolean submitVetoBidEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitVetoBidEvaluationResult");
		SubmitFeatureEvaluationResultVo  submitFeatureEvaluationResultvo = new SubmitFeatureEvaluationResultVo(tenderId,userId,evaluationStep,supplierList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitFeatureEvaluationResultvo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 保存信用得分结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param supplierList 
	 * @param evaluationResultList
	 * @return
	 */
	public boolean submitCreditEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList, Map<String, ExpertEvaluationResult> expertEvaluationResultMap){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitCreditEvaluationResult");
		SubmitCreditEvaluationResultVo  submitCreditEvaluationResultVo = new SubmitCreditEvaluationResultVo(tenderId,userId,evaluationStep,supplierList,expertEvaluationResultMap);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitCreditEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 保存清单评审结果
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param expertEvaluationResultMap 
	 * @return 
	 */
	public boolean saveBillEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, Map<String, ExpertEvaluationResult> expertEvaluationResultMap){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveBillEvaluationResult");
		SaveLimitPriceEvaluationResultVo  saveVetoBidEvaluationResultVo = new SaveLimitPriceEvaluationResultVo(tenderId,userId,evaluationStep,expertEvaluationResultMap);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveVetoBidEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 提交多轮报价结果
	 * @author wangxiang
	 * @param tenderId
	 * @param projectRule
	 * @param userId
	 * @param evaluationStep
	 * @param supplierList
	 * @return 
	 */
	public boolean submitMultiPriceResult(String tenderId, String userId, EvaluationStep evaluationStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitMultiPriceResult");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);		
		requestBody.setParam("userId", userId);		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return ResultStatus.getReultStatusBoolean(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		return false;
	}   
	
	/**
	 * @Description: 获得当前评标步骤之前未完成评审的个数
	 * @author wangxiang
	 * @param tenderId
	 * @param userId
	 * @param curStepIndex
	 * @return 
	 */
	public int getNotComplateStepCount(String tenderId, String userId, int curStepIndex){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getNotComplateStepCount");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		param.put("curStepIndex", curStepIndex);
		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
		return -1;
	}
	
	/**
	 * @Description: 保存合量评审结果
	 * @author wangxiang
	 * @param id
	 * @param commonExpert
	 * @param evaluationStep
	 * @param expertEvaluationResultMap
	 * @param supplierList 
	 * @return 
	 */
	public boolean saveTotalPriceEvaluationResult(String id, String commonExpert, EvaluationStep evaluationStep, Map<String, ExpertEvaluationResult> expertEvaluationResultMap, List<Supplier> supplierList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveTotalPriceEvaluationResult");
		SubmitCreditEvaluationResultVo  submitCreditEvaluationResultVo = new SubmitCreditEvaluationResultVo(id,commonExpert,evaluationStep,supplierList,expertEvaluationResultMap);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitCreditEvaluationResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 提交合量评审结果
	 * @author chenxw
	 * @param id
	 * @param commonExpert
	 * @param evaluationStep
	 * @param supplierList
	 * @return 
	 */
	public boolean submitTotalPriceEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<Supplier> supplierList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitTotalPriceEvaluationResult");
		SubmitFeatureEvaluationResultVo  submitFeatureEvaluationResultvo = new SubmitFeatureEvaluationResultVo(tenderId,userId,evaluationStep,supplierList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitFeatureEvaluationResultvo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
    /**
     * @Description: 根据步骤类型获取审核列表
     * @author chenxw
     * @param tenderId
     * @param stepType
     * @return 
     */
    public List<Audit> getAuditListByStepType(String tenderId, String stepType) {
        String strWebServerUrl = Constants.getServiceUrl(URL + "/getAuditListByStepType");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("tenderId", tenderId);
        param.put("stepType", stepType);
        try {
            String result = NetworkRequest.get(strWebServerUrl, param);
            if (ResultStatus.getReultStatusIsNotEmpty(result)) {
                return JsonUtil.jsonToList(result, Audit.class);
            }
            return null;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }
	
	/**
	 * @Description: 提交预评审结果
	 * @author wangxiang
	 * @param id
	 * @param curStep 
	 */
	public boolean submitPreEvaluationResult(String tenderId, EvaluationStep curStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitPreEvaluationResult");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(curStep);
		requestBody.setParam("tenderId", tenderId);		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return ResultStatus.getReultStatusBoolean(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		return false;
	}
	
	/**
	 * @Description: 保存修正报价结果
	 * @author wangxiang
	 * @param tenderId
	 * @param evaluationStep
	 * @param editPriceItemResultList
	 * @param bidPriceResultList
	 * @return 
	 */
	public boolean saveEditPriceResult(String tenderId, EvaluationStep evaluationStep, List<EditPriceItemResult> editPriceItemResultList, List<BidPriceResult> bidPriceResultList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveEditPriceResult");
		SaveEditPriceResultVo  saveEditPriceResultVo = new SaveEditPriceResultVo(tenderId,evaluationStep,editPriceItemResultList,bidPriceResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveEditPriceResultVo));
			if (ResultStatus.getReultStatusIsNotEmpty(result)) {
				return ResultStatus.getReultStatusBoolean(result);
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 提交修正报价结果
	 * @author wangxiang
	 * @param tenderId
	 * @param evaluationStep
	 * @param userId
	 * @return 
	 */
	public boolean submitEditPriceResult(String tenderId, EvaluationStep evaluationStep, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/submitEditPriceResult");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);		
		requestBody.setParam("userId", userId);		
		try{
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return ResultStatus.getReultStatusBoolean(result);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		return false;
	}

	/**
	 * @Description: 根据步骤类型删除专家评审步骤
	 * @author chenxw
	 * @param tenderId
	 * @param stepType
	 * @return 
	 */
	public boolean deleteExpertEvaluationStepByStepType(String tenderId, String stepType) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/deleteExpertEvaluationStepByStepType");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("stepType", stepType);
		try {
			NetworkRequest.get(strWebServerUrl, param);
			return true;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 保存清标检查结果
	 * @author guoyr
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param expertEvaluationStep
	 * @param expertEvaluationResultList
	 * @return
	 */
	public boolean saveCleanTenderEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<ExpertEvaluationResult> expertEvaluationResultList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveCleanTenderEvaluationResult");
		SaveCleanTenderEvaluationResultVo cleanTenderEvaluationResultVo = new SaveCleanTenderEvaluationResultVo();
		cleanTenderEvaluationResultVo.setTenderId(tenderId);
		cleanTenderEvaluationResultVo.setUserId(userId);
		cleanTenderEvaluationResultVo.setEvaluationStep(evaluationStep);
		cleanTenderEvaluationResultVo.setExpertEvaluationResultList(expertEvaluationResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(cleanTenderEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}
	
	/**
	 * @Description: 提交清标检查结果
	 * @author guoyr
	 * @param tenderId
	 * @param userId
	 * @param evaluationStep
	 * @param expertEvaluationStep
	 * @param supplierList
	 * @return
	 */
	public boolean submitCleanTenderEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, ExpertEvaluationStep expertEvaluationStep, List<Supplier> supplierList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/submitCleanTenderEvaluationResult");
		SubmitCleanTenderEvaluationResultVo submitCleanTenderEvaluationResultVo = new SubmitCleanTenderEvaluationResultVo();
		submitCleanTenderEvaluationResultVo.setTenderId(tenderId);
		submitCleanTenderEvaluationResultVo.setUserId(userId);
		submitCleanTenderEvaluationResultVo.setEvaluationStep(evaluationStep);
		submitCleanTenderEvaluationResultVo.setExpertEvaluationStep(expertEvaluationStep);
		submitCleanTenderEvaluationResultVo.setSupplierList(supplierList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(submitCleanTenderEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

	/** 
     * @Description: 保存商务否决评审结果
     * @author chenxw
     * @param tenderId
     * @param evaluationStep
     * @param userId
     * @param expertEvaluationResultList
     * @return 
     */
	public boolean saveBusinessVetoEvaluationResult(String tenderId, EvaluationStep evaluationStep, String userId, List<ExpertEvaluationResult> expertEvaluationResultList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveBusinessVetoEvaluationResult");
		SaveBusinessVetoEvaluationResultVo businessVetoEvaluationResultVo = new SaveBusinessVetoEvaluationResultVo();
		businessVetoEvaluationResultVo.setTenderId(tenderId);
		businessVetoEvaluationResultVo.setEvaluationStep(evaluationStep);
		businessVetoEvaluationResultVo.setUserId(userId);
		businessVetoEvaluationResultVo.setExpertEvaluationResultList(expertEvaluationResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(businessVetoEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

    /** 
     * @Description: 提交商务否决评审结果
     * @author chenxw
     * @param tenderId
     * @param evaluationStep
     * @param userId
     * @param supplierList
     * @return 
     */
    public boolean submitBusinessVetoEvaluationResult(String tenderId, EvaluationStep evaluationStep, String userId, List<Supplier> supplierList) {
    	String strWebServerUrl = Constants.getServiceUrl(URL + "/submitBusinessVetoEvaluationResult");
    	SubmitBusinessVetoEvaluationResultVo businessVetoEvaluationResultVo = new SubmitBusinessVetoEvaluationResultVo();
    	businessVetoEvaluationResultVo.setTenderId(tenderId);
    	businessVetoEvaluationResultVo.setEvaluationStep(evaluationStep);
    	businessVetoEvaluationResultVo.setUserId(userId);
    	businessVetoEvaluationResultVo.setSupplierList(supplierList);
    	try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(businessVetoEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

    /** 
     * @Description: 保存商务评审结果
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param evaluationStep
     * @param evaluationFactorResultList
     * @param expertEvaluationResultList
     * @return 
     */
	public boolean saveBusinessEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<EvaluationFactorResult> evaluationFactorResultList, List<ExpertEvaluationResult> expertEvaluationResultList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/saveBusinessEvaluationResult");
		SaveBusinessEvaluationResultVo businessEvaluationResultVo = new SaveBusinessEvaluationResultVo();
		businessEvaluationResultVo.setTenderId(tenderId);
		businessEvaluationResultVo.setUserId(userId);
		businessEvaluationResultVo.setEvaluationStep(evaluationStep);
		businessEvaluationResultVo.setEvaluationFactorResultList(evaluationFactorResultList);
		businessEvaluationResultVo.setExpertEvaluationResultList(expertEvaluationResultList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(businessEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}

    /** 
     * @Description: 提交商务评审结果
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param evaluationStep
     * @param supplierEvaluationStepList
     * @return 
     */
	public boolean submitBusinessEvaluationResult(String tenderId, String userId, EvaluationStep evaluationStep, List<SupplierEvaluationStep> supplierEvaluationStepList) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/submitBusinessEvaluationResult");
		SubmitBusinessEvaluationResultVo businessEvaluationResultVo = new SubmitBusinessEvaluationResultVo();
		businessEvaluationResultVo.setTenderId(tenderId);
		businessEvaluationResultVo.setUserId(userId);
		businessEvaluationResultVo.setEvaluationStep(evaluationStep);
		businessEvaluationResultVo.setSupplierEvaluationStepList(supplierEvaluationStepList);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(businessEvaluationResultVo));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return false;
	}
	
}
