package com.gx.obe.web.service.expert;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.business.entity.ExpertLibrary;
import com.gx.obe.components.core.Constants;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.http.util.WebReflecUtill;
import com.gx.obe.util.utils.StringUtil;
import com.gx.obe.web.utils.ResultStatus;

public class ExpertLibraryService {
	
	private Logger logger = Logger.getLogger(ExpertLibraryService.class);
	
	static final String URL = "expertLibrary";
	
	
	/**
	 * @Description: 交换两个专家库的排序
	 * @author guoyr
	 * @param source
	 * @param target
	 */
	public boolean changeExpertLibrarySortNo(String sourceSortNo, String sourceid, String targetSortNo, String targetId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/changeExpertLibrarySortNo");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sourceSortNo", sourceSortNo);
		param.put("sourceid", sourceid);
		param.put("targetSortNo", targetSortNo);
		param.put("targetId", targetId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	/**
	 * @Description: 获得专家库的最大序号
	 * @author guoyr
	 * @return
	 */
	public int getMaxExpertLibrarySortNo(){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMaxExpertLibrarySortNo");
		try {
			String result = NetworkRequest.get(strWebServerUrl);
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	 /**   
	 * @Title: updateAssignProperty   
	 * @Description: 更新分配属性
	 * @param: @param tenderProjectRuleEntity      
	 * @return: void      
	 * @throws   
	 */  
	public boolean updateAssignProperty(ExpertLibrary expertLibrary ,String [] attributes){
		ExpertLibrary tempExpertLibrary = null;
		try {
			WebReflecUtill<ExpertLibrary> utill = new WebReflecUtill<ExpertLibrary>();
			tempExpertLibrary = (ExpertLibrary) utill.reflex(expertLibrary, attributes,ExpertLibrary.class);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}			
		if(null != tempExpertLibrary){
			//登陆请求地址
			String strWebServerUrl = Constants.getServiceUrl( URL + "/updateAssignProperty");
 			try{
				String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(tempExpertLibrary));
				return ResultStatus.getReultStatusBoolean(result);
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
				return false;
			}
		}
		return false;
	}
	/**
	 * @Description: 保存或更新
	 * @author mazc
	 * @param authUser
	 * @return 
	 */
	public ExpertLibrary saveOrUpdateReturn(ExpertLibrary expertLibrary){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveOrUpdateReturn");
		try{
			String result = NetworkRequest.post(strWebServerUrl,  JsonUtil.jsonObjectToStr(expertLibrary));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				ExpertLibrary tempExpertLibrary = JsonUtil.jsonToBean(result, ExpertLibrary.class);					
				return tempExpertLibrary;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
	}
	
	public boolean deleteById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public List<Object>  getExpertLibByExpertLibNameOrId(String id ,String expertLibName){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertLibByExpertLibNameOrId");
 		Map<String, Object> param = new HashMap<String, Object>();
 		if(!StringUtil.empty(id)){
 			param.put("id", id);
 		}
		param.put("expertLibName", expertLibName);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public List<ExpertLibrary> getExpertLibraryByOrderByorUseStatus(String useStatus){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertLibraryByOrderByorUseStatus");
 		Map<String, Object> param = new HashMap<String, Object>();
 		if(!StringUtil.empty(useStatus)){
 			param.put("useStatus", useStatus);
 		}
 		try{
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, ExpertLibrary.class);					
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		} 
 		
	}
}
