package com.gx.obe.web.service.expert;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.UserEnum;
import  com.gx.obe.web.utils.NetworkRequest;
import com.gx.obe.http.json.JsonUtil;
import com.gx.obe.web.entity.Result.RequestBody;
import com.gx.obe.web.entity.auth.AuthUser;
import com.gx.obe.web.entity.auth.AuthUserRole;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import com.gx.obe.web.entity.expert.Expert;
import com.gx.obe.web.utils.ResultStatus;
import com.gx.obe.web.vo.SaveTempExpertVo;
import com.gx.obe.web.vo.UpdateAssignPropertyVo;

public class ExpertService {
	
	private Logger logger = Logger.getLogger(ExpertService.class);
	
	static final String URL = "expert";
	/**
	 * @Description: 只查询 id 、EvalBidType 
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<Expert> findEvalBidTypeByTenderIdList(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findEvalBidTypeByTenderId");
//		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findEvalBidTypeByTenderId"; 
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return  JsonUtil.strToList(result, Expert.class);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	public Expert insert(Expert expert){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertReturn");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(expert));
			return JsonUtil.jsonToBean(result, Expert.class);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}

	}
	
	/**
	 * @Description: 通过TenderId 查询所需要的属性
	 * @author mazc
	 * @param tenderId 
	 * @param strCoulmns 表字段名
	 * @return 
	 */
	public List<Expert> finCoulmnsByTenderId(String tenderId,String [] strCoulmns){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/finCoulmnsByTenderId");
		//请求地址
// 		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/finCoulmnsByTenderId"; 

		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("strCoulmns", strCoulmns);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 判断是否存在专家组长
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isExistExpertLeader(String tenderId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/isExistExpertLeader");
		//请求地址
// 		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/isExistExpertLeader"; 
 		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
		
	}
	/**
	 * @Description: 获得指定项目的评审成员信息
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return 
	 */
	public Expert getExpert(String tenderId, String userId){
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpert");
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findExpert"; 
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
 			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public int updateSignType(String signType , String tenderId ) {
		//获取服务器地址
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateSignType");
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/updateSignType"; 
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("signType", signType);
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.isReultStatusInteger(result)){	
				return  Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	/**
	 * @Description:  获得评标专家列表
	 * @author mazc
	 * @param tenderId
	 * @param signType
	 * @return 
	 */
	public List<Expert>  findExpertByTenderIdBatch(String tenderId, String signType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpertByTenderIdAndSignTypeBatch");
		//请求地址
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findExpertByTenderIdAndSignTypeBatch"; 
  		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);
		param.put("signType", signType);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description:  通过项目id 获得的评标专家
	 * @author mazc
	 * @param tenderId
	 * @param signType
	 * @return 
	 */
	public List<Expert>  getExpertByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpertByTenderId");
		//请求地址
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findExpertByTenderId"; 
  		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得评标步骤的评标专家
	 * @author mazc
	 * @param tenderId
	 * @param evaluationStep
	 * @return 
	 */
	public List<AuthUser> getEvaluationStepUserList(String tenderId, EvaluationStep evaluationStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findEvaluationStepUserList");
		//请求地址
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findEvaluationStepUserList"; 
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, AuthUser.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得评标专家组长
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public Expert getExpertLeader(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpertLeader");
		//请求地址
//  		strWebServerUrl = "http://127.0.0.1:8081/"+URL+"/findExpertLeader"; 
  		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
//			Map<String, Class> classMap = new HashMap<String, Class>();
//			classMap.put("user", AuthUser.class);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Expert.class);
//				return JsonUtil.strToObject(result,  Expert.class, classMap);
//				JsonUtil.strToList("user", Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 获得评标步骤的评标专家
	 * @author mazc
	 * @param tenderId
	 * @param evaluationStep
	 * @return 
	 */
	public List<Expert> getEvaluationStepExpertList(String tenderId,EvaluationStep evaluationStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findEvaluationStepExpertList");
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
 
	/**
	 * @Description: 获得评标步骤特定的专家
	 * @author mazc
	 * @param tenderId
	 * @param evaluationStep
	 * @return 
	 */
	public Expert getEvaluationStepExpert(String tenderId, EvaluationStep evaluationStep){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findEvaluationStepExpert");
		//请求地址
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToBean(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 根据项目父级ID查询当前项目（包含子项目）下所有的评审专家
	 * @author mazc
	 * @param projectId
	 * @return 
	 */
	public List<Expert> findExpertListByTenderId(String projectId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpertListByTenderId");
		//请求地址
  		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("projectId", projectId);	
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得参与当前评标步骤的专家数
	 * @author mazc
	 * @param tenderId
	 * @param evaluationStep
	 * @return 
	 */
	public int getEvaluationStepExpertCount(String tenderId, EvaluationStep evaluationStep) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findEvaluationStepExpertCount");
		//请求地址
		RequestBody<EvaluationStep> requestBody = new RequestBody<EvaluationStep>();
		requestBody.setEntity(evaluationStep);
		requestBody.setParam("tenderId", tenderId);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	
	
	/**
	 * @Description: 根据项目父级ID查询当前项目（包含子项目）下所有的评审专家
	 * @author mazc
	 * @param projectId
	 * @return 
	 */
	public List<Expert> findExpertList(String tenderId, String signType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExpertList");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);	
  		param.put("signType", signType);	
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 查询userId votesNum 、votes  
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public List<Expert> findExperColumnstByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/findExperColumnstByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);	
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param expert
	 * @param attributes
	 * @return 
	 */
	public boolean updateAssignProperty(Expert expert, String[] attributes) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateAssignProperty");
		UpdateAssignPropertyVo<Expert> vo = new UpdateAssignPropertyVo<Expert>();
		vo.setEntity(expert);
		vo.setAttributes(attributes);
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(vo));
			if (ResultStatus.getReultStatusBoolean(result)) {
				return true;
			}
			return false;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param args 
	 */
	public static void main(String[] args) {
		ExpertService expertService = new ExpertService();
//		List<Expert> list = expertService.findEvalBidTypeByTenderIdList("04854a6295da4b9bbda3438cbd67f2b6");
//		for(Expert expert : list){
//			System.out.println(expert.getId());
//		}
//		Expert expert = new Expert();
//		expert.setId("12312312312312313");
//		expertService.insert(expert);‘
//		String [] strCoulmns ={Expert.EXPERT_ID,Expert.EVAL_BID_TYPE, Expert.CREATE_USER_ID};
//		List<Expert> list =  expertService.finCoulmnsByTenderId("04854a6295da4b9bbda3438cbd67f2b6", strCoulmns);
//		for(Expert e :list){
//			System.out.println(e.getId());
//		}
//		System.out.println(expertService.isExistExpertLeader("04854a6295da4b9bbda3438cbd67f2b1"));
//		expert = expertService.getExpert("944c1910a51a458d9fd66039d98e41da", "b4b4f7e26b9e42fd9b9636b1572fc376");
//		if(expert == null){
//			return ;
//		}
//		System.out.println(expert.getId());
//		System.out.println(expert.getUser().getUserId());
//		expertService.updateSignType(null, "e5b4375bca5c41f792afef7630df2d51");
		EvaluationStep	evaluationStep  = new EvaluationStep();
		evaluationStep.setId("aaaaaaaaaaaaaaaaaaaaaaaaa");
		evaluationStep.setPassType("01");
		expertService.getEvaluationStepExpert("11111", evaluationStep);
		
	}

	/**
	 * @Description: 获得系统中所有的评标专家
	 * @author wangxiang
	 * @return 
	 */
	public List<Expert> getSystemExpertList() {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getSystemExpertList");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("userType", UserEnum.EXPERT);	
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 删除专家
	 * @author wangxiang
	 * @param id 
	 */
	public boolean deleteById(String id) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteById");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("id", id);	
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  true;
			}else{
				return false;
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获得指定评标步骤的自定义评标专家小组列表
	 * @author wangxiang
	 * @param tenderId 项目id
	 * @param stepId 步骤Id
	 * @return
	 */
	public List<Expert> getCustomExpertList(String tenderId, String stepId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getCustomExpertList");
		Map<String, Object> param = new HashMap<String, Object>();
  		param.put("tenderId", tenderId);	
  		param.put("stepId", stepId);	
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得最大的专家账号
	 * @author wangxiang
	 * @return
	 */
	public int getMaxExpertAccountName(){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getMaxExpertAccountName");
		Map<String, Object> param = new HashMap<String, Object>();
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return  Integer.valueOf(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return -1;
		}
	}
	
	/**
	 * @Description: 为专家组长投票
	 * @author wangxiang
	 * @param myId 投票者id
	 * @param voterId 投票对象的id
	 * @return
	 */
	public boolean votesExpertLeader(String myId, String voterId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/votesExpertLeader");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("myId", myId);
		param.put("voterId", voterId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return  ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 新增临时专家
	 * @author wangxiang
	 * @param expert
	 * @param userRoleList
	 * @param user 
	 */
	public boolean saveTemExpert(Expert expert, List<AuthUserRole> userRoleList, AuthUser user){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/saveTemExpert");
		SaveTempExpertVo saveTempExpertVo =  new SaveTempExpertVo(expert,userRoleList,user);
		saveTempExpertVo.setExpert(expert);
		saveTempExpertVo.setUserRoleList(userRoleList);
		saveTempExpertVo.setUser(user);
  		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(saveTempExpertVo));
			return  ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 删除所有评审专家
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	public boolean deleteAllExperts(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteAllExperts");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return  ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 获取专家可分配的分组列表
	 * @author wangxiang
	 * @param tenderId
	 * @param expertId
	 * @return 
	 */
	public List<Object> getEvaGroupList(String tenderId, String expertId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvaGroupList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("expertId", expertId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获得评标单元指定的专家
	 * @author wangxiang
	 * @param tenderId
	 * @param evalGroup
	 * @return
	 */
	public Expert getExpertByevalGroup(String tenderId, String evalGroup){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertByevalGroup");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("evalGroup", evalGroup);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToBean(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 获取所有指标单元
	 * @author wangxiang
	 * @param tenderId
	 * @param expertId
	 * @return 
	 */
	public List<Object> getAllEvaGroupList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getAllEvaGroupList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	/**
	 * @Description: 删除垃圾专家
	 * @author wangxiang
	 * @param tenderId 
	 */
	public boolean deleteDirtyExpert(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteDirtyExpert");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return  ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 通过项目ID和专家ID列表查询专家
	 * @author wangxiang
	 * @param id
	 * @param objIdList
	 * @return 
	 */
	public List<Expert> getExpertListByIdList(String tenderId, List<String> objIdList) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertListByIdList");
		RequestBody<String> requestBody = new RequestBody<String>();
		requestBody.setEntityList(objIdList);
		requestBody.setParam("tenderId", tenderId);
  		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(requestBody));
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToList(result, Expert.class);
			}
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
		return null;
	}
	
	/**
	 * @Description: 获得评标专家列表
	 * @author mazc
	 * @param tenderId 项目id
	 * @param signType 签到类型
	 * @param expertType 评审成员类型 （正选，备选）
	 * @return
	 */
	public List<Expert> getExpertList(String tenderId, String signType){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertList");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("signType", signType);
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.strToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public Expert getById(String id){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getById");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("id", id);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToBean(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}	
	
	public List<Object> getEvaGroupList(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getEvaGroupListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public int batchSave(List<Expert> expertList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insertByBatch");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(expertList));
			if(ResultStatus.isReultStatusInteger(result)){
				return Integer.valueOf(result);
			}
			return 0;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return 0;
		}
	}
	
	public boolean batchSaveOrUpdate(List<Expert> expertList){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/batchSaveOrUpdate");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(expertList));
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean deleteExpert(String tenderId, String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/deleteExpert");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	public List<Expert> getExpertListByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertListByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public Expert saveOrUpdateReturn (Expert expert){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/insert");
		try {
			String result = NetworkRequest.post(strWebServerUrl, JsonUtil.jsonObjectToStr(expert));
			if(ResultStatus.getReultStatusBoolean(result)){
				return expert;
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	public boolean updateVotesAndVotesNumByTenderId(int votes ,int votesNum,String tenderId ){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateVotesAndVotesNumByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("votes", votes);
		param.put("votesNum", votesNum);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public boolean updateSignTypeByTenderIdOrUserId(String signType,String tenderId,String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/updateSignTypeByTenderIdOrUserId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("signType", signType);
		if(null != userId){
			param.put("userId", userId);			
		}
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	public Expert getExpertByUserIdAndTenderId(String userId,String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertByUserIdAndTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl,param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return JsonUtil.jsonToBean(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public List<Object> getExpertIdListByTenderIdAndSignTypeisNull(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertIdListByTenderIdAndSignTypeisNull");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public  List<Object> getUserIdByTenderId(String tenderId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getUserIdByTenderId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
  		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Object.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
	public boolean getIdListByTenderIdAndUserId( String tenderId,String userId){
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getIdListByTenderIdAndUserId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("userId", userId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 *	 根据项目父级ID查询当前项目（包含子项目）下所有的评审专家
	 * @param id
	 * @return
	 */
	public List<Expert> getExpertListByProjectId(String id) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertListByProjectId");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", id);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}

	/**
	 * @Description: 两位专家是否在同一项目中
	 * @author chenxw
	 * @param selectUserId
	 * @param tempUserId
	 * @return 
	 */
	public boolean isTenderExpertContain(String tenderId, String selectUserId, String tempUserId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/isTenderExpertContain");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("tenderId", tenderId);
		param.put("selectUserId", selectUserId);
		param.put("tempUserId", tempUserId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}
	
	/**
	 * @Description: 两位专家是否在同一项目中
	 * @author chenxw
	 * @param selectUserId
	 * @param tempUserId
	 * @return 
	 */
	public boolean isTenderExpertContain(String selectUserId, String tempUserId) {
		return isTenderExpertContain(null, selectUserId, tempUserId);
	}
	
	/**
	 * @Description: 修改临时账号信息
	 * @author chenxw
	 * @param tempUserId
	 * @param selectUser
	 * @return 
	 */
	public boolean updateTempExpertMessgae(String selectUserId, String tempUserId) {
		String strWebServerUrl = Constants.getServiceUrl(URL + "/updateTempExpertMessgae");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("selectUserId", selectUserId);
		param.put("tempUserId", tempUserId);
		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			return ResultStatus.getReultStatusBoolean(result);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return false;
		}
	}

	/**
	 * @Description: 按照专家姓名查找
	 * @author wangxiang
	 * @param trim
	 * @return 
	 */
	public List<Expert> getExpertListByUserName(String userName) {
		String strWebServerUrl = Constants.getServiceUrl( URL + "/getExpertListByUserName");
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("userName", userName);
 		try {
			String result = NetworkRequest.get(strWebServerUrl, param);
			if(ResultStatus.getReultStatusIsNotEmpty(result)){
				return  JsonUtil.jsonToList(result, Expert.class);
			}
			return null;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			return null;
		}
	}
	
}
